Buffer

Struct Buffer 

pub struct Buffer { /* private fields */ }

Implementations

Source

impl Buffer

pub unsafe fn from_glib_ptr_borrow(ptr: &*mut GstBuffer) -> &Self

pub unsafe fn from_glib_none(ptr: *const GstBuffer) -> Self

pub unsafe fn from_glib_full(ptr: *const GstBuffer) -> Self

pub unsafe fn from_glib_borrow(ptr: *const GstBuffer) -> Borrowed<Self>

pub unsafe fn replace_ptr(&mut self, ptr: *mut GstBuffer)

pub fn make_mut(&mut self) -> &mut BufferRef

pub fn get_mut(&mut self) -> Option<&mut BufferRef>

pub fn is_writable(&self) -> bool

pub fn upcast(self) -> MiniObject

Source

impl Buffer

pub fn new() -> Self

pub fn with_size(size: usize) -> Result<Self, BoolError>

pub fn from_mut_slice<T: AsMut<[u8]> + Send + 'static>(slice: T) -> Self

pub fn from_slice<T: AsRef<[u8]> + Send + 'static>(slice: T) -> Self

pub fn try_into_inner<T: 'static>( self, ) -> Result<T, (Self, MemoryIntoInnerError)>

Attempts to extract the underlying wrapped value of type T from this Buffer.

This will only succeed if:

  • The buffer contains exactly one memory
  • That memory was created with Memory::from_slice() wrapping type T
  • The memory can be converted (see Memory::try_into_inner() requirements)

On success, the Buffer is consumed and the original wrapped value is returned. On failure, the original Buffer and an error are returned in the Err variant.

Examples
use gstreamer::Buffer;

gstreamer::init().unwrap();

let vec = vec![1u8, 2, 3, 4, 5];
let expected = vec.clone();
let buf = Buffer::from_slice(vec);

let converted: Vec<u8> = buf.try_into_inner().unwrap();
assert_eq!(converted, expected);
pub fn into_mapped_buffer_readable(self) -> Result<MappedBuffer<Readable>, Self>

pub fn into_mapped_buffer_writable(self) -> Result<MappedBuffer<Writable>, Self>

pub fn into_cursor_readable(self) -> BufferCursor<Readable>

pub fn into_cursor_writable(self) -> Result<BufferCursor<Writable>, BoolError>

pub fn append(&mut self, other: Self)

Methods from Deref<Target = BufferRef>

pub fn as_ptr(&self) -> *const GstBuffer

pub fn as_mut_ptr(&self) -> *mut GstBuffer

pub fn copy(&self) -> Buffer

pub fn upcast_ref(&self) -> &MiniObjectRef

pub fn map_readable(&self) -> Result<BufferMap<'_, Readable>, BoolError>

pub fn map_range_readable( &self, range: impl RangeBounds<usize>, ) -> Result<BufferMap<'_, Readable>, BoolError>

pub fn copy_region( &self, flags: BufferCopyFlags, range: impl RangeBounds<usize>, ) -> Result<Buffer, BoolError>

pub fn copy_into( &self, dest: &mut BufferRef, flags: BufferCopyFlags, range: impl RangeBounds<usize>, ) -> Result<(), BoolError>

pub fn copy_to_slice( &self, offset: usize, slice: &mut [u8], ) -> Result<(), usize>

pub fn copy_deep(&self) -> Result<Buffer, BoolError>

pub fn sizes(&self) -> (usize, usize, usize)

pub fn sizes_range( &self, range: impl RangeBounds<usize>, ) -> (usize, usize, usize)

pub fn size(&self) -> usize

pub fn maxsize(&self) -> usize

pub fn offset(&self) -> u64

pub fn offset_end(&self) -> u64

pub fn pts(&self) -> Option<ClockTime>

pub fn dts(&self) -> Option<ClockTime>

pub fn dts_or_pts(&self) -> Option<ClockTime>

pub fn duration(&self) -> Option<ClockTime>

pub fn flags(&self) -> BufferFlags

pub fn meta<T: MetaAPI>(&self) -> Option<MetaRef<'_, T>>

pub fn iter_meta<T: MetaAPI>(&self) -> MetaIter<'_, T>

pub fn foreach_meta<F: FnMut(MetaRef<'_, Meta>) -> ControlFlow<(), ()>>( &self, func: F, ) -> bool

pub fn find_memory( &self, range: impl RangeBounds<usize>, ) -> Option<(Range<usize>, usize)>

pub fn all_memory(&self) -> Option<Memory>

pub fn memory(&self, idx: usize) -> Option<Memory>

pub fn memory_range(&self, range: impl RangeBounds<usize>) -> Option<Memory>

pub fn is_all_memory_writable(&self) -> bool

pub fn is_memory_range_writable(&self, range: impl RangeBounds<usize>) -> bool

pub fn n_memory(&self) -> usize

pub fn peek_memory(&self, idx: usize) -> &MemoryRef

pub fn iter_memories(&self) -> Iter<'_>

pub fn iter_memories_owned(&self) -> IterOwned<'_>

pub fn as_cursor_readable(&self) -> BufferRefCursor<&BufferRef>

pub fn dump(&self) -> Dump<'_>

pub fn dump_range(&self, range: impl RangeBounds<usize>) -> Dump<'_>