Trait byte_slice_cast::ToByteSlice [−][src]
pub unsafe trait ToByteSlice where
Self: Sized, { fn to_byte_slice<T: AsRef<[Self]> + ?Sized>(
slice: &T
) -> Result<&[u8], Error>; }
Trait for converting from an immutable slice of a fundamental, built-in numeric type to an immutable byte slice.
Usually using the AsByteSlice trait is more convenient.
Example
use byte_slice_cast::*; let slice: [u16; 3] = [0x0102, 0x0304, 0x0506]; let converted_slice = ToByteSlice::to_byte_slice(&slice).unwrap(); if cfg!(target_endian = "big") { assert_eq!(converted_slice, &[1u8, 2u8, 3u8, 4u8, 5u8, 6u8]); } else { assert_eq!(converted_slice, &[2u8, 1u8, 4u8, 3u8, 6u8, 5u8]); }
Required Methods
fn to_byte_slice<T: AsRef<[Self]> + ?Sized>(slice: &T) -> Result<&[u8], Error>
Convert from an immutable slice of a fundamental, built-in numeric type to an immutable byte slice
Implementations on Foreign Types
impl ToByteSlice for u8[src]
impl ToByteSlice for u8impl ToByteSlice for u16[src]
impl ToByteSlice for u16impl ToByteSlice for u32[src]
impl ToByteSlice for u32impl ToByteSlice for u64[src]
impl ToByteSlice for u64impl ToByteSlice for u128[src]
impl ToByteSlice for u128impl ToByteSlice for i8[src]
impl ToByteSlice for i8impl ToByteSlice for i16[src]
impl ToByteSlice for i16impl ToByteSlice for i32[src]
impl ToByteSlice for i32impl ToByteSlice for i64[src]
impl ToByteSlice for i64impl ToByteSlice for i128[src]
impl ToByteSlice for i128impl ToByteSlice for f32[src]
impl ToByteSlice for f32impl ToByteSlice for f64[src]
impl ToByteSlice for f64