Trait byte_slice_cast::ToMutByteSlice [−][src]
pub unsafe trait ToMutByteSlice where
Self: Sized, { fn to_mut_byte_slice<T: AsMut<[Self]> + ?Sized>(
slice: &mut T
) -> Result<&mut [u8], Error>; }
Trait for converting from a mutable slice of a fundamental, built-in numeric type to a mutable byte slice.
Usually using the AsMutByteSlice trait is more convenient.
Example
use byte_slice_cast::*; let mut slice: [u16; 3] = [0x0102, 0x0304, 0x0506]; let converted_slice = ToMutByteSlice::to_mut_byte_slice(&mut slice).unwrap(); if cfg!(target_endian = "big") { assert_eq!(converted_slice, &[1u8, 2u8, 3u8, 4u8, 5u8, 6u8]); } else { assert_eq!(converted_slice, &[2u8, 1u8, 4u8, 3u8, 6u8, 5u8]); }
Required Methods
fn to_mut_byte_slice<T: AsMut<[Self]> + ?Sized>(
slice: &mut T
) -> Result<&mut [u8], Error>
slice: &mut T
) -> Result<&mut [u8], Error>
Convert from a mutable slice of a fundamental, built-in numeric type to a mutable byte slice
Implementations on Foreign Types
impl ToMutByteSlice for u8[src]
impl ToMutByteSlice for u8impl ToMutByteSlice for u16[src]
impl ToMutByteSlice for u16impl ToMutByteSlice for u32[src]
impl ToMutByteSlice for u32impl ToMutByteSlice for u64[src]
impl ToMutByteSlice for u64impl ToMutByteSlice for u128[src]
impl ToMutByteSlice for u128impl ToMutByteSlice for i8[src]
impl ToMutByteSlice for i8impl ToMutByteSlice for i16[src]
impl ToMutByteSlice for i16impl ToMutByteSlice for i32[src]
impl ToMutByteSlice for i32impl ToMutByteSlice for i64[src]
impl ToMutByteSlice for i64impl ToMutByteSlice for i128[src]
impl ToMutByteSlice for i128impl ToMutByteSlice for f32[src]
impl ToMutByteSlice for f32impl ToMutByteSlice for f64[src]
impl ToMutByteSlice for f64