Struct cairo::FontOptions [−]
pub struct FontOptions(_);
Methods
impl FontOptions[src]
impl FontOptionspub fn new() -> FontOptions[src]
pub fn new() -> FontOptionspub unsafe fn from_raw_full(ptr: *mut cairo_font_options_t) -> FontOptions[src]
pub unsafe fn from_raw_full(ptr: *mut cairo_font_options_t) -> FontOptionspub fn to_raw_none(&self) -> *mut cairo_font_options_t[src]
pub fn to_raw_none(&self) -> *mut cairo_font_options_tpub fn ensure_status(&self)[src]
pub fn ensure_status(&self)pub fn merge(&mut self, other: &FontOptions)[src]
pub fn merge(&mut self, other: &FontOptions)pub fn set_antialias(&mut self, antialias: Antialias)[src]
pub fn set_antialias(&mut self, antialias: Antialias)pub fn get_antialias(&self) -> Antialias[src]
pub fn get_antialias(&self) -> Antialiaspub fn set_subpixel_order(&mut self, order: SubpixelOrder)[src]
pub fn set_subpixel_order(&mut self, order: SubpixelOrder)pub fn get_subpixel_order(&self) -> SubpixelOrder[src]
pub fn get_subpixel_order(&self) -> SubpixelOrderpub fn set_hint_style(&mut self, hint_style: HintStyle)[src]
pub fn set_hint_style(&mut self, hint_style: HintStyle)pub fn get_hint_style(&self) -> HintStyle[src]
pub fn get_hint_style(&self) -> HintStylepub fn set_hint_metrics(&mut self, hint_metrics: HintMetrics)[src]
pub fn set_hint_metrics(&mut self, hint_metrics: HintMetrics)pub fn get_hint_metrics(&self) -> HintMetrics[src]
pub fn get_hint_metrics(&self) -> HintMetricsTrait Implementations
impl Debug for FontOptions[src]
impl Debug for FontOptionsfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Clone for FontOptions
impl Clone for FontOptionsfn clone(&self) -> FontOptions
fn clone(&self) -> FontOptionsReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl StaticType for FontOptions
impl StaticType for FontOptionsfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl PartialEq for FontOptions[src]
impl PartialEq for FontOptionsfn eq(&self, other: &FontOptions) -> bool[src]
fn eq(&self, other: &FontOptions) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0
[src]This method tests for !=.
impl Eq for FontOptions[src]
impl Eq for FontOptionsimpl Hash for FontOptions[src]
impl Hash for FontOptionsfn hash<H>(&self, state: &mut H) where
H: Hasher, [src]
fn hash<H>(&self, state: &mut H) where
H: Hasher, Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Default for FontOptions[src]
impl Default for FontOptionsAuto Trait Implementations
impl !Send for FontOptions
impl !Send for FontOptionsimpl !Sync for FontOptions
impl !Sync for FontOptions