Struct cairo::RectangleInt [−][src]
Fields
x: i32
y: i32
width: i32
height: i32
Methods
impl RectangleInt[src]
impl RectangleIntpub fn to_raw_none(&self) -> *mut cairo_rectangle_int_t[src]
pub fn to_raw_none(&self) -> *mut cairo_rectangle_int_tTrait Implementations
impl Clone for RectangleInt[src]
impl Clone for RectangleIntfn clone(&self) -> RectangleInt[src]
fn clone(&self) -> RectangleIntReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Copy for RectangleInt[src]
impl Copy for RectangleIntimpl Debug for RectangleInt[src]
impl Debug for RectangleIntfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for RectangleInt[src]
impl PartialEq for RectangleIntfn eq(&self, other: &RectangleInt) -> bool[src]
fn eq(&self, other: &RectangleInt) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &RectangleInt) -> bool[src]
fn ne(&self, other: &RectangleInt) -> boolThis method tests for !=.
impl Eq for RectangleInt[src]
impl Eq for RectangleIntimpl Hash for RectangleInt[src]
impl Hash for RectangleIntfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl StaticType for RectangleInt[src]
impl StaticType for RectangleIntfn static_type() -> Type[src]
fn static_type() -> TypeReturns the type identifier of Self.
impl<'a> FromValueOptional<'a> for RectangleInt[src]
impl<'a> FromValueOptional<'a> for RectangleIntunsafe fn from_value_optional(v: &'a Value) -> Option<Self>[src]
unsafe fn from_value_optional(v: &'a Value) -> Option<Self>impl SetValue for RectangleInt[src]
impl SetValue for RectangleIntimpl SetValueOptional for RectangleInt[src]
impl SetValueOptional for RectangleIntunsafe fn set_value_optional(v: &mut Value, s: Option<&Self>)[src]
unsafe fn set_value_optional(v: &mut Value, s: Option<&Self>)Auto Trait Implementations
impl Send for RectangleInt
impl Send for RectangleIntimpl Sync for RectangleInt
impl Sync for RectangleInt