Struct gdk::DragAction [−]
pub struct DragAction { /* fields omitted */ }Methods
impl DragAction
impl DragActionpub const DEFAULT: DragAction
DEFAULT: DragAction = DragAction{bits: 1,}
pub const COPY: DragAction
COPY: DragAction = DragAction{bits: 2,}
pub const MOVE: DragAction
MOVE: DragAction = DragAction{bits: 4,}
pub const LINK: DragAction
LINK: DragAction = DragAction{bits: 8,}
pub const PRIVATE: DragAction
PRIVATE: DragAction = DragAction{bits: 16,}
pub const ASK: DragAction
ASK: DragAction = DragAction{bits: 32,}
pub fn empty() -> DragAction
pub fn empty() -> DragActionReturns an empty set of flags.
pub fn all() -> DragAction
pub fn all() -> DragActionReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<DragAction>
pub fn from_bits(bits: u32) -> Option<DragAction>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> DragAction
pub fn from_bits_truncate(bits: u32) -> DragActionConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: DragAction) -> bool
pub fn intersects(&self, other: DragAction) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: DragAction) -> bool
pub fn contains(&self, other: DragAction) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: DragAction)
pub fn insert(&mut self, other: DragAction)Inserts the specified flags in-place.
pub fn remove(&mut self, other: DragAction)
pub fn remove(&mut self, other: DragAction)Removes the specified flags in-place.
pub fn toggle(&mut self, other: DragAction)
pub fn toggle(&mut self, other: DragAction)Toggles the specified flags in-place.
pub fn set(&mut self, other: DragAction, value: bool)
pub fn set(&mut self, other: DragAction, value: bool)Inserts or removes the specified flags depending on the passed value.