Struct gdk::FrameClockPhase [−]
pub struct FrameClockPhase { /* fields omitted */ }Methods
impl FrameClockPhase
impl FrameClockPhasepub const NONE: FrameClockPhase
NONE: FrameClockPhase = FrameClockPhase{bits: 0,}
pub const FLUSH_EVENTS: FrameClockPhase
FLUSH_EVENTS: FrameClockPhase = FrameClockPhase{bits: 1,}
pub const BEFORE_PAINT: FrameClockPhase
BEFORE_PAINT: FrameClockPhase = FrameClockPhase{bits: 2,}
pub const UPDATE: FrameClockPhase
UPDATE: FrameClockPhase = FrameClockPhase{bits: 4,}
pub const LAYOUT: FrameClockPhase
LAYOUT: FrameClockPhase = FrameClockPhase{bits: 8,}
pub const PAINT: FrameClockPhase
PAINT: FrameClockPhase = FrameClockPhase{bits: 16,}
pub const RESUME_EVENTS: FrameClockPhase
RESUME_EVENTS: FrameClockPhase = FrameClockPhase{bits: 32,}
pub const AFTER_PAINT: FrameClockPhase
AFTER_PAINT: FrameClockPhase = FrameClockPhase{bits: 64,}
pub fn empty() -> FrameClockPhase
pub fn empty() -> FrameClockPhaseReturns an empty set of flags.
pub fn all() -> FrameClockPhase
pub fn all() -> FrameClockPhaseReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<FrameClockPhase>
pub fn from_bits(bits: u32) -> Option<FrameClockPhase>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> FrameClockPhase
pub fn from_bits_truncate(bits: u32) -> FrameClockPhaseConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: FrameClockPhase) -> bool
pub fn intersects(&self, other: FrameClockPhase) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: FrameClockPhase) -> bool
pub fn contains(&self, other: FrameClockPhase) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: FrameClockPhase)
pub fn insert(&mut self, other: FrameClockPhase)Inserts the specified flags in-place.
pub fn remove(&mut self, other: FrameClockPhase)
pub fn remove(&mut self, other: FrameClockPhase)Removes the specified flags in-place.
pub fn toggle(&mut self, other: FrameClockPhase)
pub fn toggle(&mut self, other: FrameClockPhase)Toggles the specified flags in-place.
pub fn set(&mut self, other: FrameClockPhase, value: bool)
pub fn set(&mut self, other: FrameClockPhase, value: bool)Inserts or removes the specified flags depending on the passed value.