Struct gdk::FrameTimings [−]
pub struct FrameTimings(_);
Methods
impl FrameTimings[src]
impl FrameTimingspub fn get_complete(&self) -> bool[src]
pub fn get_complete(&self) -> boolpub fn get_frame_counter(&self) -> i64[src]
pub fn get_frame_counter(&self) -> i64pub fn get_frame_time(&self) -> i64[src]
pub fn get_frame_time(&self) -> i64pub fn get_predicted_presentation_time(&self) -> i64[src]
pub fn get_predicted_presentation_time(&self) -> i64pub fn get_presentation_time(&self) -> i64[src]
pub fn get_presentation_time(&self) -> i64pub fn get_refresh_interval(&self) -> i64[src]
pub fn get_refresh_interval(&self) -> i64Trait Implementations
impl Debug for FrameTimings[src]
impl Debug for FrameTimingsfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for FrameTimings[src]
impl PartialEq for FrameTimingsfn eq(&self, other: &FrameTimings) -> bool[src]
fn eq(&self, other: &FrameTimings) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &FrameTimings) -> bool[src]
fn ne(&self, other: &FrameTimings) -> boolThis method tests for !=.
impl Eq for FrameTimings[src]
impl Eq for FrameTimingsimpl PartialOrd for FrameTimings[src]
impl PartialOrd for FrameTimingsfn partial_cmp(&self, other: &FrameTimings) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &FrameTimings) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &FrameTimings) -> bool[src]
fn lt(&self, other: &FrameTimings) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &FrameTimings) -> bool[src]
fn le(&self, other: &FrameTimings) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &FrameTimings) -> bool[src]
fn gt(&self, other: &FrameTimings) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &FrameTimings) -> bool[src]
fn ge(&self, other: &FrameTimings) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for FrameTimings[src]
impl Ord for FrameTimingsfn cmp(&self, other: &FrameTimings) -> Ordering[src]
fn cmp(&self, other: &FrameTimings) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for FrameTimings[src]
impl Hash for FrameTimingsfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for FrameTimings
impl Clone for FrameTimingsfn clone(&self) -> FrameTimings
fn clone(&self) -> FrameTimingsReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for FrameTimings
impl StaticType for FrameTimingsfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.