Struct gdk::ModifierType [−]
pub struct ModifierType { /* fields omitted */ }Methods
impl ModifierType
impl ModifierTypepub const SHIFT_MASK: ModifierType
SHIFT_MASK: ModifierType = ModifierType{bits: 1,}
pub const LOCK_MASK: ModifierType
LOCK_MASK: ModifierType = ModifierType{bits: 2,}
pub const CONTROL_MASK: ModifierType
CONTROL_MASK: ModifierType = ModifierType{bits: 4,}
pub const MOD1_MASK: ModifierType
MOD1_MASK: ModifierType = ModifierType{bits: 8,}
pub const MOD2_MASK: ModifierType
MOD2_MASK: ModifierType = ModifierType{bits: 16,}
pub const MOD3_MASK: ModifierType
MOD3_MASK: ModifierType = ModifierType{bits: 32,}
pub const MOD4_MASK: ModifierType
MOD4_MASK: ModifierType = ModifierType{bits: 64,}
pub const MOD5_MASK: ModifierType
MOD5_MASK: ModifierType = ModifierType{bits: 128,}
pub const BUTTON1_MASK: ModifierType
BUTTON1_MASK: ModifierType = ModifierType{bits: 256,}
pub const BUTTON2_MASK: ModifierType
BUTTON2_MASK: ModifierType = ModifierType{bits: 512,}
pub const BUTTON3_MASK: ModifierType
BUTTON3_MASK: ModifierType = ModifierType{bits: 1024,}
pub const BUTTON4_MASK: ModifierType
BUTTON4_MASK: ModifierType = ModifierType{bits: 2048,}
pub const BUTTON5_MASK: ModifierType
BUTTON5_MASK: ModifierType = ModifierType{bits: 4096,}
pub const MODIFIER_RESERVED_13_MASK: ModifierType
MODIFIER_RESERVED_13_MASK: ModifierType = ModifierType{bits: 8192,}
pub const MODIFIER_RESERVED_14_MASK: ModifierType
MODIFIER_RESERVED_14_MASK: ModifierType = ModifierType{bits: 16384,}
pub const MODIFIER_RESERVED_15_MASK: ModifierType
MODIFIER_RESERVED_15_MASK: ModifierType = ModifierType{bits: 32768,}
pub const MODIFIER_RESERVED_16_MASK: ModifierType
MODIFIER_RESERVED_16_MASK: ModifierType = ModifierType{bits: 65536,}
pub const MODIFIER_RESERVED_17_MASK: ModifierType
MODIFIER_RESERVED_17_MASK: ModifierType = ModifierType{bits: 131072,}
pub const MODIFIER_RESERVED_18_MASK: ModifierType
MODIFIER_RESERVED_18_MASK: ModifierType = ModifierType{bits: 262144,}
pub const MODIFIER_RESERVED_19_MASK: ModifierType
MODIFIER_RESERVED_19_MASK: ModifierType = ModifierType{bits: 524288,}
pub const MODIFIER_RESERVED_20_MASK: ModifierType
MODIFIER_RESERVED_20_MASK: ModifierType = ModifierType{bits: 1048576,}
pub const MODIFIER_RESERVED_21_MASK: ModifierType
MODIFIER_RESERVED_21_MASK: ModifierType = ModifierType{bits: 2097152,}
pub const MODIFIER_RESERVED_22_MASK: ModifierType
MODIFIER_RESERVED_22_MASK: ModifierType = ModifierType{bits: 4194304,}
pub const MODIFIER_RESERVED_23_MASK: ModifierType
MODIFIER_RESERVED_23_MASK: ModifierType = ModifierType{bits: 8388608,}
pub const MODIFIER_RESERVED_24_MASK: ModifierType
MODIFIER_RESERVED_24_MASK: ModifierType = ModifierType{bits: 16777216,}
pub const MODIFIER_RESERVED_25_MASK: ModifierType
MODIFIER_RESERVED_25_MASK: ModifierType = ModifierType{bits: 33554432,}
pub const SUPER_MASK: ModifierType
SUPER_MASK: ModifierType = ModifierType{bits: 67108864,}
pub const HYPER_MASK: ModifierType
HYPER_MASK: ModifierType = ModifierType{bits: 134217728,}
pub const META_MASK: ModifierType
META_MASK: ModifierType = ModifierType{bits: 268435456,}
pub const MODIFIER_RESERVED_29_MASK: ModifierType
MODIFIER_RESERVED_29_MASK: ModifierType = ModifierType{bits: 536870912,}
pub const RELEASE_MASK: ModifierType
RELEASE_MASK: ModifierType = ModifierType{bits: 1073741824,}
pub const MODIFIER_MASK: ModifierType
MODIFIER_MASK: ModifierType = ModifierType{bits: 1543512063,}
pub fn empty() -> ModifierType
pub fn empty() -> ModifierTypeReturns an empty set of flags.
pub fn all() -> ModifierType
pub fn all() -> ModifierTypeReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<ModifierType>
pub fn from_bits(bits: u32) -> Option<ModifierType>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> ModifierType
pub fn from_bits_truncate(bits: u32) -> ModifierTypeConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: ModifierType) -> bool
pub fn intersects(&self, other: ModifierType) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: ModifierType) -> bool
pub fn contains(&self, other: ModifierType) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ModifierType)
pub fn insert(&mut self, other: ModifierType)Inserts the specified flags in-place.
pub fn remove(&mut self, other: ModifierType)
pub fn remove(&mut self, other: ModifierType)Removes the specified flags in-place.
pub fn toggle(&mut self, other: ModifierType)
pub fn toggle(&mut self, other: ModifierType)Toggles the specified flags in-place.
pub fn set(&mut self, other: ModifierType, value: bool)
pub fn set(&mut self, other: ModifierType, value: bool)Inserts or removes the specified flags depending on the passed value.