Struct gdk::RGBA [−][src]
Fields
red: f64
green: f64
blue: f64
alpha: f64
Methods
impl RGBA[src]
impl RGBApub fn black() -> RGBA[src]
pub fn black() -> RGBApub fn blue() -> RGBA[src]
pub fn blue() -> RGBApub fn green() -> RGBA[src]
pub fn green() -> RGBApub fn red() -> RGBA[src]
pub fn red() -> RGBApub fn white() -> RGBA[src]
pub fn white() -> RGBATrait Implementations
impl Clone for RGBA[src]
impl Clone for RGBAfn clone(&self) -> RGBA[src]
fn clone(&self) -> RGBAReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Copy for RGBA[src]
impl Copy for RGBAimpl Debug for RGBA[src]
impl Debug for RGBAfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for RGBA[src]
impl Display for RGBAfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl FromStr for RGBA[src]
impl FromStr for RGBAtype Err = RgbaParseError
The associated error which can be returned from parsing.
fn from_str(s: &str) -> Result<Self, Self::Err>[src]
fn from_str(s: &str) -> Result<Self, Self::Err>Parses a string s to return a value of this type. Read more
impl Hash for RGBA[src]
impl Hash for RGBAfn hash<H: Hasher>(&self, state: &mut H)[src]
fn hash<H: Hasher>(&self, state: &mut H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl PartialEq for RGBA[src]
impl PartialEq for RGBAfn eq(&self, other: &RGBA) -> bool[src]
fn eq(&self, other: &RGBA) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0
[src]This method tests for !=.
impl Eq for RGBA[src]
impl Eq for RGBAimpl StaticType for RGBA[src]
impl StaticType for RGBAfn static_type() -> Type[src]
fn static_type() -> TypeReturns the type identifier of Self.
impl<'a> FromValueOptional<'a> for RGBA[src]
impl<'a> FromValueOptional<'a> for RGBAunsafe fn from_value_optional(value: &'a Value) -> Option<Self>[src]
unsafe fn from_value_optional(value: &'a Value) -> Option<Self>impl SetValue for RGBA[src]
impl SetValue for RGBAimpl SetValueOptional for RGBA[src]
impl SetValueOptional for RGBAunsafe fn set_value_optional(value: &mut Value, this: Option<&Self>)[src]
unsafe fn set_value_optional(value: &mut Value, this: Option<&Self>)