Struct gdk::Visual [−]
pub struct Visual(_, _);
Methods
impl Visual[src]
impl Visualpub fn get_best() -> Visual[src]
pub fn get_best() -> Visualpub fn get_best_depth() -> i32[src]
pub fn get_best_depth() -> i32pub fn get_best_type() -> VisualType[src]
pub fn get_best_type() -> VisualTypepub fn get_best_with_both(depth: i32, visual_type: VisualType) -> Option<Visual>[src]
pub fn get_best_with_both(depth: i32, visual_type: VisualType) -> Option<Visual>pub fn get_best_with_depth(depth: i32) -> Option<Visual>[src]
pub fn get_best_with_depth(depth: i32) -> Option<Visual>pub fn get_best_with_type(visual_type: VisualType) -> Option<Visual>[src]
pub fn get_best_with_type(visual_type: VisualType) -> Option<Visual>pub fn get_system() -> Visual[src]
pub fn get_system() -> VisualTrait Implementations
impl Clone for Visual
impl Clone for Visualfn clone(&self) -> Visual
fn clone(&self) -> VisualReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Visual
impl Hash for Visualfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Visual
impl Ord for Visualfn cmp(&self, other: &Visual) -> Ordering
fn cmp(&self, other: &Visual) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Visual
impl StaticType for Visualfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Visual
impl<T: IsA<Object>> PartialEq<T> for Visualfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Visual
impl Eq for Visualimpl<T: IsA<Object>> PartialOrd<T> for Visual
impl<T: IsA<Object>> PartialOrd<T> for Visualfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Visual
impl Debug for Visualimpl IsA<Object> for Visual
impl IsA<Object> for Visual