Struct gdk::WMDecoration [−]
pub struct WMDecoration { /* fields omitted */ }Methods
impl WMDecoration
impl WMDecorationpub const ALL: WMDecoration
ALL: WMDecoration = WMDecoration{bits: 1,}
pub const BORDER: WMDecoration
BORDER: WMDecoration = WMDecoration{bits: 2,}
pub const RESIZEH: WMDecoration
RESIZEH: WMDecoration = WMDecoration{bits: 4,}
pub const TITLE: WMDecoration
TITLE: WMDecoration = WMDecoration{bits: 8,}
pub const MENU: WMDecoration
MENU: WMDecoration = WMDecoration{bits: 16,}
pub const MINIMIZE: WMDecoration
MINIMIZE: WMDecoration = WMDecoration{bits: 32,}
pub const MAXIMIZE: WMDecoration
MAXIMIZE: WMDecoration = WMDecoration{bits: 64,}
pub fn empty() -> WMDecoration
pub fn empty() -> WMDecorationReturns an empty set of flags.
pub fn all() -> WMDecoration
pub fn all() -> WMDecorationReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<WMDecoration>
pub fn from_bits(bits: u32) -> Option<WMDecoration>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> WMDecoration
pub fn from_bits_truncate(bits: u32) -> WMDecorationConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: WMDecoration) -> bool
pub fn intersects(&self, other: WMDecoration) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: WMDecoration) -> bool
pub fn contains(&self, other: WMDecoration) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: WMDecoration)
pub fn insert(&mut self, other: WMDecoration)Inserts the specified flags in-place.
pub fn remove(&mut self, other: WMDecoration)
pub fn remove(&mut self, other: WMDecoration)Removes the specified flags in-place.
pub fn toggle(&mut self, other: WMDecoration)
pub fn toggle(&mut self, other: WMDecoration)Toggles the specified flags in-place.
pub fn set(&mut self, other: WMDecoration, value: bool)
pub fn set(&mut self, other: WMDecoration, value: bool)Inserts or removes the specified flags depending on the passed value.