Struct gdk::WMFunction [−]
pub struct WMFunction { /* fields omitted */ }Methods
impl WMFunction
impl WMFunctionpub const ALL: WMFunction
ALL: WMFunction = WMFunction{bits: 1,}
pub const RESIZE: WMFunction
RESIZE: WMFunction = WMFunction{bits: 2,}
pub const MOVE: WMFunction
MOVE: WMFunction = WMFunction{bits: 4,}
pub const MINIMIZE: WMFunction
MINIMIZE: WMFunction = WMFunction{bits: 8,}
pub const MAXIMIZE: WMFunction
MAXIMIZE: WMFunction = WMFunction{bits: 16,}
pub const CLOSE: WMFunction
CLOSE: WMFunction = WMFunction{bits: 32,}
pub fn empty() -> WMFunction
pub fn empty() -> WMFunctionReturns an empty set of flags.
pub fn all() -> WMFunction
pub fn all() -> WMFunctionReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<WMFunction>
pub fn from_bits(bits: u32) -> Option<WMFunction>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> WMFunction
pub fn from_bits_truncate(bits: u32) -> WMFunctionConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: WMFunction) -> bool
pub fn intersects(&self, other: WMFunction) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: WMFunction) -> bool
pub fn contains(&self, other: WMFunction) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: WMFunction)
pub fn insert(&mut self, other: WMFunction)Inserts the specified flags in-place.
pub fn remove(&mut self, other: WMFunction)
pub fn remove(&mut self, other: WMFunction)Removes the specified flags in-place.
pub fn toggle(&mut self, other: WMFunction)
pub fn toggle(&mut self, other: WMFunction)Toggles the specified flags in-place.
pub fn set(&mut self, other: WMFunction, value: bool)
pub fn set(&mut self, other: WMFunction, value: bool)Inserts or removes the specified flags depending on the passed value.