Struct gdk::WindowHints [−]
pub struct WindowHints { /* fields omitted */ }Methods
impl WindowHints
impl WindowHintspub const POS: WindowHints
POS: WindowHints = WindowHints{bits: 1,}
pub const MIN_SIZE: WindowHints
MIN_SIZE: WindowHints = WindowHints{bits: 2,}
pub const MAX_SIZE: WindowHints
MAX_SIZE: WindowHints = WindowHints{bits: 4,}
pub const BASE_SIZE: WindowHints
BASE_SIZE: WindowHints = WindowHints{bits: 8,}
pub const ASPECT: WindowHints
ASPECT: WindowHints = WindowHints{bits: 16,}
pub const RESIZE_INC: WindowHints
RESIZE_INC: WindowHints = WindowHints{bits: 32,}
pub const WIN_GRAVITY: WindowHints
WIN_GRAVITY: WindowHints = WindowHints{bits: 64,}
pub const USER_POS: WindowHints
USER_POS: WindowHints = WindowHints{bits: 128,}
pub const USER_SIZE: WindowHints
USER_SIZE: WindowHints = WindowHints{bits: 256,}
pub fn empty() -> WindowHints
pub fn empty() -> WindowHintsReturns an empty set of flags.
pub fn all() -> WindowHints
pub fn all() -> WindowHintsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<WindowHints>
pub fn from_bits(bits: u32) -> Option<WindowHints>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> WindowHints
pub fn from_bits_truncate(bits: u32) -> WindowHintsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: WindowHints) -> bool
pub fn intersects(&self, other: WindowHints) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: WindowHints) -> bool
pub fn contains(&self, other: WindowHints) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: WindowHints)
pub fn insert(&mut self, other: WindowHints)Inserts the specified flags in-place.
pub fn remove(&mut self, other: WindowHints)
pub fn remove(&mut self, other: WindowHints)Removes the specified flags in-place.
pub fn toggle(&mut self, other: WindowHints)
pub fn toggle(&mut self, other: WindowHints)Toggles the specified flags in-place.
pub fn set(&mut self, other: WindowHints, value: bool)
pub fn set(&mut self, other: WindowHints, value: bool)Inserts or removes the specified flags depending on the passed value.