Struct gdk_pixbuf::Object [−][src]
pub struct Object(_, _);
The base class in the object hierarchy.
Methods
impl Object[src]
impl ObjectTrait Implementations
impl Clone for Object[src]
impl Clone for Objectfn clone(&self) -> Object[src]
fn clone(&self) -> ObjectReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Ord for Object[src]
impl Ord for Objectfn cmp(&self, other: &Object) -> Ordering[src]
fn cmp(&self, other: &Object) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Eq for Object[src]
impl Eq for Objectimpl StaticType for Object[src]
impl StaticType for Objectfn static_type() -> Type[src]
fn static_type() -> TypeReturns the type identifier of Self.
impl Hash for Object[src]
impl Hash for Objectfn hash<__H>(&self, state: &mut __H) where
__H: Hasher, [src]
fn hash<__H>(&self, state: &mut __H) where
__H: Hasher, Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl<T> PartialEq<T> for Object where
T: IsA<Object>, [src]
impl<T> PartialEq<T> for Object where
T: IsA<Object>, fn eq(&self, other: &T) -> bool[src]
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Debug for Object[src]
impl Debug for Objectfn fmt(&self, f: &mut Formatter) -> Result<(), Error>[src]
fn fmt(&self, f: &mut Formatter) -> Result<(), Error>Formats the value using the given formatter. Read more
impl<T> PartialOrd<T> for Object where
T: IsA<Object>, [src]
impl<T> PartialOrd<T> for Object where
T: IsA<Object>, fn partial_cmp(&self, other: &T) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl IsA<Object> for Binding[src]
impl IsA<Object> for Bindingimpl IsA<Object> for TlsCertificate
impl IsA<Object> for TlsCertificateimpl IsA<Object> for PollableOutputStream
impl IsA<Object> for PollableOutputStreamimpl IsA<Object> for ZlibDecompressor
impl IsA<Object> for ZlibDecompressorimpl IsA<Object> for ProxyResolver
impl IsA<Object> for ProxyResolverimpl IsA<Object> for Converter
impl IsA<Object> for Converterimpl IsA<Object> for MountOperation
impl IsA<Object> for MountOperationimpl IsA<Object> for OutputStream
impl IsA<Object> for OutputStreamimpl IsA<Object> for EmblemedIcon
impl IsA<Object> for EmblemedIconimpl IsA<Object> for Socket
impl IsA<Object> for Socketimpl IsA<Object> for Emblem
impl IsA<Object> for Emblemimpl IsA<Object> for ThreadedSocketService
impl IsA<Object> for ThreadedSocketServiceimpl IsA<Object> for DataInputStream
impl IsA<Object> for DataInputStreamimpl IsA<Object> for MenuLinkIter
impl IsA<Object> for MenuLinkIterimpl IsA<Object> for TlsDatabase
impl IsA<Object> for TlsDatabaseimpl IsA<Object> for Seekable
impl IsA<Object> for Seekableimpl IsA<Object> for TlsClientConnection
impl IsA<Object> for TlsClientConnectionimpl IsA<Object> for MenuModel
impl IsA<Object> for MenuModelimpl IsA<Object> for NetworkAddress
impl IsA<Object> for NetworkAddressimpl IsA<Object> for FileInputStream
impl IsA<Object> for FileInputStreamimpl IsA<Object> for MemoryInputStream
impl IsA<Object> for MemoryInputStreamimpl IsA<Object> for TlsServerConnection
impl IsA<Object> for TlsServerConnectionimpl IsA<Object> for FileOutputStream
impl IsA<Object> for FileOutputStreamimpl IsA<Object> for SettingsBackend
impl IsA<Object> for SettingsBackendimpl IsA<Object> for NetworkMonitor
impl IsA<Object> for NetworkMonitorimpl IsA<Object> for TlsPassword
impl IsA<Object> for TlsPasswordimpl IsA<Object> for Application
impl IsA<Object> for Applicationimpl IsA<Object> for SocketAddress
impl IsA<Object> for SocketAddressimpl IsA<Object> for ApplicationCommandLine
impl IsA<Object> for ApplicationCommandLineimpl IsA<Object> for DesktopAppInfo
impl IsA<Object> for DesktopAppInfoimpl IsA<Object> for FilenameCompleter
impl IsA<Object> for FilenameCompleterimpl IsA<Object> for FilterInputStream
impl IsA<Object> for FilterInputStreamimpl IsA<Object> for Action
impl IsA<Object> for Actionimpl IsA<Object> for ConverterOutputStream
impl IsA<Object> for ConverterOutputStreamimpl IsA<Object> for SocketConnection
impl IsA<Object> for SocketConnectionimpl IsA<Object> for FileInfo
impl IsA<Object> for FileInfoimpl IsA<Object> for SimpleActionGroup
impl IsA<Object> for SimpleActionGroupimpl IsA<Object> for UnixSocketAddress
impl IsA<Object> for UnixSocketAddressimpl IsA<Object> for Cancellable
impl IsA<Object> for Cancellableimpl IsA<Object> for ActionGroup
impl IsA<Object> for ActionGroupimpl IsA<Object> for InetAddress
impl IsA<Object> for InetAddressimpl IsA<Object> for TlsInteraction
impl IsA<Object> for TlsInteractionimpl IsA<Object> for TlsFileDatabase
impl IsA<Object> for TlsFileDatabaseimpl IsA<Object> for SocketAddressEnumerator
impl IsA<Object> for SocketAddressEnumeratorimpl IsA<Object> for DataOutputStream
impl IsA<Object> for DataOutputStreamimpl IsA<Object> for Credentials
impl IsA<Object> for Credentialsimpl IsA<Object> for NetworkService
impl IsA<Object> for NetworkServiceimpl IsA<Object> for SocketClient
impl IsA<Object> for SocketClientimpl IsA<Object> for SocketService
impl IsA<Object> for SocketServiceimpl IsA<Object> for Icon
impl IsA<Object> for Iconimpl IsA<Object> for CharsetConverter
impl IsA<Object> for CharsetConverterimpl IsA<Object> for MemoryOutputStream
impl IsA<Object> for MemoryOutputStreamimpl IsA<Object> for ActionMap
impl IsA<Object> for ActionMapimpl IsA<Object> for SimpleAction
impl IsA<Object> for SimpleActionimpl IsA<Object> for TcpConnection
impl IsA<Object> for TcpConnectionimpl IsA<Object> for Volume
impl IsA<Object> for Volumeimpl IsA<Object> for BufferedOutputStream
impl IsA<Object> for BufferedOutputStreamimpl IsA<Object> for Menu
impl IsA<Object> for Menuimpl IsA<Object> for VolumeMonitor
impl IsA<Object> for VolumeMonitorimpl IsA<Object> for IOStream
impl IsA<Object> for IOStreamimpl IsA<Object> for ConverterInputStream
impl IsA<Object> for ConverterInputStreamimpl IsA<Object> for Drive
impl IsA<Object> for Driveimpl IsA<Object> for Vfs
impl IsA<Object> for Vfsimpl IsA<Object> for SocketListener
impl IsA<Object> for SocketListenerimpl IsA<Object> for MenuAttributeIter
impl IsA<Object> for MenuAttributeIterimpl IsA<Object> for FileIcon
impl IsA<Object> for FileIconimpl IsA<Object> for PollableInputStream
impl IsA<Object> for PollableInputStreamimpl IsA<Object> for Resolver
impl IsA<Object> for Resolverimpl IsA<Object> for ThemedIcon
impl IsA<Object> for ThemedIconimpl IsA<Object> for InputStream
impl IsA<Object> for InputStreamimpl IsA<Object> for AppLaunchContext
impl IsA<Object> for AppLaunchContextimpl IsA<Object> for SocketConnectable
impl IsA<Object> for SocketConnectableimpl IsA<Object> for ZlibCompressor
impl IsA<Object> for ZlibCompressorimpl IsA<Object> for Permission
impl IsA<Object> for Permissionimpl IsA<Object> for FileIOStream
impl IsA<Object> for FileIOStreamimpl IsA<Object> for Proxy
impl IsA<Object> for Proxyimpl IsA<Object> for FilterOutputStream
impl IsA<Object> for FilterOutputStreamimpl IsA<Object> for Mount
impl IsA<Object> for Mountimpl IsA<Object> for SimplePermission
impl IsA<Object> for SimplePermissionimpl IsA<Object> for File
impl IsA<Object> for Fileimpl IsA<Object> for FileMonitor
impl IsA<Object> for FileMonitorimpl IsA<Object> for TlsConnection
impl IsA<Object> for TlsConnectionimpl IsA<Object> for InetAddressMask
impl IsA<Object> for InetAddressMaskimpl IsA<Object> for InetSocketAddress
impl IsA<Object> for InetSocketAddressimpl IsA<Object> for ProxyAddress
impl IsA<Object> for ProxyAddressimpl IsA<Object> for LoadableIcon
impl IsA<Object> for LoadableIconimpl IsA<Object> for MenuItem
impl IsA<Object> for MenuItemimpl IsA<Object> for AppInfo
impl IsA<Object> for AppInfoimpl IsA<Object> for Settings
impl IsA<Object> for Settingsimpl IsA<Object> for BufferedInputStream
impl IsA<Object> for BufferedInputStreamimpl IsA<Object> for Pixbuf
impl IsA<Object> for Pixbufimpl IsA<Object> for PixbufLoader
impl IsA<Object> for PixbufLoaderimpl IsA<Object> for PixbufSimpleAnim
impl IsA<Object> for PixbufSimpleAnimimpl IsA<Object> for PixbufAnimationIter
impl IsA<Object> for PixbufAnimationIterimpl IsA<Object> for PixbufAnimation
impl IsA<Object> for PixbufAnimation