Struct gdk_pixbuf::Pixbuf [−]
pub struct Pixbuf(_, _);
Methods
impl Pixbuf[src]
impl Pixbufpub fn new(
colorspace: Colorspace,
has_alpha: bool,
bits_per_sample: i32,
width: i32,
height: i32
) -> Pixbuf[src]
pub fn new(
colorspace: Colorspace,
has_alpha: bool,
bits_per_sample: i32,
width: i32,
height: i32
) -> Pixbufpub fn new_from_inline(data: &[u8], copy_pixels: bool) -> Result<Pixbuf, Error>[src]
pub fn new_from_inline(data: &[u8], copy_pixels: bool) -> Result<Pixbuf, Error>pub fn new_from_resource(resource_path: &str) -> Result<Pixbuf, Error>[src]
pub fn new_from_resource(resource_path: &str) -> Result<Pixbuf, Error>pub fn new_from_resource_at_scale(
resource_path: &str,
width: i32,
height: i32,
preserve_aspect_ratio: bool
) -> Result<Pixbuf, Error>[src]
pub fn new_from_resource_at_scale(
resource_path: &str,
width: i32,
height: i32,
preserve_aspect_ratio: bool
) -> Result<Pixbuf, Error>pub fn new_from_stream<'a, P: IsA<InputStream>, Q: Into<Option<&'a Cancellable>>>(
stream: &P,
cancellable: Q
) -> Result<Pixbuf, Error>[src]
pub fn new_from_stream<'a, P: IsA<InputStream>, Q: Into<Option<&'a Cancellable>>>(
stream: &P,
cancellable: Q
) -> Result<Pixbuf, Error>pub fn new_from_stream_at_scale<'a, P: IsA<InputStream>, Q: Into<Option<&'a Cancellable>>>(
stream: &P,
width: i32,
height: i32,
preserve_aspect_ratio: bool,
cancellable: Q
) -> Result<Pixbuf, Error>[src]
pub fn new_from_stream_at_scale<'a, P: IsA<InputStream>, Q: Into<Option<&'a Cancellable>>>(
stream: &P,
width: i32,
height: i32,
preserve_aspect_ratio: bool,
cancellable: Q
) -> Result<Pixbuf, Error>pub fn new_from_xpm_data(data: &[&str]) -> Pixbuf[src]
pub fn new_from_xpm_data(data: &[&str]) -> Pixbufpub fn get_formats() -> Vec<PixbufFormat>[src]
pub fn get_formats() -> Vec<PixbufFormat>impl Pixbuf[src]
impl Pixbufpub fn new_from_vec(
vec: Vec<u8>,
colorspace: Colorspace,
has_alpha: bool,
bits_per_sample: i32,
width: i32,
height: i32,
row_stride: i32
) -> Pixbuf[src]
pub fn new_from_vec(
vec: Vec<u8>,
colorspace: Colorspace,
has_alpha: bool,
bits_per_sample: i32,
width: i32,
height: i32,
row_stride: i32
) -> Pixbufpub fn new_from_file<T: AsRef<Path>>(filename: T) -> Result<Pixbuf, Error>[src]
pub fn new_from_file<T: AsRef<Path>>(filename: T) -> Result<Pixbuf, Error>pub fn new_from_file_at_size<T: AsRef<Path>>(
filename: T,
width: i32,
height: i32
) -> Result<Pixbuf, Error>[src]
pub fn new_from_file_at_size<T: AsRef<Path>>(
filename: T,
width: i32,
height: i32
) -> Result<Pixbuf, Error>pub fn new_from_file_at_scale<T: AsRef<Path>>(
filename: T,
width: i32,
height: i32,
preserve_aspect_ratio: bool
) -> Result<Pixbuf, Error>[src]
pub fn new_from_file_at_scale<T: AsRef<Path>>(
filename: T,
width: i32,
height: i32,
preserve_aspect_ratio: bool
) -> Result<Pixbuf, Error>pub fn new_from_stream_async<'a, P: IsA<InputStream>, Q: Into<Option<&'a Cancellable>>, R: FnOnce(Result<Pixbuf, Error>) + Send + 'static>(
stream: &P,
cancellable: Q,
callback: R
)[src]
pub fn new_from_stream_async<'a, P: IsA<InputStream>, Q: Into<Option<&'a Cancellable>>, R: FnOnce(Result<Pixbuf, Error>) + Send + 'static>(
stream: &P,
cancellable: Q,
callback: R
)pub fn new_from_stream_at_scale_async<'a, P: IsA<InputStream>, Q: Into<Option<&'a Cancellable>>, R: FnOnce(Result<Pixbuf, Error>) + Send + 'static>(
stream: &P,
width: i32,
height: i32,
preserve_aspect_ratio: bool,
cancellable: Q,
callback: R
)[src]
pub fn new_from_stream_at_scale_async<'a, P: IsA<InputStream>, Q: Into<Option<&'a Cancellable>>, R: FnOnce(Result<Pixbuf, Error>) + Send + 'static>(
stream: &P,
width: i32,
height: i32,
preserve_aspect_ratio: bool,
cancellable: Q,
callback: R
)pub unsafe fn get_pixels(&self) -> &mut [u8][src]
pub unsafe fn get_pixels(&self) -> &mut [u8]pub fn put_pixel(&self, x: i32, y: i32, red: u8, green: u8, blue: u8, alpha: u8)[src]
pub fn put_pixel(&self, x: i32, y: i32, red: u8, green: u8, blue: u8, alpha: u8)pub fn get_file_info<T: AsRef<Path>>(
filename: T
) -> Option<(PixbufFormat, i32, i32)>[src]
pub fn get_file_info<T: AsRef<Path>>(
filename: T
) -> Option<(PixbufFormat, i32, i32)>pub fn save_to_bufferv(
&self,
type_: &str,
options: &[(&str, &str)]
) -> Result<Vec<u8>, Error>[src]
pub fn save_to_bufferv(
&self,
type_: &str,
options: &[(&str, &str)]
) -> Result<Vec<u8>, Error>pub fn savev<T: AsRef<Path>>(
&self,
filename: T,
type_: &str,
options: &[(&str, &str)]
) -> Result<(), Error>[src]
pub fn savev<T: AsRef<Path>>(
&self,
filename: T,
type_: &str,
options: &[(&str, &str)]
) -> Result<(), Error>Trait Implementations
impl Clone for Pixbuf
impl Clone for Pixbuffn clone(&self) -> Pixbuf
fn clone(&self) -> PixbufReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Pixbuf
impl Hash for Pixbuffn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Pixbuf
impl Ord for Pixbuffn cmp(&self, other: &Pixbuf) -> Ordering
fn cmp(&self, other: &Pixbuf) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Pixbuf
impl StaticType for Pixbuffn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Pixbuf
impl<T: IsA<Object>> PartialEq<T> for Pixbuffn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Pixbuf
impl Eq for Pixbufimpl<T: IsA<Object>> PartialOrd<T> for Pixbuf
impl<T: IsA<Object>> PartialOrd<T> for Pixbuffn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Pixbuf
impl Debug for Pixbufimpl IsA<Icon> for Pixbuf
impl IsA<Icon> for Pixbufimpl IsA<LoadableIcon> for Pixbuf
impl IsA<LoadableIcon> for Pixbufimpl IsA<Object> for Pixbuf
impl IsA<Object> for Pixbuf