Struct gdk_pixbuf::PixbufAnimation [−]
pub struct PixbufAnimation(_, _);
Methods
impl PixbufAnimation[src]
impl PixbufAnimationpub fn new_from_file<T: AsRef<Path>>(file: T) -> Result<PixbufAnimation, Error>[src]
pub fn new_from_file<T: AsRef<Path>>(file: T) -> Result<PixbufAnimation, Error>pub fn new_from_resource(resource_path: &str) -> Result<PixbufAnimation, Error>[src]
pub fn new_from_resource(resource_path: &str) -> Result<PixbufAnimation, Error>Trait Implementations
impl IsA<PixbufAnimation> for PixbufSimpleAnim
impl IsA<PixbufAnimation> for PixbufSimpleAnimimpl Clone for PixbufAnimation
impl Clone for PixbufAnimationfn clone(&self) -> PixbufAnimation
fn clone(&self) -> PixbufAnimationReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for PixbufAnimation
impl Hash for PixbufAnimationfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for PixbufAnimation
impl Ord for PixbufAnimationfn cmp(&self, other: &PixbufAnimation) -> Ordering
fn cmp(&self, other: &PixbufAnimation) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for PixbufAnimation
impl StaticType for PixbufAnimationfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for PixbufAnimation
impl<T: IsA<Object>> PartialEq<T> for PixbufAnimationfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for PixbufAnimation
impl Eq for PixbufAnimationimpl<T: IsA<Object>> PartialOrd<T> for PixbufAnimation
impl<T: IsA<Object>> PartialOrd<T> for PixbufAnimationfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for PixbufAnimation
impl Debug for PixbufAnimationimpl IsA<Object> for PixbufAnimation
impl IsA<Object> for PixbufAnimationAuto Trait Implementations
impl !Send for PixbufAnimation
impl !Send for PixbufAnimationimpl !Sync for PixbufAnimation
impl !Sync for PixbufAnimation