Struct gdk_pixbuf::PixbufAnimationIter [−]
pub struct PixbufAnimationIter(_, _);
Methods
impl PixbufAnimationIter[src]
impl PixbufAnimationIterpub fn advance(&self, start_time: TimeVal) -> bool[src]
pub fn advance(&self, start_time: TimeVal) -> boolpub fn get_pixbuf(&self) -> Pixbuf[src]
pub fn get_pixbuf(&self) -> Pixbufpub fn get_delay_time(&self) -> i32[src]
pub fn get_delay_time(&self) -> i32pub fn on_currently_loading_frame(&self) -> bool[src]
pub fn on_currently_loading_frame(&self) -> boolTrait Implementations
impl Clone for PixbufAnimationIter
impl Clone for PixbufAnimationIterfn clone(&self) -> PixbufAnimationIter
fn clone(&self) -> PixbufAnimationIterReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for PixbufAnimationIter
impl Hash for PixbufAnimationIterfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for PixbufAnimationIter
impl Ord for PixbufAnimationIterfn cmp(&self, other: &PixbufAnimationIter) -> Ordering
fn cmp(&self, other: &PixbufAnimationIter) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for PixbufAnimationIter
impl StaticType for PixbufAnimationIterfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for PixbufAnimationIter
impl<T: IsA<Object>> PartialEq<T> for PixbufAnimationIterfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for PixbufAnimationIter
impl Eq for PixbufAnimationIterimpl<T: IsA<Object>> PartialOrd<T> for PixbufAnimationIter
impl<T: IsA<Object>> PartialOrd<T> for PixbufAnimationIterfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for PixbufAnimationIter
impl Debug for PixbufAnimationIterimpl IsA<Object> for PixbufAnimationIter
impl IsA<Object> for PixbufAnimationIterAuto Trait Implementations
impl !Send for PixbufAnimationIter
impl !Send for PixbufAnimationIterimpl !Sync for PixbufAnimationIter
impl !Sync for PixbufAnimationIter