Struct gdk_pixbuf::PixbufLoader [−]
pub struct PixbufLoader(_, _);
Methods
impl PixbufLoader[src]
impl PixbufLoaderpub fn new() -> PixbufLoader[src]
pub fn new() -> PixbufLoaderpub fn new_with_mime_type(mime_type: &str) -> Result<PixbufLoader, Error>[src]
pub fn new_with_mime_type(mime_type: &str) -> Result<PixbufLoader, Error>pub fn new_with_type(image_type: &str) -> Result<PixbufLoader, Error>[src]
pub fn new_with_type(image_type: &str) -> Result<PixbufLoader, Error>Trait Implementations
impl Clone for PixbufLoader
impl Clone for PixbufLoaderfn clone(&self) -> PixbufLoader
fn clone(&self) -> PixbufLoaderReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for PixbufLoader
impl Hash for PixbufLoaderfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for PixbufLoader
impl Ord for PixbufLoaderfn cmp(&self, other: &PixbufLoader) -> Ordering
fn cmp(&self, other: &PixbufLoader) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for PixbufLoader
impl StaticType for PixbufLoaderfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for PixbufLoader
impl<T: IsA<Object>> PartialEq<T> for PixbufLoaderfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for PixbufLoader
impl Eq for PixbufLoaderimpl<T: IsA<Object>> PartialOrd<T> for PixbufLoader
impl<T: IsA<Object>> PartialOrd<T> for PixbufLoaderfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for PixbufLoader
impl Debug for PixbufLoaderimpl IsA<Object> for PixbufLoader
impl IsA<Object> for PixbufLoaderimpl Default for PixbufLoader[src]
impl Default for PixbufLoaderAuto Trait Implementations
impl !Send for PixbufLoader
impl !Send for PixbufLoaderimpl !Sync for PixbufLoader
impl !Sync for PixbufLoader