Struct gio::AppInfo [−]
pub struct AppInfo(_, _);
Methods
impl AppInfo[src]
impl AppInfopub fn create_from_commandline<'a, P: AsRef<OsStr>, Q: Into<Option<&'a str>>>(
commandline: P,
application_name: Q,
flags: AppInfoCreateFlags
) -> Result<AppInfo, Error>[src]
pub fn create_from_commandline<'a, P: AsRef<OsStr>, Q: Into<Option<&'a str>>>(
commandline: P,
application_name: Q,
flags: AppInfoCreateFlags
) -> Result<AppInfo, Error>pub fn get_all() -> Vec<AppInfo>[src]
pub fn get_all() -> Vec<AppInfo>pub fn get_all_for_type(content_type: &str) -> Vec<AppInfo>[src]
pub fn get_all_for_type(content_type: &str) -> Vec<AppInfo>pub fn get_default_for_type(
content_type: &str,
must_support_uris: bool
) -> Option<AppInfo>[src]
pub fn get_default_for_type(
content_type: &str,
must_support_uris: bool
) -> Option<AppInfo>pub fn get_default_for_uri_scheme(uri_scheme: &str) -> Option<AppInfo>[src]
pub fn get_default_for_uri_scheme(uri_scheme: &str) -> Option<AppInfo>pub fn get_fallback_for_type(content_type: &str) -> Vec<AppInfo>[src]
pub fn get_fallback_for_type(content_type: &str) -> Vec<AppInfo>pub fn get_recommended_for_type(content_type: &str) -> Vec<AppInfo>[src]
pub fn get_recommended_for_type(content_type: &str) -> Vec<AppInfo>pub fn launch_default_for_uri<'a, P: Into<Option<&'a AppLaunchContext>>>(
uri: &str,
context: P
) -> Result<(), Error>[src]
pub fn launch_default_for_uri<'a, P: Into<Option<&'a AppLaunchContext>>>(
uri: &str,
context: P
) -> Result<(), Error>pub fn reset_type_associations(content_type: &str)[src]
pub fn reset_type_associations(content_type: &str)Trait Implementations
impl Clone for AppInfo
impl Clone for AppInfofn clone(&self) -> AppInfo
fn clone(&self) -> AppInfoReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for AppInfo
impl Hash for AppInfofn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for AppInfo
impl Ord for AppInfofn cmp(&self, other: &AppInfo) -> Ordering
fn cmp(&self, other: &AppInfo) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for AppInfo
impl StaticType for AppInfofn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for AppInfo
impl<T: IsA<Object>> PartialEq<T> for AppInfofn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for AppInfo
impl Eq for AppInfoimpl<T: IsA<Object>> PartialOrd<T> for AppInfo
impl<T: IsA<Object>> PartialOrd<T> for AppInfofn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for AppInfo
impl Debug for AppInfoimpl IsA<Object> for AppInfo
impl IsA<Object> for AppInfoimpl IsA<AppInfo> for DesktopAppInfo
impl IsA<AppInfo> for DesktopAppInfo