Struct gio::BufferedInputStream [−]
pub struct BufferedInputStream(_, _);
Methods
impl BufferedInputStream[src]
impl BufferedInputStreampub fn new<P: IsA<InputStream>>(base_stream: &P) -> BufferedInputStream[src]
pub fn new<P: IsA<InputStream>>(base_stream: &P) -> BufferedInputStreampub fn new_sized<P: IsA<InputStream>>(
base_stream: &P,
size: usize
) -> BufferedInputStream[src]
pub fn new_sized<P: IsA<InputStream>>(
base_stream: &P,
size: usize
) -> BufferedInputStreamTrait Implementations
impl Clone for BufferedInputStream
impl Clone for BufferedInputStreamfn clone(&self) -> BufferedInputStream
fn clone(&self) -> BufferedInputStreamReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for BufferedInputStream
impl Hash for BufferedInputStreamfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for BufferedInputStream
impl Ord for BufferedInputStreamfn cmp(&self, other: &BufferedInputStream) -> Ordering
fn cmp(&self, other: &BufferedInputStream) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for BufferedInputStream
impl StaticType for BufferedInputStreamfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for BufferedInputStream
impl<T: IsA<Object>> PartialEq<T> for BufferedInputStreamfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for BufferedInputStream
impl Eq for BufferedInputStreamimpl<T: IsA<Object>> PartialOrd<T> for BufferedInputStream
impl<T: IsA<Object>> PartialOrd<T> for BufferedInputStreamfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for BufferedInputStream
impl Debug for BufferedInputStreamimpl IsA<FilterInputStream> for BufferedInputStream
impl IsA<FilterInputStream> for BufferedInputStreamimpl IsA<InputStream> for BufferedInputStream
impl IsA<InputStream> for BufferedInputStreamimpl IsA<Seekable> for BufferedInputStream
impl IsA<Seekable> for BufferedInputStreamimpl IsA<Object> for BufferedInputStream
impl IsA<Object> for BufferedInputStreamimpl IsA<BufferedInputStream> for DataInputStream
impl IsA<BufferedInputStream> for DataInputStreamAuto Trait Implementations
impl !Send for BufferedInputStream
impl !Send for BufferedInputStreamimpl !Sync for BufferedInputStream
impl !Sync for BufferedInputStream