Struct gio::BufferedOutputStream [−]
pub struct BufferedOutputStream(_, _);
Methods
impl BufferedOutputStream[src]
impl BufferedOutputStreampub fn new<P: IsA<OutputStream>>(base_stream: &P) -> BufferedOutputStream[src]
pub fn new<P: IsA<OutputStream>>(base_stream: &P) -> BufferedOutputStreampub fn new_sized<P: IsA<OutputStream>>(
base_stream: &P,
size: usize
) -> BufferedOutputStream[src]
pub fn new_sized<P: IsA<OutputStream>>(
base_stream: &P,
size: usize
) -> BufferedOutputStreamTrait Implementations
impl Clone for BufferedOutputStream
impl Clone for BufferedOutputStreamfn clone(&self) -> BufferedOutputStream
fn clone(&self) -> BufferedOutputStreamReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for BufferedOutputStream
impl Hash for BufferedOutputStreamfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for BufferedOutputStream
impl Ord for BufferedOutputStreamfn cmp(&self, other: &BufferedOutputStream) -> Ordering
fn cmp(&self, other: &BufferedOutputStream) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for BufferedOutputStream
impl StaticType for BufferedOutputStreamfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for BufferedOutputStream
impl<T: IsA<Object>> PartialEq<T> for BufferedOutputStreamfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for BufferedOutputStream
impl Eq for BufferedOutputStreamimpl<T: IsA<Object>> PartialOrd<T> for BufferedOutputStream
impl<T: IsA<Object>> PartialOrd<T> for BufferedOutputStreamfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for BufferedOutputStream
impl Debug for BufferedOutputStreamimpl IsA<FilterOutputStream> for BufferedOutputStream
impl IsA<FilterOutputStream> for BufferedOutputStreamimpl IsA<OutputStream> for BufferedOutputStream
impl IsA<OutputStream> for BufferedOutputStreamimpl IsA<Seekable> for BufferedOutputStream
impl IsA<Seekable> for BufferedOutputStreamimpl IsA<Object> for BufferedOutputStream
impl IsA<Object> for BufferedOutputStreamAuto Trait Implementations
impl !Send for BufferedOutputStream
impl !Send for BufferedOutputStreamimpl !Sync for BufferedOutputStream
impl !Sync for BufferedOutputStream