Struct gio::Cancellable [−]
pub struct Cancellable(_, _);
Methods
impl Cancellable[src]
impl Cancellablepub fn new() -> Cancellable[src]
pub fn new() -> Cancellablepub fn cancel(&self)[src]
pub fn cancel(&self)pub fn disconnect(&self, handler_id: c_ulong)[src]
pub fn disconnect(&self, handler_id: c_ulong)pub fn get_fd(&self) -> i32[src]
pub fn get_fd(&self) -> i32pub fn is_cancelled(&self) -> bool[src]
pub fn is_cancelled(&self) -> boolpub fn pop_current(&self)[src]
pub fn pop_current(&self)pub fn push_current(&self)[src]
pub fn push_current(&self)pub fn release_fd(&self)[src]
pub fn release_fd(&self)pub fn set_error_if_cancelled(&self) -> Result<(), Error>[src]
pub fn set_error_if_cancelled(&self) -> Result<(), Error>pub fn get_current() -> Option<Cancellable>[src]
pub fn get_current() -> Option<Cancellable>pub fn connect_cancelled<F: Fn(&Cancellable) + Send + Sync + 'static>(
&self,
f: F
) -> SignalHandlerId[src]
pub fn connect_cancelled<F: Fn(&Cancellable) + Send + Sync + 'static>(
&self,
f: F
) -> SignalHandlerIdTrait Implementations
impl Clone for Cancellable
impl Clone for Cancellablefn clone(&self) -> Cancellable
fn clone(&self) -> CancellableReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Cancellable
impl Hash for Cancellablefn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Cancellable
impl Ord for Cancellablefn cmp(&self, other: &Cancellable) -> Ordering
fn cmp(&self, other: &Cancellable) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Cancellable
impl StaticType for Cancellablefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Cancellable
impl<T: IsA<Object>> PartialEq<T> for Cancellablefn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Cancellable
impl Eq for Cancellableimpl<T: IsA<Object>> PartialOrd<T> for Cancellable
impl<T: IsA<Object>> PartialOrd<T> for Cancellablefn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Cancellable
impl Debug for Cancellableimpl IsA<Object> for Cancellable
impl IsA<Object> for Cancellableimpl Default for Cancellable[src]
impl Default for Cancellableimpl Send for Cancellable[src]
impl Send for Cancellableimpl Sync for Cancellable[src]
impl Sync for Cancellable