Struct gio::ConverterInputStream [−]
pub struct ConverterInputStream(_, _);
Methods
impl ConverterInputStream[src]
impl ConverterInputStreampub fn new<P: IsA<InputStream>, Q: IsA<Converter>>(
base_stream: &P,
converter: &Q
) -> ConverterInputStream[src]
pub fn new<P: IsA<InputStream>, Q: IsA<Converter>>(
base_stream: &P,
converter: &Q
) -> ConverterInputStreamTrait Implementations
impl Clone for ConverterInputStream
impl Clone for ConverterInputStreamfn clone(&self) -> ConverterInputStream
fn clone(&self) -> ConverterInputStreamReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ConverterInputStream
impl Hash for ConverterInputStreamfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ConverterInputStream
impl Ord for ConverterInputStreamfn cmp(&self, other: &ConverterInputStream) -> Ordering
fn cmp(&self, other: &ConverterInputStream) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ConverterInputStream
impl StaticType for ConverterInputStreamfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ConverterInputStream
impl<T: IsA<Object>> PartialEq<T> for ConverterInputStreamfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ConverterInputStream
impl Eq for ConverterInputStreamimpl<T: IsA<Object>> PartialOrd<T> for ConverterInputStream
impl<T: IsA<Object>> PartialOrd<T> for ConverterInputStreamfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ConverterInputStream
impl Debug for ConverterInputStreamimpl IsA<FilterInputStream> for ConverterInputStream
impl IsA<FilterInputStream> for ConverterInputStreamimpl IsA<InputStream> for ConverterInputStream
impl IsA<InputStream> for ConverterInputStreamimpl IsA<PollableInputStream> for ConverterInputStream
impl IsA<PollableInputStream> for ConverterInputStreamimpl IsA<Object> for ConverterInputStream
impl IsA<Object> for ConverterInputStreamAuto Trait Implementations
impl !Send for ConverterInputStream
impl !Send for ConverterInputStreamimpl !Sync for ConverterInputStream
impl !Sync for ConverterInputStream