Struct gio::DataInputStream [−]
pub struct DataInputStream(_, _);
Methods
impl DataInputStream[src]
impl DataInputStreampub fn new<P: IsA<InputStream>>(base_stream: &P) -> DataInputStream[src]
pub fn new<P: IsA<InputStream>>(base_stream: &P) -> DataInputStreamTrait Implementations
impl Clone for DataInputStream
impl Clone for DataInputStreamfn clone(&self) -> DataInputStream
fn clone(&self) -> DataInputStreamReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for DataInputStream
impl Hash for DataInputStreamfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for DataInputStream
impl Ord for DataInputStreamfn cmp(&self, other: &DataInputStream) -> Ordering
fn cmp(&self, other: &DataInputStream) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for DataInputStream
impl StaticType for DataInputStreamfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for DataInputStream
impl<T: IsA<Object>> PartialEq<T> for DataInputStreamfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for DataInputStream
impl Eq for DataInputStreamimpl<T: IsA<Object>> PartialOrd<T> for DataInputStream
impl<T: IsA<Object>> PartialOrd<T> for DataInputStreamfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for DataInputStream
impl Debug for DataInputStreamimpl IsA<BufferedInputStream> for DataInputStream
impl IsA<BufferedInputStream> for DataInputStreamimpl IsA<FilterInputStream> for DataInputStream
impl IsA<FilterInputStream> for DataInputStreamimpl IsA<InputStream> for DataInputStream
impl IsA<InputStream> for DataInputStreamimpl IsA<Seekable> for DataInputStream
impl IsA<Seekable> for DataInputStreamimpl IsA<Object> for DataInputStream
impl IsA<Object> for DataInputStreamAuto Trait Implementations
impl !Send for DataInputStream
impl !Send for DataInputStreamimpl !Sync for DataInputStream
impl !Sync for DataInputStream