Struct gio::DesktopAppInfo [−]
pub struct DesktopAppInfo(_, _);
Methods
impl DesktopAppInfo[src]
impl DesktopAppInfoimpl DesktopAppInfo[src]
impl DesktopAppInfopub fn new(desktop_id: &str) -> DesktopAppInfo[src]
pub fn new(desktop_id: &str) -> DesktopAppInfopub fn new_from_filename<P: AsRef<Path>>(filename: P) -> DesktopAppInfo[src]
pub fn new_from_filename<P: AsRef<Path>>(filename: P) -> DesktopAppInfopub fn new_from_keyfile(key_file: &KeyFile) -> DesktopAppInfo[src]
pub fn new_from_keyfile(key_file: &KeyFile) -> DesktopAppInfopub fn set_desktop_env(desktop_env: &str)[src]
pub fn set_desktop_env(desktop_env: &str)Trait Implementations
impl Clone for DesktopAppInfo
impl Clone for DesktopAppInfofn clone(&self) -> DesktopAppInfo
fn clone(&self) -> DesktopAppInfoReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for DesktopAppInfo
impl Hash for DesktopAppInfofn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for DesktopAppInfo
impl Ord for DesktopAppInfofn cmp(&self, other: &DesktopAppInfo) -> Ordering
fn cmp(&self, other: &DesktopAppInfo) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for DesktopAppInfo
impl StaticType for DesktopAppInfofn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for DesktopAppInfo
impl<T: IsA<Object>> PartialEq<T> for DesktopAppInfofn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for DesktopAppInfo
impl Eq for DesktopAppInfoimpl<T: IsA<Object>> PartialOrd<T> for DesktopAppInfo
impl<T: IsA<Object>> PartialOrd<T> for DesktopAppInfofn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for DesktopAppInfo
impl Debug for DesktopAppInfoimpl IsA<AppInfo> for DesktopAppInfo
impl IsA<AppInfo> for DesktopAppInfoimpl IsA<Object> for DesktopAppInfo
impl IsA<Object> for DesktopAppInfoAuto Trait Implementations
impl !Send for DesktopAppInfo
impl !Send for DesktopAppInfoimpl !Sync for DesktopAppInfo
impl !Sync for DesktopAppInfo