Struct gio::DriveStartFlags [−]
pub struct DriveStartFlags { /* fields omitted */ }Methods
impl DriveStartFlags
impl DriveStartFlagspub const NONE: DriveStartFlags
NONE: DriveStartFlags = DriveStartFlags{bits: 0,}
pub fn empty() -> DriveStartFlags
pub fn empty() -> DriveStartFlagsReturns an empty set of flags.
pub fn all() -> DriveStartFlags
pub fn all() -> DriveStartFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<DriveStartFlags>
pub fn from_bits(bits: u32) -> Option<DriveStartFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> DriveStartFlags
pub fn from_bits_truncate(bits: u32) -> DriveStartFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: DriveStartFlags) -> bool
pub fn intersects(&self, other: DriveStartFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: DriveStartFlags) -> bool
pub fn contains(&self, other: DriveStartFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: DriveStartFlags)
pub fn insert(&mut self, other: DriveStartFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: DriveStartFlags)
pub fn remove(&mut self, other: DriveStartFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: DriveStartFlags)
pub fn toggle(&mut self, other: DriveStartFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: DriveStartFlags, value: bool)
pub fn set(&mut self, other: DriveStartFlags, value: bool)Inserts or removes the specified flags depending on the passed value.