Struct gio::Emblem [−]
pub struct Emblem(_, _);
Methods
impl Emblem[src]
impl Emblempub fn new<P: IsA<Icon>>(icon: &P) -> Emblem[src]
pub fn new<P: IsA<Icon>>(icon: &P) -> Emblempub fn new_with_origin<P: IsA<Icon>>(icon: &P, origin: EmblemOrigin) -> Emblem[src]
pub fn new_with_origin<P: IsA<Icon>>(icon: &P, origin: EmblemOrigin) -> EmblemTrait Implementations
impl Clone for Emblem
impl Clone for Emblemfn clone(&self) -> Emblem
fn clone(&self) -> EmblemReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Emblem
impl Hash for Emblemfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Emblem
impl Ord for Emblemfn cmp(&self, other: &Emblem) -> Ordering
fn cmp(&self, other: &Emblem) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Emblem
impl StaticType for Emblemfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Emblem
impl<T: IsA<Object>> PartialEq<T> for Emblemfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Emblem
impl Eq for Emblemimpl<T: IsA<Object>> PartialOrd<T> for Emblem
impl<T: IsA<Object>> PartialOrd<T> for Emblemfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Emblem
impl Debug for Emblemimpl IsA<Icon> for Emblem
impl IsA<Icon> for Emblemimpl IsA<Object> for Emblem
impl IsA<Object> for Emblem