Struct gio::EmblemedIcon [−]
pub struct EmblemedIcon(_, _);
Methods
impl EmblemedIcon[src]
impl EmblemedIconpub fn new<'a, P: IsA<Icon>, Q: Into<Option<&'a Emblem>>>(
icon: &P,
emblem: Q
) -> EmblemedIcon[src]
pub fn new<'a, P: IsA<Icon>, Q: Into<Option<&'a Emblem>>>(
icon: &P,
emblem: Q
) -> EmblemedIconTrait Implementations
impl Clone for EmblemedIcon
impl Clone for EmblemedIconfn clone(&self) -> EmblemedIcon
fn clone(&self) -> EmblemedIconReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for EmblemedIcon
impl Hash for EmblemedIconfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for EmblemedIcon
impl Ord for EmblemedIconfn cmp(&self, other: &EmblemedIcon) -> Ordering
fn cmp(&self, other: &EmblemedIcon) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for EmblemedIcon
impl StaticType for EmblemedIconfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for EmblemedIcon
impl<T: IsA<Object>> PartialEq<T> for EmblemedIconfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for EmblemedIcon
impl Eq for EmblemedIconimpl<T: IsA<Object>> PartialOrd<T> for EmblemedIcon
impl<T: IsA<Object>> PartialOrd<T> for EmblemedIconfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for EmblemedIcon
impl Debug for EmblemedIconimpl IsA<Icon> for EmblemedIcon
impl IsA<Icon> for EmblemedIconimpl IsA<Object> for EmblemedIcon
impl IsA<Object> for EmblemedIconAuto Trait Implementations
impl !Send for EmblemedIcon
impl !Send for EmblemedIconimpl !Sync for EmblemedIcon
impl !Sync for EmblemedIcon