Struct gio::File [−]
pub struct File(_, _);
Methods
impl File[src]
impl Filepub fn new_for_commandline_arg<P: AsRef<OsStr>>(arg: P) -> File[src]
pub fn new_for_commandline_arg<P: AsRef<OsStr>>(arg: P) -> Filepub fn new_for_commandline_arg_and_cwd<P: AsRef<OsStr>, Q: AsRef<Path>>(
arg: P,
cwd: Q
) -> File[src]
pub fn new_for_commandline_arg_and_cwd<P: AsRef<OsStr>, Q: AsRef<Path>>(
arg: P,
cwd: Q
) -> Filepub fn new_for_path<P: AsRef<Path>>(path: P) -> File[src]
pub fn new_for_path<P: AsRef<Path>>(path: P) -> Filepub fn new_for_uri(uri: &str) -> File[src]
pub fn new_for_uri(uri: &str) -> Filepub fn new_tmp<P: AsRef<Path>>(tmpl: P) -> Result<(File, FileIOStream), Error>[src]
pub fn new_tmp<P: AsRef<Path>>(tmpl: P) -> Result<(File, FileIOStream), Error>pub fn parse_name(parse_name: &str) -> Option<File>[src]
pub fn parse_name(parse_name: &str) -> Option<File>Trait Implementations
impl Clone for File
impl Clone for Filefn clone(&self) -> File
fn clone(&self) -> FileReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for File
impl Hash for Filefn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for File
impl Ord for Filefn cmp(&self, other: &File) -> Ordering
fn cmp(&self, other: &File) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for File
impl StaticType for Filefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for File
impl<T: IsA<Object>> PartialEq<T> for Filefn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for File
impl Eq for Fileimpl<T: IsA<Object>> PartialOrd<T> for File
impl<T: IsA<Object>> PartialOrd<T> for Filefn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for File
impl Debug for Fileimpl IsA<Object> for File
impl IsA<Object> for Fileimpl Send for File[src]
impl Send for Fileimpl Sync for File[src]
impl Sync for File