Struct gio::FileMonitorFlags [−]
pub struct FileMonitorFlags { /* fields omitted */ }Methods
impl FileMonitorFlags
impl FileMonitorFlagspub const NONE: FileMonitorFlags
NONE: FileMonitorFlags = FileMonitorFlags{bits: 0,}
pub const WATCH_MOUNTS: FileMonitorFlags
WATCH_MOUNTS: FileMonitorFlags = FileMonitorFlags{bits: 1,}
pub const SEND_MOVED: FileMonitorFlags
SEND_MOVED: FileMonitorFlags = FileMonitorFlags{bits: 2,}
pub const WATCH_HARD_LINKS: FileMonitorFlags
WATCH_HARD_LINKS: FileMonitorFlags = FileMonitorFlags{bits: 4,}
pub const WATCH_MOVES: FileMonitorFlags
WATCH_MOVES: FileMonitorFlags = FileMonitorFlags{bits: 8,}
pub fn empty() -> FileMonitorFlags
pub fn empty() -> FileMonitorFlagsReturns an empty set of flags.
pub fn all() -> FileMonitorFlags
pub fn all() -> FileMonitorFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<FileMonitorFlags>
pub fn from_bits(bits: u32) -> Option<FileMonitorFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> FileMonitorFlags
pub fn from_bits_truncate(bits: u32) -> FileMonitorFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: FileMonitorFlags) -> bool
pub fn intersects(&self, other: FileMonitorFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: FileMonitorFlags) -> bool
pub fn contains(&self, other: FileMonitorFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: FileMonitorFlags)
pub fn insert(&mut self, other: FileMonitorFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: FileMonitorFlags)
pub fn remove(&mut self, other: FileMonitorFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: FileMonitorFlags)
pub fn toggle(&mut self, other: FileMonitorFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: FileMonitorFlags, value: bool)
pub fn set(&mut self, other: FileMonitorFlags, value: bool)Inserts or removes the specified flags depending on the passed value.