Struct gio::FileQueryInfoFlags [−]
pub struct FileQueryInfoFlags { /* fields omitted */ }Methods
impl FileQueryInfoFlags
impl FileQueryInfoFlagspub const NONE: FileQueryInfoFlags
NONE: FileQueryInfoFlags = FileQueryInfoFlags{bits: 0,}
pub const NOFOLLOW_SYMLINKS: FileQueryInfoFlags
NOFOLLOW_SYMLINKS: FileQueryInfoFlags = FileQueryInfoFlags{bits: 1,}
pub fn empty() -> FileQueryInfoFlags
pub fn empty() -> FileQueryInfoFlagsReturns an empty set of flags.
pub fn all() -> FileQueryInfoFlags
pub fn all() -> FileQueryInfoFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<FileQueryInfoFlags>
pub fn from_bits(bits: u32) -> Option<FileQueryInfoFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> FileQueryInfoFlags
pub fn from_bits_truncate(bits: u32) -> FileQueryInfoFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: FileQueryInfoFlags) -> bool
pub fn intersects(&self, other: FileQueryInfoFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: FileQueryInfoFlags) -> bool
pub fn contains(&self, other: FileQueryInfoFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: FileQueryInfoFlags)
pub fn insert(&mut self, other: FileQueryInfoFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: FileQueryInfoFlags)
pub fn remove(&mut self, other: FileQueryInfoFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: FileQueryInfoFlags)
pub fn toggle(&mut self, other: FileQueryInfoFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: FileQueryInfoFlags, value: bool)
pub fn set(&mut self, other: FileQueryInfoFlags, value: bool)Inserts or removes the specified flags depending on the passed value.