Struct gio::MemoryInputStream [−]
pub struct MemoryInputStream(_, _);
Methods
impl MemoryInputStream[src]
impl MemoryInputStreampub fn new() -> MemoryInputStream[src]
pub fn new() -> MemoryInputStreampub fn new_from_bytes(bytes: &Bytes) -> MemoryInputStream[src]
pub fn new_from_bytes(bytes: &Bytes) -> MemoryInputStreamTrait Implementations
impl Clone for MemoryInputStream
impl Clone for MemoryInputStreamfn clone(&self) -> MemoryInputStream
fn clone(&self) -> MemoryInputStreamReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for MemoryInputStream
impl Hash for MemoryInputStreamfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for MemoryInputStream
impl Ord for MemoryInputStreamfn cmp(&self, other: &MemoryInputStream) -> Ordering
fn cmp(&self, other: &MemoryInputStream) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for MemoryInputStream
impl StaticType for MemoryInputStreamfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for MemoryInputStream
impl<T: IsA<Object>> PartialEq<T> for MemoryInputStreamfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for MemoryInputStream
impl Eq for MemoryInputStreamimpl<T: IsA<Object>> PartialOrd<T> for MemoryInputStream
impl<T: IsA<Object>> PartialOrd<T> for MemoryInputStreamfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for MemoryInputStream
impl Debug for MemoryInputStreamimpl IsA<InputStream> for MemoryInputStream
impl IsA<InputStream> for MemoryInputStreamimpl IsA<PollableInputStream> for MemoryInputStream
impl IsA<PollableInputStream> for MemoryInputStreamimpl IsA<Seekable> for MemoryInputStream
impl IsA<Seekable> for MemoryInputStreamimpl IsA<Object> for MemoryInputStream
impl IsA<Object> for MemoryInputStreamimpl Default for MemoryInputStream[src]
impl Default for MemoryInputStreamAuto Trait Implementations
impl !Send for MemoryInputStream
impl !Send for MemoryInputStreamimpl !Sync for MemoryInputStream
impl !Sync for MemoryInputStream