Struct gio::MemoryOutputStream [−]
pub struct MemoryOutputStream(_, _);
Methods
impl MemoryOutputStream[src]
impl MemoryOutputStreampub fn new_resizable() -> MemoryOutputStream[src]
pub fn new_resizable() -> MemoryOutputStreamTrait Implementations
impl Clone for MemoryOutputStream
impl Clone for MemoryOutputStreamfn clone(&self) -> MemoryOutputStream
fn clone(&self) -> MemoryOutputStreamReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for MemoryOutputStream
impl Hash for MemoryOutputStreamfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for MemoryOutputStream
impl Ord for MemoryOutputStreamfn cmp(&self, other: &MemoryOutputStream) -> Ordering
fn cmp(&self, other: &MemoryOutputStream) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for MemoryOutputStream
impl StaticType for MemoryOutputStreamfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for MemoryOutputStream
impl<T: IsA<Object>> PartialEq<T> for MemoryOutputStreamfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for MemoryOutputStream
impl Eq for MemoryOutputStreamimpl<T: IsA<Object>> PartialOrd<T> for MemoryOutputStream
impl<T: IsA<Object>> PartialOrd<T> for MemoryOutputStreamfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for MemoryOutputStream
impl Debug for MemoryOutputStreamimpl IsA<OutputStream> for MemoryOutputStream
impl IsA<OutputStream> for MemoryOutputStreamimpl IsA<PollableOutputStream> for MemoryOutputStream
impl IsA<PollableOutputStream> for MemoryOutputStreamimpl IsA<Seekable> for MemoryOutputStream
impl IsA<Seekable> for MemoryOutputStreamimpl IsA<Object> for MemoryOutputStream
impl IsA<Object> for MemoryOutputStreamAuto Trait Implementations
impl !Send for MemoryOutputStream
impl !Send for MemoryOutputStreamimpl !Sync for MemoryOutputStream
impl !Sync for MemoryOutputStream