Struct gio::MountMountFlags [−]
pub struct MountMountFlags { /* fields omitted */ }Methods
impl MountMountFlags
impl MountMountFlagspub const NONE: MountMountFlags
NONE: MountMountFlags = MountMountFlags{bits: 0,}
pub fn empty() -> MountMountFlags
pub fn empty() -> MountMountFlagsReturns an empty set of flags.
pub fn all() -> MountMountFlags
pub fn all() -> MountMountFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<MountMountFlags>
pub fn from_bits(bits: u32) -> Option<MountMountFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> MountMountFlags
pub fn from_bits_truncate(bits: u32) -> MountMountFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: MountMountFlags) -> bool
pub fn intersects(&self, other: MountMountFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: MountMountFlags) -> bool
pub fn contains(&self, other: MountMountFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: MountMountFlags)
pub fn insert(&mut self, other: MountMountFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: MountMountFlags)
pub fn remove(&mut self, other: MountMountFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: MountMountFlags)
pub fn toggle(&mut self, other: MountMountFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: MountMountFlags, value: bool)
pub fn set(&mut self, other: MountMountFlags, value: bool)Inserts or removes the specified flags depending on the passed value.