Struct gio::OutputStreamSpliceFlags [−]
pub struct OutputStreamSpliceFlags { /* fields omitted */ }Methods
impl OutputStreamSpliceFlags
impl OutputStreamSpliceFlagspub const NONE: OutputStreamSpliceFlags
NONE: OutputStreamSpliceFlags = OutputStreamSpliceFlags{bits: 0,}
pub const CLOSE_SOURCE: OutputStreamSpliceFlags
CLOSE_SOURCE: OutputStreamSpliceFlags = OutputStreamSpliceFlags{bits: 1,}
pub const CLOSE_TARGET: OutputStreamSpliceFlags
CLOSE_TARGET: OutputStreamSpliceFlags = OutputStreamSpliceFlags{bits: 2,}
pub fn empty() -> OutputStreamSpliceFlags
pub fn empty() -> OutputStreamSpliceFlagsReturns an empty set of flags.
pub fn all() -> OutputStreamSpliceFlags
pub fn all() -> OutputStreamSpliceFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<OutputStreamSpliceFlags>
pub fn from_bits(bits: u32) -> Option<OutputStreamSpliceFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> OutputStreamSpliceFlags
pub fn from_bits_truncate(bits: u32) -> OutputStreamSpliceFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: OutputStreamSpliceFlags) -> bool
pub fn intersects(&self, other: OutputStreamSpliceFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: OutputStreamSpliceFlags) -> bool
pub fn contains(&self, other: OutputStreamSpliceFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: OutputStreamSpliceFlags)
pub fn insert(&mut self, other: OutputStreamSpliceFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: OutputStreamSpliceFlags)
pub fn remove(&mut self, other: OutputStreamSpliceFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: OutputStreamSpliceFlags)
pub fn toggle(&mut self, other: OutputStreamSpliceFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: OutputStreamSpliceFlags, value: bool)
pub fn set(&mut self, other: OutputStreamSpliceFlags, value: bool)Inserts or removes the specified flags depending on the passed value.