Struct gio::ProxyAddress [−]
pub struct ProxyAddress(_, _);
Methods
impl ProxyAddress[src]
impl ProxyAddresspub fn new<'a, 'b, P: Into<Option<&'a str>>, Q: Into<Option<&'b str>>>(
inetaddr: &InetAddress,
port: u16,
protocol: &str,
dest_hostname: &str,
dest_port: u16,
username: P,
password: Q
) -> ProxyAddress[src]
pub fn new<'a, 'b, P: Into<Option<&'a str>>, Q: Into<Option<&'b str>>>(
inetaddr: &InetAddress,
port: u16,
protocol: &str,
dest_hostname: &str,
dest_port: u16,
username: P,
password: Q
) -> ProxyAddressTrait Implementations
impl Clone for ProxyAddress
impl Clone for ProxyAddressfn clone(&self) -> ProxyAddress
fn clone(&self) -> ProxyAddressReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ProxyAddress
impl Hash for ProxyAddressfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ProxyAddress
impl Ord for ProxyAddressfn cmp(&self, other: &ProxyAddress) -> Ordering
fn cmp(&self, other: &ProxyAddress) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ProxyAddress
impl StaticType for ProxyAddressfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ProxyAddress
impl<T: IsA<Object>> PartialEq<T> for ProxyAddressfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ProxyAddress
impl Eq for ProxyAddressimpl<T: IsA<Object>> PartialOrd<T> for ProxyAddress
impl<T: IsA<Object>> PartialOrd<T> for ProxyAddressfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ProxyAddress
impl Debug for ProxyAddressimpl IsA<InetSocketAddress> for ProxyAddress
impl IsA<InetSocketAddress> for ProxyAddressimpl IsA<SocketAddress> for ProxyAddress
impl IsA<SocketAddress> for ProxyAddressimpl IsA<SocketConnectable> for ProxyAddress
impl IsA<SocketConnectable> for ProxyAddressimpl IsA<Object> for ProxyAddress
impl IsA<Object> for ProxyAddressimpl Send for ProxyAddress[src]
impl Send for ProxyAddressimpl Sync for ProxyAddress[src]
impl Sync for ProxyAddress