Struct gio::Resource [−]
pub struct Resource(_);
Methods
impl Resource[src]
impl Resourceimpl Resource[src]
impl Resourcepub fn enumerate_children(
&self,
path: &str,
lookup_flags: ResourceLookupFlags
) -> Result<Vec<String>, Error>[src]
pub fn enumerate_children(
&self,
path: &str,
lookup_flags: ResourceLookupFlags
) -> Result<Vec<String>, Error>pub fn get_info(
&self,
path: &str,
lookup_flags: ResourceLookupFlags
) -> Result<(usize, u32), Error>[src]
pub fn get_info(
&self,
path: &str,
lookup_flags: ResourceLookupFlags
) -> Result<(usize, u32), Error>pub fn lookup_data(
&self,
path: &str,
lookup_flags: ResourceLookupFlags
) -> Result<Bytes, Error>[src]
pub fn lookup_data(
&self,
path: &str,
lookup_flags: ResourceLookupFlags
) -> Result<Bytes, Error>pub fn open_stream(
&self,
path: &str,
lookup_flags: ResourceLookupFlags
) -> Result<InputStream, Error>[src]
pub fn open_stream(
&self,
path: &str,
lookup_flags: ResourceLookupFlags
) -> Result<InputStream, Error>pub fn load<P: AsRef<Path>>(filename: P) -> Result<Resource, Error>[src]
pub fn load<P: AsRef<Path>>(filename: P) -> Result<Resource, Error>Trait Implementations
impl Debug for Resource[src]
impl Debug for Resourcefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for Resource[src]
impl PartialEq for Resourcefn eq(&self, other: &Resource) -> bool[src]
fn eq(&self, other: &Resource) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Resource) -> bool[src]
fn ne(&self, other: &Resource) -> boolThis method tests for !=.
impl Eq for Resource[src]
impl Eq for Resourceimpl PartialOrd for Resource[src]
impl PartialOrd for Resourcefn partial_cmp(&self, other: &Resource) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &Resource) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Resource) -> bool[src]
fn lt(&self, other: &Resource) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Resource) -> bool[src]
fn le(&self, other: &Resource) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Resource) -> bool[src]
fn gt(&self, other: &Resource) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Resource) -> bool[src]
fn ge(&self, other: &Resource) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for Resource[src]
impl Ord for Resourcefn cmp(&self, other: &Resource) -> Ordering[src]
fn cmp(&self, other: &Resource) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for Resource[src]
impl Hash for Resourcefn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for Resource
impl Clone for Resourcefn clone(&self) -> Resource
fn clone(&self) -> ResourceReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for Resource
impl StaticType for Resourcefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.