Struct gio::SettingsSchema [−]
pub struct SettingsSchema(_);
Methods
impl SettingsSchema[src]
impl SettingsSchemaTrait Implementations
impl Debug for SettingsSchema[src]
impl Debug for SettingsSchemafn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for SettingsSchema[src]
impl PartialEq for SettingsSchemafn eq(&self, other: &SettingsSchema) -> bool[src]
fn eq(&self, other: &SettingsSchema) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &SettingsSchema) -> bool[src]
fn ne(&self, other: &SettingsSchema) -> boolThis method tests for !=.
impl Eq for SettingsSchema[src]
impl Eq for SettingsSchemaimpl PartialOrd for SettingsSchema[src]
impl PartialOrd for SettingsSchemafn partial_cmp(&self, other: &SettingsSchema) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &SettingsSchema) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &SettingsSchema) -> bool[src]
fn lt(&self, other: &SettingsSchema) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &SettingsSchema) -> bool[src]
fn le(&self, other: &SettingsSchema) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &SettingsSchema) -> bool[src]
fn gt(&self, other: &SettingsSchema) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &SettingsSchema) -> bool[src]
fn ge(&self, other: &SettingsSchema) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for SettingsSchema[src]
impl Ord for SettingsSchemafn cmp(&self, other: &SettingsSchema) -> Ordering[src]
fn cmp(&self, other: &SettingsSchema) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for SettingsSchema[src]
impl Hash for SettingsSchemafn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for SettingsSchema
impl Clone for SettingsSchemafn clone(&self) -> SettingsSchema
fn clone(&self) -> SettingsSchemaReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for SettingsSchema
impl StaticType for SettingsSchemafn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.