Struct gio::SettingsSchemaSource [−]
pub struct SettingsSchemaSource(_);
Methods
impl SettingsSchemaSource[src]
impl SettingsSchemaSourcepub fn new_from_directory<'a, P: AsRef<Path>, Q: Into<Option<&'a SettingsSchemaSource>>>(
directory: P,
parent: Q,
trusted: bool
) -> Result<SettingsSchemaSource, Error>[src]
pub fn new_from_directory<'a, P: AsRef<Path>, Q: Into<Option<&'a SettingsSchemaSource>>>(
directory: P,
parent: Q,
trusted: bool
) -> Result<SettingsSchemaSource, Error>pub fn lookup(&self, schema_id: &str, recursive: bool) -> Option<SettingsSchema>[src]
pub fn lookup(&self, schema_id: &str, recursive: bool) -> Option<SettingsSchema>pub fn get_default() -> Option<SettingsSchemaSource>[src]
pub fn get_default() -> Option<SettingsSchemaSource>Trait Implementations
impl Debug for SettingsSchemaSource[src]
impl Debug for SettingsSchemaSourcefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for SettingsSchemaSource[src]
impl PartialEq for SettingsSchemaSourcefn eq(&self, other: &SettingsSchemaSource) -> bool[src]
fn eq(&self, other: &SettingsSchemaSource) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &SettingsSchemaSource) -> bool[src]
fn ne(&self, other: &SettingsSchemaSource) -> boolThis method tests for !=.
impl Eq for SettingsSchemaSource[src]
impl Eq for SettingsSchemaSourceimpl PartialOrd for SettingsSchemaSource[src]
impl PartialOrd for SettingsSchemaSourcefn partial_cmp(&self, other: &SettingsSchemaSource) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &SettingsSchemaSource) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &SettingsSchemaSource) -> bool[src]
fn lt(&self, other: &SettingsSchemaSource) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &SettingsSchemaSource) -> bool[src]
fn le(&self, other: &SettingsSchemaSource) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &SettingsSchemaSource) -> bool[src]
fn gt(&self, other: &SettingsSchemaSource) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &SettingsSchemaSource) -> bool[src]
fn ge(&self, other: &SettingsSchemaSource) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for SettingsSchemaSource[src]
impl Ord for SettingsSchemaSourcefn cmp(&self, other: &SettingsSchemaSource) -> Ordering[src]
fn cmp(&self, other: &SettingsSchemaSource) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for SettingsSchemaSource[src]
impl Hash for SettingsSchemaSourcefn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for SettingsSchemaSource
impl Clone for SettingsSchemaSourcefn clone(&self) -> SettingsSchemaSource
fn clone(&self) -> SettingsSchemaSourceReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for SettingsSchemaSource
impl StaticType for SettingsSchemaSourcefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.