Struct gio::ThemedIcon [−]
pub struct ThemedIcon(_, _);
Methods
impl ThemedIcon[src]
impl ThemedIconpub fn new(iconname: &str) -> ThemedIcon[src]
pub fn new(iconname: &str) -> ThemedIconpub fn new_from_names(iconnames: &[&str]) -> ThemedIcon[src]
pub fn new_from_names(iconnames: &[&str]) -> ThemedIconpub fn new_with_default_fallbacks(iconname: &str) -> ThemedIcon[src]
pub fn new_with_default_fallbacks(iconname: &str) -> ThemedIconTrait Implementations
impl Clone for ThemedIcon
impl Clone for ThemedIconfn clone(&self) -> ThemedIcon
fn clone(&self) -> ThemedIconReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ThemedIcon
impl Hash for ThemedIconfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ThemedIcon
impl Ord for ThemedIconfn cmp(&self, other: &ThemedIcon) -> Ordering
fn cmp(&self, other: &ThemedIcon) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ThemedIcon
impl StaticType for ThemedIconfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ThemedIcon
impl<T: IsA<Object>> PartialEq<T> for ThemedIconfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ThemedIcon
impl Eq for ThemedIconimpl<T: IsA<Object>> PartialOrd<T> for ThemedIcon
impl<T: IsA<Object>> PartialOrd<T> for ThemedIconfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ThemedIcon
impl Debug for ThemedIconimpl IsA<Icon> for ThemedIcon
impl IsA<Icon> for ThemedIconimpl IsA<Object> for ThemedIcon
impl IsA<Object> for ThemedIconAuto Trait Implementations
impl !Send for ThemedIcon
impl !Send for ThemedIconimpl !Sync for ThemedIcon
impl !Sync for ThemedIcon