Struct gio::TlsServerConnection [−]
pub struct TlsServerConnection(_, _);
Methods
impl TlsServerConnection[src]
impl TlsServerConnectionpub fn new<'a, P: IsA<IOStream>, Q: Into<Option<&'a TlsCertificate>>>(
base_io_stream: &P,
certificate: Q
) -> Result<TlsServerConnection, Error>[src]
pub fn new<'a, P: IsA<IOStream>, Q: Into<Option<&'a TlsCertificate>>>(
base_io_stream: &P,
certificate: Q
) -> Result<TlsServerConnection, Error>Trait Implementations
impl Clone for TlsServerConnection
impl Clone for TlsServerConnectionfn clone(&self) -> TlsServerConnection
fn clone(&self) -> TlsServerConnectionReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for TlsServerConnection
impl Hash for TlsServerConnectionfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for TlsServerConnection
impl Ord for TlsServerConnectionfn cmp(&self, other: &TlsServerConnection) -> Ordering
fn cmp(&self, other: &TlsServerConnection) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for TlsServerConnection
impl StaticType for TlsServerConnectionfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for TlsServerConnection
impl<T: IsA<Object>> PartialEq<T> for TlsServerConnectionfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for TlsServerConnection
impl Eq for TlsServerConnectionimpl<T: IsA<Object>> PartialOrd<T> for TlsServerConnection
impl<T: IsA<Object>> PartialOrd<T> for TlsServerConnectionfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for TlsServerConnection
impl Debug for TlsServerConnectionimpl IsA<TlsConnection> for TlsServerConnection
impl IsA<TlsConnection> for TlsServerConnectionimpl IsA<IOStream> for TlsServerConnection
impl IsA<IOStream> for TlsServerConnectionimpl IsA<Object> for TlsServerConnection
impl IsA<Object> for TlsServerConnectionAuto Trait Implementations
impl !Send for TlsServerConnection
impl !Send for TlsServerConnectionimpl !Sync for TlsServerConnection
impl !Sync for TlsServerConnection