Struct gio::UnixSocketAddress [−]
pub struct UnixSocketAddress(_, _);
Methods
impl UnixSocketAddress[src]
impl UnixSocketAddresspub fn new(path: &Path) -> UnixSocketAddress[src]
pub fn new(path: &Path) -> UnixSocketAddresspub fn new_with_type(address_type: UnixSocketAddressPath) -> Self[src]
pub fn new_with_type(address_type: UnixSocketAddressPath) -> Selfimpl UnixSocketAddress[src]
impl UnixSocketAddresspub fn abstract_names_supported() -> bool[src]
pub fn abstract_names_supported() -> boolTrait Implementations
impl Clone for UnixSocketAddress
impl Clone for UnixSocketAddressfn clone(&self) -> UnixSocketAddress
fn clone(&self) -> UnixSocketAddressReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for UnixSocketAddress
impl Hash for UnixSocketAddressfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for UnixSocketAddress
impl Ord for UnixSocketAddressfn cmp(&self, other: &UnixSocketAddress) -> Ordering
fn cmp(&self, other: &UnixSocketAddress) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for UnixSocketAddress
impl StaticType for UnixSocketAddressfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for UnixSocketAddress
impl<T: IsA<Object>> PartialEq<T> for UnixSocketAddressfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for UnixSocketAddress
impl Eq for UnixSocketAddressimpl<T: IsA<Object>> PartialOrd<T> for UnixSocketAddress
impl<T: IsA<Object>> PartialOrd<T> for UnixSocketAddressfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for UnixSocketAddress
impl Debug for UnixSocketAddressimpl IsA<SocketAddress> for UnixSocketAddress
impl IsA<SocketAddress> for UnixSocketAddressimpl IsA<SocketConnectable> for UnixSocketAddress
impl IsA<SocketConnectable> for UnixSocketAddressimpl IsA<Object> for UnixSocketAddress
impl IsA<Object> for UnixSocketAddressimpl Send for UnixSocketAddress[src]
impl Send for UnixSocketAddressimpl Sync for UnixSocketAddress[src]
impl Sync for UnixSocketAddress