Struct gio::ZlibDecompressor [−]
pub struct ZlibDecompressor(_, _);
Methods
impl ZlibDecompressor[src]
impl ZlibDecompressorpub fn new(format: ZlibCompressorFormat) -> ZlibDecompressor[src]
pub fn new(format: ZlibCompressorFormat) -> ZlibDecompressorTrait Implementations
impl Clone for ZlibDecompressor
impl Clone for ZlibDecompressorfn clone(&self) -> ZlibDecompressor
fn clone(&self) -> ZlibDecompressorReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ZlibDecompressor
impl Hash for ZlibDecompressorfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ZlibDecompressor
impl Ord for ZlibDecompressorfn cmp(&self, other: &ZlibDecompressor) -> Ordering
fn cmp(&self, other: &ZlibDecompressor) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ZlibDecompressor
impl StaticType for ZlibDecompressorfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ZlibDecompressor
impl<T: IsA<Object>> PartialEq<T> for ZlibDecompressorfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ZlibDecompressor
impl Eq for ZlibDecompressorimpl<T: IsA<Object>> PartialOrd<T> for ZlibDecompressor
impl<T: IsA<Object>> PartialOrd<T> for ZlibDecompressorfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ZlibDecompressor
impl Debug for ZlibDecompressorimpl IsA<Converter> for ZlibDecompressor
impl IsA<Converter> for ZlibDecompressorimpl IsA<Object> for ZlibDecompressor
impl IsA<Object> for ZlibDecompressorAuto Trait Implementations
impl !Send for ZlibDecompressor
impl !Send for ZlibDecompressorimpl !Sync for ZlibDecompressor
impl !Sync for ZlibDecompressor