Struct gstreamer_pbutils::DiscovererAudioInfo[]

pub struct DiscovererAudioInfo(_, _);

DiscovererStreamInfo specific to audio streams.

Implements

DiscovererStreamInfoExt, glib::object::ObjectExt

Methods

impl DiscovererAudioInfo
[src]

Returns

the average or nominal bitrate of the stream in bits/second.

Feature: v1_14

Returns

the channel-mask of the stream, refer to gst_audio_channel_positions_from_mask for more information.

Returns

the number of channels in the stream.

Returns

the number of bits used per sample in each channel.

Returns

the language of the stream, or NULL if unknown.

Returns

the maximum bitrate of the stream in bits/second.

Returns

the sample rate of the stream in Hertz.