Struct gstreamer_pbutils::DiscovererInfo [−]
pub struct DiscovererInfo(_, _);
Structure containing the information of a URI analyzed by Discoverer.
Implements
Methods
impl DiscovererInfo[src]
impl DiscovererInfopub fn from_variant(variant: &Variant) -> Option<DiscovererInfo>[src]
pub fn from_variant(variant: &Variant) -> Option<DiscovererInfo>Trait Implementations
impl Clone for DiscovererInfo
impl Clone for DiscovererInfofn clone(&self) -> DiscovererInfo
fn clone(&self) -> DiscovererInfoReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for DiscovererInfo
impl Hash for DiscovererInfofn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for DiscovererInfo
impl Ord for DiscovererInfofn cmp(&self, other: &DiscovererInfo) -> Ordering
fn cmp(&self, other: &DiscovererInfo) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for DiscovererInfo
impl StaticType for DiscovererInfofn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for DiscovererInfo
impl<T: IsA<Object>> PartialEq<T> for DiscovererInfofn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for DiscovererInfo
impl Eq for DiscovererInfoimpl<T: IsA<Object>> PartialOrd<T> for DiscovererInfo
impl<T: IsA<Object>> PartialOrd<T> for DiscovererInfofn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for DiscovererInfo
impl Debug for DiscovererInfoimpl IsA<Object> for DiscovererInfo
impl IsA<Object> for DiscovererInfoimpl Send for DiscovererInfo[src]
impl Send for DiscovererInfoimpl Sync for DiscovererInfo[src]
impl Sync for DiscovererInfo