Struct gstreamer_pbutils::DiscovererSerializeFlags[]

pub struct DiscovererSerializeFlags { /* fields omitted */ }

Methods

impl DiscovererSerializeFlags

BASIC: DiscovererSerializeFlags = DiscovererSerializeFlags{bits: 0,}

CAPS: DiscovererSerializeFlags = DiscovererSerializeFlags{bits: 1,}

TAGS: DiscovererSerializeFlags = DiscovererSerializeFlags{bits: 2,}

MISC: DiscovererSerializeFlags = DiscovererSerializeFlags{bits: 4,}

ALL: DiscovererSerializeFlags = DiscovererSerializeFlags{bits: 7,}

Returns an empty set of flags.

Returns the set containing all flags.

Returns the raw value of the flags currently stored.

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

Returns true if no flags are currently stored.

Returns true if all flags are currently set.

Returns true if there are flags common to both self and other.

Returns true all of the flags in other are contained within self.

Inserts the specified flags in-place.

Removes the specified flags in-place.

Toggles the specified flags in-place.

Inserts or removes the specified flags depending on the passed value.