Trait gstreamer_pbutils::DiscovererStreamInfoExt[][src]

pub trait DiscovererStreamInfoExt {
    fn get_caps(&self) -> Option<Caps>;
fn get_misc(&self) -> Option<Structure>;
fn get_next(&self) -> Option<DiscovererStreamInfo>;
fn get_previous(&self) -> Option<DiscovererStreamInfo>;
fn get_stream_id(&self) -> Option<String>;
fn get_stream_type_nick(&self) -> String;
fn get_tags(&self) -> Option<TagList>;
fn get_toc(&self) -> Option<Toc>; }

Trait containing all DiscovererStreamInfo methods.

Implementors

DiscovererAudioInfo, DiscovererContainerInfo, DiscovererStreamInfo, DiscovererSubtitleInfo, DiscovererVideoInfo

Required Methods

Returns

the gst::Caps of the stream. Unref with gst_caps_unref after usage.

Deprecated

This functions is deprecated since version 1.4, use DiscovererInfoExt::get_missing_elements_installer_details

Returns

additional information regarding the stream (for example codec version, profile, etc..). If you wish to use the gst::Structure after the life-time of self you will need to copy it.

Returns

the next DiscovererStreamInfo in a chain. None for final streams. Unref with gst_discoverer_stream_info_unref after usage.

Returns

the previous DiscovererStreamInfo in a chain. None for starting points. Unref with gst_discoverer_stream_info_unref after usage.

Returns

the stream ID of this stream. If you wish to use the stream ID after the life-time of self you will need to copy it.

Returns

a human readable name for the stream type of the given self (ex : "audio", "container",...).

Returns

the tags contained in this stream. If you wish to use the tags after the life-time of self you will need to copy them.

Returns

the TOC contained in this stream. If you wish to use the TOC after the life-time of self you will need to copy it.

Implementors