Struct gstreamer_rtsp::RTSPEvent [−]
pub struct RTSPEvent { /* fields omitted */ }Methods
impl RTSPEvent
impl RTSPEventpub const READ: RTSPEvent
READ: RTSPEvent = RTSPEvent{bits: 1,}
pub const WRITE: RTSPEvent
WRITE: RTSPEvent = RTSPEvent{bits: 2,}
pub fn empty() -> RTSPEvent
pub fn empty() -> RTSPEventReturns an empty set of flags.
pub fn all() -> RTSPEvent
pub fn all() -> RTSPEventReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<RTSPEvent>
pub fn from_bits(bits: u32) -> Option<RTSPEvent>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> RTSPEvent
pub fn from_bits_truncate(bits: u32) -> RTSPEventConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: RTSPEvent) -> bool
pub fn intersects(&self, other: RTSPEvent) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: RTSPEvent) -> bool
pub fn contains(&self, other: RTSPEvent) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: RTSPEvent)
pub fn insert(&mut self, other: RTSPEvent)Inserts the specified flags in-place.
pub fn remove(&mut self, other: RTSPEvent)
pub fn remove(&mut self, other: RTSPEvent)Removes the specified flags in-place.
pub fn toggle(&mut self, other: RTSPEvent)
pub fn toggle(&mut self, other: RTSPEvent)Toggles the specified flags in-place.
pub fn set(&mut self, other: RTSPEvent, value: bool)
pub fn set(&mut self, other: RTSPEvent, value: bool)Inserts or removes the specified flags depending on the passed value.