Struct gstreamer_rtsp::RTSPLowerTrans [−]
pub struct RTSPLowerTrans { /* fields omitted */ }Methods
impl RTSPLowerTrans
impl RTSPLowerTranspub const UNKNOWN: RTSPLowerTrans
UNKNOWN: RTSPLowerTrans = RTSPLowerTrans{bits: 0,}
pub const UDP: RTSPLowerTrans
UDP: RTSPLowerTrans = RTSPLowerTrans{bits: 1,}
pub const UDP_MCAST: RTSPLowerTrans
UDP_MCAST: RTSPLowerTrans = RTSPLowerTrans{bits: 2,}
pub const TCP: RTSPLowerTrans
TCP: RTSPLowerTrans = RTSPLowerTrans{bits: 4,}
pub const HTTP: RTSPLowerTrans
HTTP: RTSPLowerTrans = RTSPLowerTrans{bits: 16,}
pub const TLS: RTSPLowerTrans
TLS: RTSPLowerTrans = RTSPLowerTrans{bits: 32,}
pub fn empty() -> RTSPLowerTrans
pub fn empty() -> RTSPLowerTransReturns an empty set of flags.
pub fn all() -> RTSPLowerTrans
pub fn all() -> RTSPLowerTransReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<RTSPLowerTrans>
pub fn from_bits(bits: u32) -> Option<RTSPLowerTrans>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> RTSPLowerTrans
pub fn from_bits_truncate(bits: u32) -> RTSPLowerTransConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: RTSPLowerTrans) -> bool
pub fn intersects(&self, other: RTSPLowerTrans) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: RTSPLowerTrans) -> bool
pub fn contains(&self, other: RTSPLowerTrans) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: RTSPLowerTrans)
pub fn insert(&mut self, other: RTSPLowerTrans)Inserts the specified flags in-place.
pub fn remove(&mut self, other: RTSPLowerTrans)
pub fn remove(&mut self, other: RTSPLowerTrans)Removes the specified flags in-place.
pub fn toggle(&mut self, other: RTSPLowerTrans)
pub fn toggle(&mut self, other: RTSPLowerTrans)Toggles the specified flags in-place.
pub fn set(&mut self, other: RTSPLowerTrans, value: bool)
pub fn set(&mut self, other: RTSPLowerTrans, value: bool)Inserts or removes the specified flags depending on the passed value.