Struct gstreamer_rtsp::RTSPMethod [−]
pub struct RTSPMethod { /* fields omitted */ }Methods
impl RTSPMethod
impl RTSPMethodpub const INVALID: RTSPMethod
INVALID: RTSPMethod = RTSPMethod{bits: 0,}
pub const DESCRIBE: RTSPMethod
DESCRIBE: RTSPMethod = RTSPMethod{bits: 1,}
pub const ANNOUNCE: RTSPMethod
ANNOUNCE: RTSPMethod = RTSPMethod{bits: 2,}
pub const GET_PARAMETER: RTSPMethod
GET_PARAMETER: RTSPMethod = RTSPMethod{bits: 4,}
pub const OPTIONS: RTSPMethod
OPTIONS: RTSPMethod = RTSPMethod{bits: 8,}
pub const PAUSE: RTSPMethod
PAUSE: RTSPMethod = RTSPMethod{bits: 16,}
pub const PLAY: RTSPMethod
PLAY: RTSPMethod = RTSPMethod{bits: 32,}
pub const RECORD: RTSPMethod
RECORD: RTSPMethod = RTSPMethod{bits: 64,}
pub const REDIRECT: RTSPMethod
REDIRECT: RTSPMethod = RTSPMethod{bits: 128,}
pub const SETUP: RTSPMethod
SETUP: RTSPMethod = RTSPMethod{bits: 256,}
pub const SET_PARAMETER: RTSPMethod
SET_PARAMETER: RTSPMethod = RTSPMethod{bits: 512,}
pub const TEARDOWN: RTSPMethod
TEARDOWN: RTSPMethod = RTSPMethod{bits: 1024,}
pub const GET: RTSPMethod
GET: RTSPMethod = RTSPMethod{bits: 2048,}
pub const POST: RTSPMethod
POST: RTSPMethod = RTSPMethod{bits: 4096,}
pub fn empty() -> RTSPMethod
pub fn empty() -> RTSPMethodReturns an empty set of flags.
pub fn all() -> RTSPMethod
pub fn all() -> RTSPMethodReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<RTSPMethod>
pub fn from_bits(bits: u32) -> Option<RTSPMethod>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> RTSPMethod
pub fn from_bits_truncate(bits: u32) -> RTSPMethodConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: RTSPMethod) -> bool
pub fn intersects(&self, other: RTSPMethod) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: RTSPMethod) -> bool
pub fn contains(&self, other: RTSPMethod) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: RTSPMethod)
pub fn insert(&mut self, other: RTSPMethod)Inserts the specified flags in-place.
pub fn remove(&mut self, other: RTSPMethod)
pub fn remove(&mut self, other: RTSPMethod)Removes the specified flags in-place.
pub fn toggle(&mut self, other: RTSPMethod)
pub fn toggle(&mut self, other: RTSPMethod)Toggles the specified flags in-place.
pub fn set(&mut self, other: RTSPMethod, value: bool)
pub fn set(&mut self, other: RTSPMethod, value: bool)Inserts or removes the specified flags depending on the passed value.