Struct gstreamer_rtsp::RTSPProfile [−]
pub struct RTSPProfile { /* fields omitted */ }Methods
impl RTSPProfile
impl RTSPProfilepub const UNKNOWN: RTSPProfile
UNKNOWN: RTSPProfile = RTSPProfile{bits: 0,}
pub const AVP: RTSPProfile
AVP: RTSPProfile = RTSPProfile{bits: 1,}
pub const SAVP: RTSPProfile
SAVP: RTSPProfile = RTSPProfile{bits: 2,}
pub const AVPF: RTSPProfile
AVPF: RTSPProfile = RTSPProfile{bits: 4,}
pub const SAVPF: RTSPProfile
SAVPF: RTSPProfile = RTSPProfile{bits: 8,}
pub fn empty() -> RTSPProfile
pub fn empty() -> RTSPProfileReturns an empty set of flags.
pub fn all() -> RTSPProfile
pub fn all() -> RTSPProfileReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<RTSPProfile>
pub fn from_bits(bits: u32) -> Option<RTSPProfile>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> RTSPProfile
pub fn from_bits_truncate(bits: u32) -> RTSPProfileConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: RTSPProfile) -> bool
pub fn intersects(&self, other: RTSPProfile) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: RTSPProfile) -> bool
pub fn contains(&self, other: RTSPProfile) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: RTSPProfile)
pub fn insert(&mut self, other: RTSPProfile)Inserts the specified flags in-place.
pub fn remove(&mut self, other: RTSPProfile)
pub fn remove(&mut self, other: RTSPProfile)Removes the specified flags in-place.
pub fn toggle(&mut self, other: RTSPProfile)
pub fn toggle(&mut self, other: RTSPProfile)Toggles the specified flags in-place.
pub fn set(&mut self, other: RTSPProfile, value: bool)
pub fn set(&mut self, other: RTSPProfile, value: bool)Inserts or removes the specified flags depending on the passed value.