Struct gstreamer_rtsp::RTSPTransMode [−]
pub struct RTSPTransMode { /* fields omitted */ }Methods
impl RTSPTransMode
impl RTSPTransModepub const UNKNOWN: RTSPTransMode
UNKNOWN: RTSPTransMode = RTSPTransMode{bits: 0,}
pub const RTP: RTSPTransMode
RTP: RTSPTransMode = RTSPTransMode{bits: 1,}
pub const RDT: RTSPTransMode
RDT: RTSPTransMode = RTSPTransMode{bits: 2,}
pub fn empty() -> RTSPTransMode
pub fn empty() -> RTSPTransModeReturns an empty set of flags.
pub fn all() -> RTSPTransMode
pub fn all() -> RTSPTransModeReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<RTSPTransMode>
pub fn from_bits(bits: u32) -> Option<RTSPTransMode>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> RTSPTransMode
pub fn from_bits_truncate(bits: u32) -> RTSPTransModeConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: RTSPTransMode) -> bool
pub fn intersects(&self, other: RTSPTransMode) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: RTSPTransMode) -> bool
pub fn contains(&self, other: RTSPTransMode) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: RTSPTransMode)
pub fn insert(&mut self, other: RTSPTransMode)Inserts the specified flags in-place.
pub fn remove(&mut self, other: RTSPTransMode)
pub fn remove(&mut self, other: RTSPTransMode)Removes the specified flags in-place.
pub fn toggle(&mut self, other: RTSPTransMode)
pub fn toggle(&mut self, other: RTSPTransMode)Toggles the specified flags in-place.
pub fn set(&mut self, other: RTSPTransMode, value: bool)
pub fn set(&mut self, other: RTSPTransMode, value: bool)Inserts or removes the specified flags depending on the passed value.