Struct gstreamer_rtsp::RTSPUrl [−]
pub struct RTSPUrl(_);
Provides helper functions to handle RTSP urls.
Methods
impl RTSPUrl[src]
impl RTSPUrlpub fn decode_path_components(&self) -> Vec<String>[src]
pub fn decode_path_components(&self) -> Vec<String>Splits the path of self on '/' boundaries, decoding the resulting components,
The decoding performed by this routine is "URI decoding", as defined in RFC 3986, commonly known as percent-decoding. For example, a string "foo%2fbar" will decode to "foo/bar" -- the %2f being replaced by the corresponding byte with hex value 0x2f. Note that there is no guarantee that the resulting byte sequence is valid in any given encoding. As a special case, %00 is not unescaped to NUL, as that would prematurely terminate the string.
Also note that since paths usually start with a slash, the first component will usually be the empty string.
Returns
None-terminated array of URL components. Free with
g_strfreev when no longer needed.
pub fn get_request_uri(&self) -> Option<String>[src]
pub fn get_request_uri(&self) -> Option<String>Get a newly allocated string describing the request URI for self.
Returns
a string with the request URI. g_free after usage.
pub fn set_port(&mut self, port: u16) -> RTSPResult[src]
pub fn set_port(&mut self, port: u16) -> RTSPResultpub fn parse(urlstr: &str) -> (RTSPResult, RTSPUrl)[src]
pub fn parse(urlstr: &str) -> (RTSPResult, RTSPUrl)Trait Implementations
impl Debug for RTSPUrl[src]
impl Debug for RTSPUrlfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for RTSPUrl[src]
impl PartialEq for RTSPUrlfn eq(&self, other: &RTSPUrl) -> bool[src]
fn eq(&self, other: &RTSPUrl) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &RTSPUrl) -> bool[src]
fn ne(&self, other: &RTSPUrl) -> boolThis method tests for !=.
impl Eq for RTSPUrl[src]
impl Eq for RTSPUrlimpl PartialOrd for RTSPUrl[src]
impl PartialOrd for RTSPUrlfn partial_cmp(&self, other: &RTSPUrl) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &RTSPUrl) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &RTSPUrl) -> bool[src]
fn lt(&self, other: &RTSPUrl) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &RTSPUrl) -> bool[src]
fn le(&self, other: &RTSPUrl) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &RTSPUrl) -> bool[src]
fn gt(&self, other: &RTSPUrl) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &RTSPUrl) -> bool[src]
fn ge(&self, other: &RTSPUrl) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for RTSPUrl[src]
impl Ord for RTSPUrlfn cmp(&self, other: &RTSPUrl) -> Ordering[src]
fn cmp(&self, other: &RTSPUrl) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for RTSPUrl[src]
impl Hash for RTSPUrlfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for RTSPUrl
impl Clone for RTSPUrlfn clone(&self) -> RTSPUrl
fn clone(&self) -> RTSPUrlReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for RTSPUrl
impl StaticType for RTSPUrlfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Send for RTSPUrl[src]
impl Send for RTSPUrl