Struct gstreamer_rtsp_server::RTSPAddressFlags [−]
pub struct RTSPAddressFlags { /* fields omitted */ }Methods
impl RTSPAddressFlags
impl RTSPAddressFlagspub const NONE: RTSPAddressFlags
NONE: RTSPAddressFlags = RTSPAddressFlags{bits: 0,}
pub const IPV4: RTSPAddressFlags
IPV4: RTSPAddressFlags = RTSPAddressFlags{bits: 1,}
pub const IPV6: RTSPAddressFlags
IPV6: RTSPAddressFlags = RTSPAddressFlags{bits: 2,}
pub const EVEN_PORT: RTSPAddressFlags
EVEN_PORT: RTSPAddressFlags = RTSPAddressFlags{bits: 4,}
pub const MULTICAST: RTSPAddressFlags
MULTICAST: RTSPAddressFlags = RTSPAddressFlags{bits: 8,}
pub const UNICAST: RTSPAddressFlags
UNICAST: RTSPAddressFlags = RTSPAddressFlags{bits: 16,}
pub fn empty() -> RTSPAddressFlags
pub fn empty() -> RTSPAddressFlagsReturns an empty set of flags.
pub fn all() -> RTSPAddressFlags
pub fn all() -> RTSPAddressFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<RTSPAddressFlags>
pub fn from_bits(bits: u32) -> Option<RTSPAddressFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> RTSPAddressFlags
pub fn from_bits_truncate(bits: u32) -> RTSPAddressFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: RTSPAddressFlags) -> bool
pub fn intersects(&self, other: RTSPAddressFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: RTSPAddressFlags) -> bool
pub fn contains(&self, other: RTSPAddressFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: RTSPAddressFlags)
pub fn insert(&mut self, other: RTSPAddressFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: RTSPAddressFlags)
pub fn remove(&mut self, other: RTSPAddressFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: RTSPAddressFlags)
pub fn toggle(&mut self, other: RTSPAddressFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: RTSPAddressFlags, value: bool)
pub fn set(&mut self, other: RTSPAddressFlags, value: bool)Inserts or removes the specified flags depending on the passed value.