Struct gstreamer_rtsp_server::RTSPAddressPool [−]
pub struct RTSPAddressPool(_, _);
Methods
impl RTSPAddressPool[src]
impl RTSPAddressPoolpub fn new() -> RTSPAddressPool[src]
pub fn new() -> RTSPAddressPoolTrait Implementations
impl Clone for RTSPAddressPool
impl Clone for RTSPAddressPoolfn clone(&self) -> RTSPAddressPool
fn clone(&self) -> RTSPAddressPoolReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for RTSPAddressPool
impl Hash for RTSPAddressPoolfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for RTSPAddressPool
impl Ord for RTSPAddressPoolfn cmp(&self, other: &RTSPAddressPool) -> Ordering
fn cmp(&self, other: &RTSPAddressPool) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for RTSPAddressPool
impl StaticType for RTSPAddressPoolfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for RTSPAddressPool
impl<T: IsA<Object>> PartialEq<T> for RTSPAddressPoolfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for RTSPAddressPool
impl Eq for RTSPAddressPoolimpl<T: IsA<Object>> PartialOrd<T> for RTSPAddressPool
impl<T: IsA<Object>> PartialOrd<T> for RTSPAddressPoolfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for RTSPAddressPool
impl Debug for RTSPAddressPoolimpl IsA<Object> for RTSPAddressPool
impl IsA<Object> for RTSPAddressPoolimpl Default for RTSPAddressPool[src]
impl Default for RTSPAddressPoolimpl Send for RTSPAddressPool[src]
impl Send for RTSPAddressPoolimpl Sync for RTSPAddressPool[src]
impl Sync for RTSPAddressPool