Struct gstreamer_rtsp_server::RTSPAuth [−]
pub struct RTSPAuth(_, _);
Methods
impl RTSPAuth[src]
impl RTSPAuthpub fn new() -> RTSPAuth[src]
pub fn new() -> RTSPAuthpub fn check(check: &str) -> bool[src]
pub fn check(check: &str) -> boolCheck if check is allowed in the current context.
check
the item to check
Returns
FALSE if check failed.
pub fn make_basic(user: &str, pass: &str) -> String[src]
pub fn make_basic(user: &str, pass: &str) -> StringTrait Implementations
impl Clone for RTSPAuth
impl Clone for RTSPAuthfn clone(&self) -> RTSPAuth
fn clone(&self) -> RTSPAuthReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for RTSPAuth
impl Hash for RTSPAuthfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for RTSPAuth
impl Ord for RTSPAuthfn cmp(&self, other: &RTSPAuth) -> Ordering
fn cmp(&self, other: &RTSPAuth) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for RTSPAuth
impl StaticType for RTSPAuthfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for RTSPAuth
impl<T: IsA<Object>> PartialEq<T> for RTSPAuthfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for RTSPAuth
impl Eq for RTSPAuthimpl<T: IsA<Object>> PartialOrd<T> for RTSPAuth
impl<T: IsA<Object>> PartialOrd<T> for RTSPAuthfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for RTSPAuth
impl Debug for RTSPAuthimpl IsA<Object> for RTSPAuth
impl IsA<Object> for RTSPAuthimpl Default for RTSPAuth[src]
impl Default for RTSPAuthimpl Send for RTSPAuth[src]
impl Send for RTSPAuthimpl Sync for RTSPAuth[src]
impl Sync for RTSPAuth