Struct gstreamer_rtsp_server::RTSPClient [−]
pub struct RTSPClient(_, _);
The client object represents the connection and its state with a client.
Implements
Methods
impl RTSPClient[src]
impl RTSPClientpub fn new() -> RTSPClient[src]
pub fn new() -> RTSPClientTrait Implementations
impl Clone for RTSPClient
impl Clone for RTSPClientfn clone(&self) -> RTSPClient
fn clone(&self) -> RTSPClientReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for RTSPClient
impl Hash for RTSPClientfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for RTSPClient
impl Ord for RTSPClientfn cmp(&self, other: &RTSPClient) -> Ordering
fn cmp(&self, other: &RTSPClient) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for RTSPClient
impl StaticType for RTSPClientfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for RTSPClient
impl<T: IsA<Object>> PartialEq<T> for RTSPClientfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for RTSPClient
impl Eq for RTSPClientimpl<T: IsA<Object>> PartialOrd<T> for RTSPClient
impl<T: IsA<Object>> PartialOrd<T> for RTSPClientfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for RTSPClient
impl Debug for RTSPClientimpl IsA<Object> for RTSPClient
impl IsA<Object> for RTSPClientimpl Default for RTSPClient[src]
impl Default for RTSPClientimpl Send for RTSPClient[src]
impl Send for RTSPClientimpl Sync for RTSPClient[src]
impl Sync for RTSPClient