Struct gstreamer_rtsp_server::RTSPContext [−][src]
pub struct RTSPContext(_);
Information passed around containing the context of a request.
Methods
impl RTSPContext[src]
impl RTSPContextpub fn with_current_context<F: FnOnce(&RTSPContext) -> T, T>(
func: F
) -> Option<T>[src]
pub fn with_current_context<F: FnOnce(&RTSPContext) -> T, T>(
func: F
) -> Option<T>Trait Implementations
impl PartialEq for RTSPContext[src]
impl PartialEq for RTSPContextfn eq(&self, other: &RTSPContext) -> bool[src]
fn eq(&self, other: &RTSPContext) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &RTSPContext) -> bool[src]
fn ne(&self, other: &RTSPContext) -> boolThis method tests for !=.
impl Eq for RTSPContext[src]
impl Eq for RTSPContextAuto Trait Implementations
impl !Send for RTSPContext
impl !Send for RTSPContextimpl !Sync for RTSPContext
impl !Sync for RTSPContext