Struct gstreamer_rtsp_server::RTSPMediaFactory [−]
pub struct RTSPMediaFactory(_, _);
The definition and logic for constructing the pipeline for a media. The media can contain multiple streams like audio and video.
Implements
Methods
impl RTSPMediaFactory[src]
impl RTSPMediaFactorypub fn new() -> RTSPMediaFactory[src]
pub fn new() -> RTSPMediaFactoryTrait Implementations
impl Clone for RTSPMediaFactory
impl Clone for RTSPMediaFactoryfn clone(&self) -> RTSPMediaFactory
fn clone(&self) -> RTSPMediaFactoryReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for RTSPMediaFactory
impl Hash for RTSPMediaFactoryfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for RTSPMediaFactory
impl Ord for RTSPMediaFactoryfn cmp(&self, other: &RTSPMediaFactory) -> Ordering
fn cmp(&self, other: &RTSPMediaFactory) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for RTSPMediaFactory
impl StaticType for RTSPMediaFactoryfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for RTSPMediaFactory
impl<T: IsA<Object>> PartialEq<T> for RTSPMediaFactoryfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for RTSPMediaFactory
impl Eq for RTSPMediaFactoryimpl<T: IsA<Object>> PartialOrd<T> for RTSPMediaFactory
impl<T: IsA<Object>> PartialOrd<T> for RTSPMediaFactoryfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for RTSPMediaFactory
impl Debug for RTSPMediaFactoryimpl IsA<Object> for RTSPMediaFactory
impl IsA<Object> for RTSPMediaFactoryimpl Default for RTSPMediaFactory[src]
impl Default for RTSPMediaFactoryimpl Send for RTSPMediaFactory[src]
impl Send for RTSPMediaFactoryimpl Sync for RTSPMediaFactory[src]
impl Sync for RTSPMediaFactoryimpl IsA<RTSPMediaFactory> for RTSPMediaFactoryURI
impl IsA<RTSPMediaFactory> for RTSPMediaFactoryURI