Struct gstreamer_rtsp_server::RTSPMountPoints [−]
pub struct RTSPMountPoints(_, _);
Creates a RTSPMediaFactory object for a given url.
Implements
Methods
impl RTSPMountPoints[src]
impl RTSPMountPointspub fn new() -> RTSPMountPoints[src]
pub fn new() -> RTSPMountPointsTrait Implementations
impl Clone for RTSPMountPoints
impl Clone for RTSPMountPointsfn clone(&self) -> RTSPMountPoints
fn clone(&self) -> RTSPMountPointsReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for RTSPMountPoints
impl Hash for RTSPMountPointsfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for RTSPMountPoints
impl Ord for RTSPMountPointsfn cmp(&self, other: &RTSPMountPoints) -> Ordering
fn cmp(&self, other: &RTSPMountPoints) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for RTSPMountPoints
impl StaticType for RTSPMountPointsfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for RTSPMountPoints
impl<T: IsA<Object>> PartialEq<T> for RTSPMountPointsfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for RTSPMountPoints
impl Eq for RTSPMountPointsimpl<T: IsA<Object>> PartialOrd<T> for RTSPMountPoints
impl<T: IsA<Object>> PartialOrd<T> for RTSPMountPointsfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for RTSPMountPoints
impl Debug for RTSPMountPointsimpl IsA<Object> for RTSPMountPoints
impl IsA<Object> for RTSPMountPointsimpl Default for RTSPMountPoints[src]
impl Default for RTSPMountPointsimpl Send for RTSPMountPoints[src]
impl Send for RTSPMountPointsimpl Sync for RTSPMountPoints[src]
impl Sync for RTSPMountPoints