Struct gstreamer_rtsp_server::RTSPSessionPool [−]
pub struct RTSPSessionPool(_, _);
An object that keeps track of the active sessions. This object is usually
attached to a RTSPServer object to manage the sessions in that server.
Implements
Methods
impl RTSPSessionPool[src]
impl RTSPSessionPoolpub fn new() -> RTSPSessionPool[src]
pub fn new() -> RTSPSessionPoolCreate a new RTSPSessionPool instance.
Returns
A new RTSPSessionPool. gobject::ObjectExt::unref after
usage.