Struct gstreamer_rtsp_server::RTSPThreadPool [−]
pub struct RTSPThreadPool(_, _);
Methods
impl RTSPThreadPool[src]
impl RTSPThreadPoolpub fn new() -> RTSPThreadPool[src]
pub fn new() -> RTSPThreadPoolpub fn cleanup()[src]
pub fn cleanup()Wait for all tasks to be stopped and free all allocated resources. This is mainly used in test suites to ensure proper cleanup of internal data structures.