Struct gstreamer_rtsp_server::RTSPTokenRef [−][src]
pub struct RTSPTokenRef(_);
Methods
impl RTSPTokenRef[src]
impl RTSPTokenRefpub fn get_string(&self, field: &str) -> Option<String>[src]
pub fn get_string(&self, field: &str) -> Option<String>pub fn get_structure(&self) -> Option<Structure>[src]
pub fn get_structure(&self) -> Option<Structure>pub fn is_allowed(&self, field: &str) -> bool[src]
pub fn is_allowed(&self, field: &str) -> boolpub fn get_mut_structure(&mut self) -> Option<&mut StructureRef>[src]
pub fn get_mut_structure(&mut self) -> Option<&mut StructureRef>Trait Implementations
impl MiniObject for RTSPTokenRef[src]
impl MiniObject for RTSPTokenReftype GstType = GstRTSPToken
unsafe fn as_ptr(&self) -> *const Self::GstType[src]
unsafe fn as_ptr(&self) -> *const Self::GstTypeunsafe fn as_mut_ptr(&self) -> *mut Self::GstType[src]
unsafe fn as_mut_ptr(&self) -> *mut Self::GstTypeⓘImportant traits for &'a mut Runsafe fn from_ptr<'a>(ptr: *const Self::GstType) -> &'a Self[src]
ⓘImportant traits for &'a mut R
unsafe fn from_ptr<'a>(ptr: *const Self::GstType) -> &'a SelfⓘImportant traits for &'a mut Runsafe fn from_mut_ptr<'a>(ptr: *mut Self::GstType) -> &'a mut Self[src]
ⓘImportant traits for &'a mut R
unsafe fn from_mut_ptr<'a>(ptr: *mut Self::GstType) -> &'a mut Selffn copy(&self) -> GstRc<Self>[src]
fn copy(&self) -> GstRc<Self>impl GstRcRTSPTokenExt<RTSPTokenRef> for GstRc<RTSPTokenRef>[src]
impl GstRcRTSPTokenExt<RTSPTokenRef> for GstRc<RTSPTokenRef>impl ToOwned for RTSPTokenRef[src]
impl ToOwned for RTSPTokenReftype Owned = GstRc<RTSPTokenRef>
fn to_owned(&self) -> GstRc<RTSPTokenRef>[src]
fn to_owned(&self) -> GstRc<RTSPTokenRef>Creates owned data from borrowed data, usually by cloning. Read more
fn clone_into(&self, target: &mut Self::Owned)[src]
fn clone_into(&self, target: &mut Self::Owned)🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl StaticType for RTSPTokenRef[src]
impl StaticType for RTSPTokenReffn static_type() -> Type[src]
fn static_type() -> TypeReturns the type identifier of Self.