Struct gstreamer_rtsp_server::RTSPTransportMode [−]
pub struct RTSPTransportMode { /* fields omitted */ }Methods
impl RTSPTransportMode
impl RTSPTransportModepub const PLAY: RTSPTransportMode
PLAY: RTSPTransportMode = RTSPTransportMode{bits: 1,}
pub const RECORD: RTSPTransportMode
RECORD: RTSPTransportMode = RTSPTransportMode{bits: 2,}
pub fn empty() -> RTSPTransportMode
pub fn empty() -> RTSPTransportModeReturns an empty set of flags.
pub fn all() -> RTSPTransportMode
pub fn all() -> RTSPTransportModeReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<RTSPTransportMode>
pub fn from_bits(bits: u32) -> Option<RTSPTransportMode>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> RTSPTransportMode
pub fn from_bits_truncate(bits: u32) -> RTSPTransportModeConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: RTSPTransportMode) -> bool
pub fn intersects(&self, other: RTSPTransportMode) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: RTSPTransportMode) -> bool
pub fn contains(&self, other: RTSPTransportMode) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: RTSPTransportMode)
pub fn insert(&mut self, other: RTSPTransportMode)Inserts the specified flags in-place.
pub fn remove(&mut self, other: RTSPTransportMode)
pub fn remove(&mut self, other: RTSPTransportMode)Removes the specified flags in-place.
pub fn toggle(&mut self, other: RTSPTransportMode)
pub fn toggle(&mut self, other: RTSPTransportMode)Toggles the specified flags in-place.
pub fn set(&mut self, other: RTSPTransportMode, value: bool)
pub fn set(&mut self, other: RTSPTransportMode, value: bool)Inserts or removes the specified flags depending on the passed value.