Trait gstreamer_rtsp_server::RTSPMountPointsExt [−][src]
pub trait RTSPMountPointsExt {
fn add_factory<P: IsA<RTSPMediaFactory>>(&self, path: &str, factory: &P);
fn make_path(&self, url: &RTSPUrl) -> Option<String>;
fn match_(&self, path: &str) -> (RTSPMediaFactory, i32);
fn remove_factory(&self, path: &str);
}Required Methods
fn add_factory<P: IsA<RTSPMediaFactory>>(&self, path: &str, factory: &P)
Attach factory to the mount point path in self.
path is of the form (/node)+. Any previous mount point will be freed.
Ownership is taken of the reference on factory so that factory should not be
used after calling this function.
path
a mount point
factory
a RTSPMediaFactory
fn make_path(&self, url: &RTSPUrl) -> Option<String>
Make a path string from url.
url
a gst_rtsp::RTSPUrl
Returns
a path string for url, g_free after usage.
fn match_(&self, path: &str) -> (RTSPMediaFactory, i32)
fn remove_factory(&self, path: &str)
Implementors
impl<O: IsA<RTSPMountPoints>> RTSPMountPointsExt for O