Enum gtk::IMStatusStyle [−][src]
pub enum IMStatusStyle {
Nothing,
Callback,
None,
// some variants omitted
}Variants
NothingCallbackNoneTrait Implementations
impl Debug for IMStatusStyle[src]
impl Debug for IMStatusStylefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Eq for IMStatusStyle[src]
impl Eq for IMStatusStyleimpl PartialEq for IMStatusStyle[src]
impl PartialEq for IMStatusStylefn eq(&self, other: &IMStatusStyle) -> bool[src]
fn eq(&self, other: &IMStatusStyle) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IMStatusStyle) -> bool[src]
fn ne(&self, other: &IMStatusStyle) -> boolThis method tests for !=.
impl Ord for IMStatusStyle[src]
impl Ord for IMStatusStylefn cmp(&self, other: &IMStatusStyle) -> Ordering[src]
fn cmp(&self, other: &IMStatusStyle) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl PartialOrd for IMStatusStyle[src]
impl PartialOrd for IMStatusStylefn partial_cmp(&self, other: &IMStatusStyle) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &IMStatusStyle) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &IMStatusStyle) -> bool[src]
fn lt(&self, other: &IMStatusStyle) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &IMStatusStyle) -> bool[src]
fn le(&self, other: &IMStatusStyle) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &IMStatusStyle) -> bool[src]
fn gt(&self, other: &IMStatusStyle) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &IMStatusStyle) -> bool[src]
fn ge(&self, other: &IMStatusStyle) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Hash for IMStatusStyle[src]
impl Hash for IMStatusStylefn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for IMStatusStyle[src]
impl Clone for IMStatusStylefn clone(&self) -> IMStatusStyle[src]
fn clone(&self) -> IMStatusStyleReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Copy for IMStatusStyle[src]
impl Copy for IMStatusStyleimpl StaticType for IMStatusStyle[src]
impl StaticType for IMStatusStylefn static_type() -> Type[src]
fn static_type() -> TypeReturns the type identifier of Self.
impl<'a> FromValueOptional<'a> for IMStatusStyle[src]
impl<'a> FromValueOptional<'a> for IMStatusStyleunsafe fn from_value_optional(value: &Value) -> Option<Self>[src]
unsafe fn from_value_optional(value: &Value) -> Option<Self>impl<'a> FromValue<'a> for IMStatusStyle[src]
impl<'a> FromValue<'a> for IMStatusStyleunsafe fn from_value(value: &Value) -> Self[src]
unsafe fn from_value(value: &Value) -> Selfimpl SetValue for IMStatusStyle[src]
impl SetValue for IMStatusStyleAuto Trait Implementations
impl Send for IMStatusStyle
impl Send for IMStatusStyleimpl Sync for IMStatusStyle
impl Sync for IMStatusStyle