Struct gtk::AccelFlags [−]
pub struct AccelFlags { /* fields omitted */ }Methods
impl AccelFlags
impl AccelFlagspub const VISIBLE: AccelFlags
VISIBLE: AccelFlags = AccelFlags{bits: 1,}
pub const LOCKED: AccelFlags
LOCKED: AccelFlags = AccelFlags{bits: 2,}
pub const MASK: AccelFlags
MASK: AccelFlags = AccelFlags{bits: 7,}
pub fn empty() -> AccelFlags
pub fn empty() -> AccelFlagsReturns an empty set of flags.
pub fn all() -> AccelFlags
pub fn all() -> AccelFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<AccelFlags>
pub fn from_bits(bits: u32) -> Option<AccelFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> AccelFlags
pub fn from_bits_truncate(bits: u32) -> AccelFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: AccelFlags) -> bool
pub fn intersects(&self, other: AccelFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: AccelFlags) -> bool
pub fn contains(&self, other: AccelFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: AccelFlags)
pub fn insert(&mut self, other: AccelFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: AccelFlags)
pub fn remove(&mut self, other: AccelFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: AccelFlags)
pub fn toggle(&mut self, other: AccelFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: AccelFlags, value: bool)
pub fn set(&mut self, other: AccelFlags, value: bool)Inserts or removes the specified flags depending on the passed value.