Struct gtk::AccelGroup [−]
pub struct AccelGroup(_, _);
Methods
impl AccelGroup[src]
impl AccelGrouppub fn new() -> AccelGroup[src]
pub fn new() -> AccelGrouppub fn from_accel_closure(closure: &Closure) -> Option<AccelGroup>[src]
pub fn from_accel_closure(closure: &Closure) -> Option<AccelGroup>Trait Implementations
impl Clone for AccelGroup
impl Clone for AccelGroupfn clone(&self) -> AccelGroup
fn clone(&self) -> AccelGroupReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for AccelGroup
impl Hash for AccelGroupfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for AccelGroup
impl Ord for AccelGroupfn cmp(&self, other: &AccelGroup) -> Ordering
fn cmp(&self, other: &AccelGroup) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for AccelGroup
impl StaticType for AccelGroupfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for AccelGroup
impl<T: IsA<Object>> PartialEq<T> for AccelGroupfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for AccelGroup
impl Eq for AccelGroupimpl<T: IsA<Object>> PartialOrd<T> for AccelGroup
impl<T: IsA<Object>> PartialOrd<T> for AccelGroupfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for AccelGroup
impl Debug for AccelGroupimpl IsA<Object> for AccelGroup
impl IsA<Object> for AccelGroupimpl Default for AccelGroup[src]
impl Default for AccelGroupAuto Trait Implementations
impl !Send for AccelGroup
impl !Send for AccelGroupimpl !Sync for AccelGroup
impl !Sync for AccelGroup