Struct gtk::AccelLabel [−]
pub struct AccelLabel(_, _);
Methods
impl AccelLabel[src]
impl AccelLabelpub fn new(string: &str) -> AccelLabel[src]
pub fn new(string: &str) -> AccelLabelTrait Implementations
impl Clone for AccelLabel
impl Clone for AccelLabelfn clone(&self) -> AccelLabel
fn clone(&self) -> AccelLabelReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for AccelLabel
impl Hash for AccelLabelfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for AccelLabel
impl Ord for AccelLabelfn cmp(&self, other: &AccelLabel) -> Ordering
fn cmp(&self, other: &AccelLabel) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for AccelLabel
impl StaticType for AccelLabelfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for AccelLabel
impl<T: IsA<Object>> PartialEq<T> for AccelLabelfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for AccelLabel
impl Eq for AccelLabelimpl<T: IsA<Object>> PartialOrd<T> for AccelLabel
impl<T: IsA<Object>> PartialOrd<T> for AccelLabelfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for AccelLabel
impl Debug for AccelLabelimpl IsA<Label> for AccelLabel
impl IsA<Label> for AccelLabelimpl IsA<Misc> for AccelLabel
impl IsA<Misc> for AccelLabelimpl IsA<Widget> for AccelLabel
impl IsA<Widget> for AccelLabelimpl IsA<Buildable> for AccelLabel
impl IsA<Buildable> for AccelLabelimpl IsA<Object> for AccelLabel
impl IsA<Object> for AccelLabelAuto Trait Implementations
impl !Send for AccelLabel
impl !Send for AccelLabelimpl !Sync for AccelLabel
impl !Sync for AccelLabel