Struct gtk::Allocation [−][src]
Fields
x: i32
y: i32
width: i32
height: i32
Methods
impl Rectangle[src]
impl Rectanglepub fn intersect(&self, other: &Rectangle) -> Option<Rectangle>[src]
pub fn intersect(&self, other: &Rectangle) -> Option<Rectangle>pub fn union(&self, other: &Rectangle) -> Rectangle[src]
pub fn union(&self, other: &Rectangle) -> RectangleTrait Implementations
impl StaticType for Rectangle[src]
impl StaticType for Rectanglefn static_type() -> Type[src]
fn static_type() -> TypeReturns the type identifier of Self.
impl AsRef<RectangleInt> for Rectangle[src]
impl AsRef<RectangleInt> for Rectanglefn as_ref(&self) -> &RectangleInt[src]
fn as_ref(&self) -> &RectangleIntPerforms the conversion.
impl From<RectangleInt> for Rectangle[src]
impl From<RectangleInt> for Rectanglefn from(r: RectangleInt) -> Rectangle[src]
fn from(r: RectangleInt) -> RectanglePerforms the conversion.
impl Clone for Rectangle[src]
impl Clone for Rectanglefn clone(&self) -> Rectangle[src]
fn clone(&self) -> RectangleReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Eq for Rectangle[src]
impl Eq for Rectangleimpl Hash for Rectangle[src]
impl Hash for Rectanglefn hash<__H>(&self, state: &mut __H) where
__H: Hasher, [src]
fn hash<__H>(&self, state: &mut __H) where
__H: Hasher, Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl<'a> FromValueOptional<'a> for Rectangle[src]
impl<'a> FromValueOptional<'a> for Rectangleunsafe fn from_value_optional(value: &'a Value) -> Option<Rectangle>[src]
unsafe fn from_value_optional(value: &'a Value) -> Option<Rectangle>impl SetValue for Rectangle[src]
impl SetValue for Rectangleimpl PartialEq<Rectangle> for Rectangle[src]
impl PartialEq<Rectangle> for Rectanglefn eq(&self, other: &Rectangle) -> bool[src]
fn eq(&self, other: &Rectangle) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rectangle) -> bool[src]
fn ne(&self, other: &Rectangle) -> boolThis method tests for !=.
impl Debug for Rectangle[src]
impl Debug for Rectanglefn fmt(&self, f: &mut Formatter) -> Result<(), Error>[src]
fn fmt(&self, f: &mut Formatter) -> Result<(), Error>Formats the value using the given formatter. Read more
impl SetValueOptional for Rectangle[src]
impl SetValueOptional for Rectangleunsafe fn set_value_optional(value: &mut Value, this: Option<&Rectangle>)[src]
unsafe fn set_value_optional(value: &mut Value, this: Option<&Rectangle>)impl Copy for Rectangle[src]
impl Copy for Rectangle