Struct gtk::AppChooserButton [−]
pub struct AppChooserButton(_, _);
Methods
impl AppChooserButton[src]
impl AppChooserButtonpub fn new(content_type: &str) -> AppChooserButton[src]
pub fn new(content_type: &str) -> AppChooserButtonTrait Implementations
impl Clone for AppChooserButton
impl Clone for AppChooserButtonfn clone(&self) -> AppChooserButton
fn clone(&self) -> AppChooserButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for AppChooserButton
impl Hash for AppChooserButtonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for AppChooserButton
impl Ord for AppChooserButtonfn cmp(&self, other: &AppChooserButton) -> Ordering
fn cmp(&self, other: &AppChooserButton) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for AppChooserButton
impl StaticType for AppChooserButtonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for AppChooserButton
impl<T: IsA<Object>> PartialEq<T> for AppChooserButtonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for AppChooserButton
impl Eq for AppChooserButtonimpl<T: IsA<Object>> PartialOrd<T> for AppChooserButton
impl<T: IsA<Object>> PartialOrd<T> for AppChooserButtonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for AppChooserButton
impl Debug for AppChooserButtonimpl IsA<ComboBox> for AppChooserButton
impl IsA<ComboBox> for AppChooserButtonimpl IsA<Bin> for AppChooserButton
impl IsA<Bin> for AppChooserButtonimpl IsA<Container> for AppChooserButton
impl IsA<Container> for AppChooserButtonimpl IsA<Widget> for AppChooserButton
impl IsA<Widget> for AppChooserButtonimpl IsA<Buildable> for AppChooserButton
impl IsA<Buildable> for AppChooserButtonimpl IsA<CellEditable> for AppChooserButton
impl IsA<CellEditable> for AppChooserButtonimpl IsA<CellLayout> for AppChooserButton
impl IsA<CellLayout> for AppChooserButtonimpl IsA<AppChooser> for AppChooserButton
impl IsA<AppChooser> for AppChooserButtonimpl IsA<Object> for AppChooserButton
impl IsA<Object> for AppChooserButtonAuto Trait Implementations
impl !Send for AppChooserButton
impl !Send for AppChooserButtonimpl !Sync for AppChooserButton
impl !Sync for AppChooserButton