Struct gtk::AppChooserDialog [−]
pub struct AppChooserDialog(_, _);
Methods
impl AppChooserDialog[src]
impl AppChooserDialogpub fn new<'a, P: IsA<Window> + 'a, Q: Into<Option<&'a P>>, R: IsA<File>>(
parent: Q,
flags: DialogFlags,
file: &R
) -> AppChooserDialog[src]
pub fn new<'a, P: IsA<Window> + 'a, Q: Into<Option<&'a P>>, R: IsA<File>>(
parent: Q,
flags: DialogFlags,
file: &R
) -> AppChooserDialogpub fn new_for_content_type<'a, P: IsA<Window> + 'a, Q: Into<Option<&'a P>>>(
parent: Q,
flags: DialogFlags,
content_type: &str
) -> AppChooserDialog[src]
pub fn new_for_content_type<'a, P: IsA<Window> + 'a, Q: Into<Option<&'a P>>>(
parent: Q,
flags: DialogFlags,
content_type: &str
) -> AppChooserDialogTrait Implementations
impl Clone for AppChooserDialog
impl Clone for AppChooserDialogfn clone(&self) -> AppChooserDialog
fn clone(&self) -> AppChooserDialogReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for AppChooserDialog
impl Hash for AppChooserDialogfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for AppChooserDialog
impl Ord for AppChooserDialogfn cmp(&self, other: &AppChooserDialog) -> Ordering
fn cmp(&self, other: &AppChooserDialog) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for AppChooserDialog
impl StaticType for AppChooserDialogfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for AppChooserDialog
impl<T: IsA<Object>> PartialEq<T> for AppChooserDialogfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for AppChooserDialog
impl Eq for AppChooserDialogimpl<T: IsA<Object>> PartialOrd<T> for AppChooserDialog
impl<T: IsA<Object>> PartialOrd<T> for AppChooserDialogfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for AppChooserDialog
impl Debug for AppChooserDialogimpl IsA<Dialog> for AppChooserDialog
impl IsA<Dialog> for AppChooserDialogimpl IsA<Window> for AppChooserDialog
impl IsA<Window> for AppChooserDialogimpl IsA<Bin> for AppChooserDialog
impl IsA<Bin> for AppChooserDialogimpl IsA<Container> for AppChooserDialog
impl IsA<Container> for AppChooserDialogimpl IsA<Widget> for AppChooserDialog
impl IsA<Widget> for AppChooserDialogimpl IsA<Buildable> for AppChooserDialog
impl IsA<Buildable> for AppChooserDialogimpl IsA<AppChooser> for AppChooserDialog
impl IsA<AppChooser> for AppChooserDialogimpl IsA<Object> for AppChooserDialog
impl IsA<Object> for AppChooserDialogAuto Trait Implementations
impl !Send for AppChooserDialog
impl !Send for AppChooserDialogimpl !Sync for AppChooserDialog
impl !Sync for AppChooserDialog