Struct gtk::ApplicationInhibitFlags [−]
pub struct ApplicationInhibitFlags { /* fields omitted */ }Methods
impl ApplicationInhibitFlags
impl ApplicationInhibitFlagspub const LOGOUT: ApplicationInhibitFlags
LOGOUT: ApplicationInhibitFlags = ApplicationInhibitFlags{bits: 1,}
pub const SWITCH: ApplicationInhibitFlags
SWITCH: ApplicationInhibitFlags = ApplicationInhibitFlags{bits: 2,}
pub const SUSPEND: ApplicationInhibitFlags
SUSPEND: ApplicationInhibitFlags = ApplicationInhibitFlags{bits: 4,}
pub const IDLE: ApplicationInhibitFlags
IDLE: ApplicationInhibitFlags = ApplicationInhibitFlags{bits: 8,}
pub fn empty() -> ApplicationInhibitFlags
pub fn empty() -> ApplicationInhibitFlagsReturns an empty set of flags.
pub fn all() -> ApplicationInhibitFlags
pub fn all() -> ApplicationInhibitFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<ApplicationInhibitFlags>
pub fn from_bits(bits: u32) -> Option<ApplicationInhibitFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> ApplicationInhibitFlags
pub fn from_bits_truncate(bits: u32) -> ApplicationInhibitFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: ApplicationInhibitFlags) -> bool
pub fn intersects(&self, other: ApplicationInhibitFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: ApplicationInhibitFlags) -> bool
pub fn contains(&self, other: ApplicationInhibitFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ApplicationInhibitFlags)
pub fn insert(&mut self, other: ApplicationInhibitFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: ApplicationInhibitFlags)
pub fn remove(&mut self, other: ApplicationInhibitFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: ApplicationInhibitFlags)
pub fn toggle(&mut self, other: ApplicationInhibitFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: ApplicationInhibitFlags, value: bool)
pub fn set(&mut self, other: ApplicationInhibitFlags, value: bool)Inserts or removes the specified flags depending on the passed value.