Struct gtk::Arrow [−]
pub struct Arrow(_, _);
Methods
impl Arrow[src]
impl Arrowpub fn new(arrow_type: ArrowType, shadow_type: ShadowType) -> Arrow[src]
pub fn new(arrow_type: ArrowType, shadow_type: ShadowType) -> ArrowTrait Implementations
impl Clone for Arrow
impl Clone for Arrowfn clone(&self) -> Arrow
fn clone(&self) -> ArrowReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Arrow
impl Hash for Arrowfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Arrow
impl Ord for Arrowfn cmp(&self, other: &Arrow) -> Ordering
fn cmp(&self, other: &Arrow) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Arrow
impl StaticType for Arrowfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Arrow
impl<T: IsA<Object>> PartialEq<T> for Arrowfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Arrow
impl Eq for Arrowimpl<T: IsA<Object>> PartialOrd<T> for Arrow
impl<T: IsA<Object>> PartialOrd<T> for Arrowfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Arrow
impl Debug for Arrowimpl IsA<Misc> for Arrow
impl IsA<Misc> for Arrowimpl IsA<Widget> for Arrow
impl IsA<Widget> for Arrowimpl IsA<Buildable> for Arrow
impl IsA<Buildable> for Arrowimpl IsA<Object> for Arrow
impl IsA<Object> for Arrow