Struct gtk::AspectFrame [−]
pub struct AspectFrame(_, _);
Methods
impl AspectFrame[src]
impl AspectFramepub fn new<'a, P: Into<Option<&'a str>>>(
label: P,
xalign: f32,
yalign: f32,
ratio: f32,
obey_child: bool
) -> AspectFrame[src]
pub fn new<'a, P: Into<Option<&'a str>>>(
label: P,
xalign: f32,
yalign: f32,
ratio: f32,
obey_child: bool
) -> AspectFrameTrait Implementations
impl Clone for AspectFrame
impl Clone for AspectFramefn clone(&self) -> AspectFrame
fn clone(&self) -> AspectFrameReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for AspectFrame
impl Hash for AspectFramefn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for AspectFrame
impl Ord for AspectFramefn cmp(&self, other: &AspectFrame) -> Ordering
fn cmp(&self, other: &AspectFrame) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for AspectFrame
impl StaticType for AspectFramefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for AspectFrame
impl<T: IsA<Object>> PartialEq<T> for AspectFramefn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for AspectFrame
impl Eq for AspectFrameimpl<T: IsA<Object>> PartialOrd<T> for AspectFrame
impl<T: IsA<Object>> PartialOrd<T> for AspectFramefn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for AspectFrame
impl Debug for AspectFrameimpl IsA<Frame> for AspectFrame
impl IsA<Frame> for AspectFrameimpl IsA<Bin> for AspectFrame
impl IsA<Bin> for AspectFrameimpl IsA<Container> for AspectFrame
impl IsA<Container> for AspectFrameimpl IsA<Widget> for AspectFrame
impl IsA<Widget> for AspectFrameimpl IsA<Buildable> for AspectFrame
impl IsA<Buildable> for AspectFrameimpl IsA<Object> for AspectFrame
impl IsA<Object> for AspectFrameAuto Trait Implementations
impl !Send for AspectFrame
impl !Send for AspectFrameimpl !Sync for AspectFrame
impl !Sync for AspectFrame