Struct gtk::Border [−]
pub struct Border(_);
Methods
impl Border[src]
impl BorderTrait Implementations
impl PartialEq for Border[src]
impl PartialEq for Borderfn eq(&self, other: &Border) -> bool[src]
fn eq(&self, other: &Border) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Border) -> bool[src]
fn ne(&self, other: &Border) -> boolThis method tests for !=.
impl Eq for Border[src]
impl Eq for Borderimpl PartialOrd for Border[src]
impl PartialOrd for Borderfn partial_cmp(&self, other: &Border) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &Border) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Border) -> bool[src]
fn lt(&self, other: &Border) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Border) -> bool[src]
fn le(&self, other: &Border) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Border) -> bool[src]
fn gt(&self, other: &Border) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Border) -> bool[src]
fn ge(&self, other: &Border) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for Border[src]
impl Ord for Borderfn cmp(&self, other: &Border) -> Ordering[src]
fn cmp(&self, other: &Border) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for Border[src]
impl Hash for Borderfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for Border
impl Clone for Borderfn clone(&self) -> Border
fn clone(&self) -> BorderReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for Border
impl StaticType for Borderfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Deref for Border[src]
impl Deref for Bordertype Target = GtkBorder
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl DerefMut for Border[src]
impl DerefMut for Borderimpl Default for Border[src]
impl Default for Borderimpl Debug for Border[src]
impl Debug for Border