Struct gtk::Box [−]
pub struct Box(_, _);
Methods
impl Box[src]
impl Boxpub fn new(orientation: Orientation, spacing: i32) -> Box[src]
pub fn new(orientation: Orientation, spacing: i32) -> BoxTrait Implementations
impl IsA<Box> for AppChooserWidget
impl IsA<Box> for AppChooserWidgetimpl Clone for Box
impl Clone for Boxfn clone(&self) -> Box
fn clone(&self) -> BoxReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Box
impl Hash for Boxfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Box
impl Ord for Boxfn cmp(&self, other: &Box) -> Ordering
fn cmp(&self, other: &Box) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Box
impl StaticType for Boxfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Box
impl<T: IsA<Object>> PartialEq<T> for Boxfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Box
impl Eq for Boximpl<T: IsA<Object>> PartialOrd<T> for Box
impl<T: IsA<Object>> PartialOrd<T> for Boxfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Box
impl Debug for Boximpl IsA<Container> for Box
impl IsA<Container> for Boximpl IsA<Widget> for Box
impl IsA<Widget> for Boximpl IsA<Buildable> for Box
impl IsA<Buildable> for Boximpl IsA<Orientable> for Box
impl IsA<Orientable> for Boximpl IsA<Object> for Box
impl IsA<Object> for Boximpl IsA<Box> for ButtonBox
impl IsA<Box> for ButtonBoximpl IsA<Box> for ColorChooserWidget
impl IsA<Box> for ColorChooserWidgetimpl IsA<Box> for FileChooserButton
impl IsA<Box> for FileChooserButtonimpl IsA<Box> for FileChooserWidget
impl IsA<Box> for FileChooserWidgetimpl IsA<Box> for FontChooserWidget
impl IsA<Box> for FontChooserWidgetimpl IsA<Box> for InfoBar
impl IsA<Box> for InfoBarimpl IsA<Box> for RecentChooserWidget
impl IsA<Box> for RecentChooserWidgetimpl IsA<Box> for StackSwitcher
impl IsA<Box> for StackSwitcherimpl IsA<Box> for Statusbar
impl IsA<Box> for Statusbar