Struct gtk::Builder [−]
pub struct Builder(_, _);
Methods
impl Builder[src]
impl Builderpub fn new() -> Builder[src]
pub fn new() -> Builderpub fn new_from_resource(resource_path: &str) -> Builder[src]
pub fn new_from_resource(resource_path: &str) -> Builderpub fn new_from_string(string: &str) -> Builder[src]
pub fn new_from_string(string: &str) -> Builderimpl Builder[src]
impl Builderpub fn new_from_file<T: AsRef<Path>>(file_path: T) -> Builder[src]
pub fn new_from_file<T: AsRef<Path>>(file_path: T) -> Builderpub fn get_object<T: IsA<Object>>(&self, name: &str) -> Option<T>[src]
pub fn get_object<T: IsA<Object>>(&self, name: &str) -> Option<T>pub fn add_from_file<T: AsRef<Path>>(&self, file_path: T) -> Result<(), Error>[src]
pub fn add_from_file<T: AsRef<Path>>(&self, file_path: T) -> Result<(), Error>Trait Implementations
impl Clone for Builder
impl Clone for Builderfn clone(&self) -> Builder
fn clone(&self) -> BuilderReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Builder
impl Hash for Builderfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Builder
impl Ord for Builderfn cmp(&self, other: &Builder) -> Ordering
fn cmp(&self, other: &Builder) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Builder
impl StaticType for Builderfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Builder
impl<T: IsA<Object>> PartialEq<T> for Builderfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Builder
impl Eq for Builderimpl<T: IsA<Object>> PartialOrd<T> for Builder
impl<T: IsA<Object>> PartialOrd<T> for Builderfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Builder
impl Debug for Builderimpl IsA<Object> for Builder
impl IsA<Object> for Builderimpl Default for Builder[src]
impl Default for Builder