Struct gtk::Button [−]
pub struct Button(_, _);
Methods
impl Button[src]
impl Buttonpub fn new() -> Button[src]
pub fn new() -> Buttonpub fn new_from_icon_name<'a, P: Into<Option<&'a str>>>(
icon_name: P,
size: i32
) -> Button[src]
pub fn new_from_icon_name<'a, P: Into<Option<&'a str>>>(
icon_name: P,
size: i32
) -> Buttonpub fn new_from_stock(stock_id: &str) -> Button[src]
pub fn new_from_stock(stock_id: &str) -> Buttonpub fn new_with_label(label: &str) -> Button[src]
pub fn new_with_label(label: &str) -> Buttonpub fn new_with_mnemonic(label: &str) -> Button[src]
pub fn new_with_mnemonic(label: &str) -> ButtonTrait Implementations
impl Clone for Button
impl Clone for Buttonfn clone(&self) -> Button
fn clone(&self) -> ButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Button
impl Hash for Buttonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Button
impl Ord for Buttonfn cmp(&self, other: &Button) -> Ordering
fn cmp(&self, other: &Button) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Button
impl StaticType for Buttonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Button
impl<T: IsA<Object>> PartialEq<T> for Buttonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Button
impl Eq for Buttonimpl<T: IsA<Object>> PartialOrd<T> for Button
impl<T: IsA<Object>> PartialOrd<T> for Buttonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Button
impl Debug for Buttonimpl IsA<Bin> for Button
impl IsA<Bin> for Buttonimpl IsA<Container> for Button
impl IsA<Container> for Buttonimpl IsA<Widget> for Button
impl IsA<Widget> for Buttonimpl IsA<Buildable> for Button
impl IsA<Buildable> for Buttonimpl IsA<Actionable> for Button
impl IsA<Actionable> for Buttonimpl IsA<Object> for Button
impl IsA<Object> for Buttonimpl Default for Button[src]
impl Default for Buttonimpl IsA<Button> for CheckButton
impl IsA<Button> for CheckButtonimpl IsA<Button> for ColorButton
impl IsA<Button> for ColorButtonimpl IsA<Button> for FontButton
impl IsA<Button> for FontButtonimpl IsA<Button> for LinkButton
impl IsA<Button> for LinkButtonimpl IsA<Button> for LockButton
impl IsA<Button> for LockButtonimpl IsA<Button> for MenuButton
impl IsA<Button> for MenuButtonimpl IsA<Button> for RadioButton
impl IsA<Button> for RadioButtonimpl IsA<Button> for ScaleButton
impl IsA<Button> for ScaleButtonimpl IsA<Button> for ToggleButton
impl IsA<Button> for ToggleButtonimpl IsA<Button> for VolumeButton
impl IsA<Button> for VolumeButton