Struct gtk::CalendarDisplayOptions [−]
pub struct CalendarDisplayOptions { /* fields omitted */ }Methods
impl CalendarDisplayOptions
impl CalendarDisplayOptionspub const SHOW_HEADING: CalendarDisplayOptions
SHOW_HEADING: CalendarDisplayOptions = CalendarDisplayOptions{bits: 1,}
pub const SHOW_DAY_NAMES: CalendarDisplayOptions
SHOW_DAY_NAMES: CalendarDisplayOptions = CalendarDisplayOptions{bits: 2,}
pub const NO_MONTH_CHANGE: CalendarDisplayOptions
NO_MONTH_CHANGE: CalendarDisplayOptions = CalendarDisplayOptions{bits: 4,}
pub const SHOW_WEEK_NUMBERS: CalendarDisplayOptions
SHOW_WEEK_NUMBERS: CalendarDisplayOptions = CalendarDisplayOptions{bits: 8,}
pub const SHOW_DETAILS: CalendarDisplayOptions
SHOW_DETAILS: CalendarDisplayOptions = CalendarDisplayOptions{bits: 32,}
pub fn empty() -> CalendarDisplayOptions
pub fn empty() -> CalendarDisplayOptionsReturns an empty set of flags.
pub fn all() -> CalendarDisplayOptions
pub fn all() -> CalendarDisplayOptionsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<CalendarDisplayOptions>
pub fn from_bits(bits: u32) -> Option<CalendarDisplayOptions>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> CalendarDisplayOptions
pub fn from_bits_truncate(bits: u32) -> CalendarDisplayOptionsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: CalendarDisplayOptions) -> bool
pub fn intersects(&self, other: CalendarDisplayOptions) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: CalendarDisplayOptions) -> bool
pub fn contains(&self, other: CalendarDisplayOptions) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: CalendarDisplayOptions)
pub fn insert(&mut self, other: CalendarDisplayOptions)Inserts the specified flags in-place.
pub fn remove(&mut self, other: CalendarDisplayOptions)
pub fn remove(&mut self, other: CalendarDisplayOptions)Removes the specified flags in-place.
pub fn toggle(&mut self, other: CalendarDisplayOptions)
pub fn toggle(&mut self, other: CalendarDisplayOptions)Toggles the specified flags in-place.
pub fn set(&mut self, other: CalendarDisplayOptions, value: bool)
pub fn set(&mut self, other: CalendarDisplayOptions, value: bool)Inserts or removes the specified flags depending on the passed value.