Struct gtk::CellAreaBox [−]
pub struct CellAreaBox(_, _);
Methods
impl CellAreaBox[src]
impl CellAreaBoxpub fn new() -> CellAreaBox[src]
pub fn new() -> CellAreaBoxTrait Implementations
impl Clone for CellAreaBox
impl Clone for CellAreaBoxfn clone(&self) -> CellAreaBox
fn clone(&self) -> CellAreaBoxReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for CellAreaBox
impl Hash for CellAreaBoxfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for CellAreaBox
impl Ord for CellAreaBoxfn cmp(&self, other: &CellAreaBox) -> Ordering
fn cmp(&self, other: &CellAreaBox) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for CellAreaBox
impl StaticType for CellAreaBoxfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for CellAreaBox
impl<T: IsA<Object>> PartialEq<T> for CellAreaBoxfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for CellAreaBox
impl Eq for CellAreaBoximpl<T: IsA<Object>> PartialOrd<T> for CellAreaBox
impl<T: IsA<Object>> PartialOrd<T> for CellAreaBoxfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for CellAreaBox
impl Debug for CellAreaBoximpl IsA<CellArea> for CellAreaBox
impl IsA<CellArea> for CellAreaBoximpl IsA<Buildable> for CellAreaBox
impl IsA<Buildable> for CellAreaBoximpl IsA<CellLayout> for CellAreaBox
impl IsA<CellLayout> for CellAreaBoximpl IsA<Orientable> for CellAreaBox
impl IsA<Orientable> for CellAreaBoximpl IsA<Object> for CellAreaBox
impl IsA<Object> for CellAreaBoximpl Default for CellAreaBox[src]
impl Default for CellAreaBoxAuto Trait Implementations
impl !Send for CellAreaBox
impl !Send for CellAreaBoximpl !Sync for CellAreaBox
impl !Sync for CellAreaBox