Struct gtk::CellRendererPixbuf [−]
pub struct CellRendererPixbuf(_, _);
Methods
impl CellRendererPixbuf[src]
impl CellRendererPixbufpub fn new() -> CellRendererPixbuf[src]
pub fn new() -> CellRendererPixbufTrait Implementations
impl Clone for CellRendererPixbuf
impl Clone for CellRendererPixbuffn clone(&self) -> CellRendererPixbuf
fn clone(&self) -> CellRendererPixbufReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for CellRendererPixbuf
impl Hash for CellRendererPixbuffn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for CellRendererPixbuf
impl Ord for CellRendererPixbuffn cmp(&self, other: &CellRendererPixbuf) -> Ordering
fn cmp(&self, other: &CellRendererPixbuf) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for CellRendererPixbuf
impl StaticType for CellRendererPixbuffn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for CellRendererPixbuf
impl<T: IsA<Object>> PartialEq<T> for CellRendererPixbuffn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for CellRendererPixbuf
impl Eq for CellRendererPixbufimpl<T: IsA<Object>> PartialOrd<T> for CellRendererPixbuf
impl<T: IsA<Object>> PartialOrd<T> for CellRendererPixbuffn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for CellRendererPixbuf
impl Debug for CellRendererPixbufimpl IsA<CellRenderer> for CellRendererPixbuf
impl IsA<CellRenderer> for CellRendererPixbufimpl IsA<Object> for CellRendererPixbuf
impl IsA<Object> for CellRendererPixbufimpl Default for CellRendererPixbuf[src]
impl Default for CellRendererPixbufAuto Trait Implementations
impl !Send for CellRendererPixbuf
impl !Send for CellRendererPixbufimpl !Sync for CellRendererPixbuf
impl !Sync for CellRendererPixbuf