Struct gtk::CellRendererText [−]
pub struct CellRendererText(_, _);
Methods
impl CellRendererText[src]
impl CellRendererTextpub fn new() -> CellRendererText[src]
pub fn new() -> CellRendererTextTrait Implementations
impl IsA<CellRendererText> for CellRendererAccel
impl IsA<CellRendererText> for CellRendererAccelimpl IsA<CellRendererText> for CellRendererCombo
impl IsA<CellRendererText> for CellRendererComboimpl IsA<CellRendererText> for CellRendererSpin
impl IsA<CellRendererText> for CellRendererSpinimpl Clone for CellRendererText
impl Clone for CellRendererTextfn clone(&self) -> CellRendererText
fn clone(&self) -> CellRendererTextReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for CellRendererText
impl Hash for CellRendererTextfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for CellRendererText
impl Ord for CellRendererTextfn cmp(&self, other: &CellRendererText) -> Ordering
fn cmp(&self, other: &CellRendererText) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for CellRendererText
impl StaticType for CellRendererTextfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for CellRendererText
impl<T: IsA<Object>> PartialEq<T> for CellRendererTextfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for CellRendererText
impl Eq for CellRendererTextimpl<T: IsA<Object>> PartialOrd<T> for CellRendererText
impl<T: IsA<Object>> PartialOrd<T> for CellRendererTextfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for CellRendererText
impl Debug for CellRendererTextimpl IsA<CellRenderer> for CellRendererText
impl IsA<CellRenderer> for CellRendererTextimpl IsA<Object> for CellRendererText
impl IsA<Object> for CellRendererTextimpl Default for CellRendererText[src]
impl Default for CellRendererTextAuto Trait Implementations
impl !Send for CellRendererText
impl !Send for CellRendererTextimpl !Sync for CellRendererText
impl !Sync for CellRendererText