Struct gtk::CellView [−]
pub struct CellView(_, _);
Methods
impl CellView[src]
impl CellViewpub fn new() -> CellView[src]
pub fn new() -> CellViewpub fn new_with_context<P: IsA<CellArea>>(
area: &P,
context: &CellAreaContext
) -> CellView[src]
pub fn new_with_context<P: IsA<CellArea>>(
area: &P,
context: &CellAreaContext
) -> CellViewpub fn new_with_markup(markup: &str) -> CellView[src]
pub fn new_with_markup(markup: &str) -> CellViewpub fn new_with_pixbuf(pixbuf: &Pixbuf) -> CellView[src]
pub fn new_with_pixbuf(pixbuf: &Pixbuf) -> CellViewpub fn new_with_text(text: &str) -> CellView[src]
pub fn new_with_text(text: &str) -> CellViewTrait Implementations
impl Clone for CellView
impl Clone for CellViewfn clone(&self) -> CellView
fn clone(&self) -> CellViewReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for CellView
impl Hash for CellViewfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for CellView
impl Ord for CellViewfn cmp(&self, other: &CellView) -> Ordering
fn cmp(&self, other: &CellView) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for CellView
impl StaticType for CellViewfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for CellView
impl<T: IsA<Object>> PartialEq<T> for CellViewfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for CellView
impl Eq for CellViewimpl<T: IsA<Object>> PartialOrd<T> for CellView
impl<T: IsA<Object>> PartialOrd<T> for CellViewfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for CellView
impl Debug for CellViewimpl IsA<Widget> for CellView
impl IsA<Widget> for CellViewimpl IsA<Buildable> for CellView
impl IsA<Buildable> for CellViewimpl IsA<CellLayout> for CellView
impl IsA<CellLayout> for CellViewimpl IsA<Orientable> for CellView
impl IsA<Orientable> for CellViewimpl IsA<Object> for CellView
impl IsA<Object> for CellViewimpl Default for CellView[src]
impl Default for CellView