Struct gtk::ColorButton [−]
pub struct ColorButton(_, _);
Methods
impl ColorButton[src]
impl ColorButtonpub fn new() -> ColorButton[src]
pub fn new() -> ColorButtonpub fn new_with_rgba(rgba: &RGBA) -> ColorButton[src]
pub fn new_with_rgba(rgba: &RGBA) -> ColorButtonTrait Implementations
impl Clone for ColorButton
impl Clone for ColorButtonfn clone(&self) -> ColorButton
fn clone(&self) -> ColorButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ColorButton
impl Hash for ColorButtonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ColorButton
impl Ord for ColorButtonfn cmp(&self, other: &ColorButton) -> Ordering
fn cmp(&self, other: &ColorButton) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ColorButton
impl StaticType for ColorButtonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ColorButton
impl<T: IsA<Object>> PartialEq<T> for ColorButtonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ColorButton
impl Eq for ColorButtonimpl<T: IsA<Object>> PartialOrd<T> for ColorButton
impl<T: IsA<Object>> PartialOrd<T> for ColorButtonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ColorButton
impl Debug for ColorButtonimpl IsA<Button> for ColorButton
impl IsA<Button> for ColorButtonimpl IsA<Bin> for ColorButton
impl IsA<Bin> for ColorButtonimpl IsA<Container> for ColorButton
impl IsA<Container> for ColorButtonimpl IsA<Widget> for ColorButton
impl IsA<Widget> for ColorButtonimpl IsA<Buildable> for ColorButton
impl IsA<Buildable> for ColorButtonimpl IsA<Actionable> for ColorButton
impl IsA<Actionable> for ColorButtonimpl IsA<ColorChooser> for ColorButton
impl IsA<ColorChooser> for ColorButtonimpl IsA<Object> for ColorButton
impl IsA<Object> for ColorButtonimpl Default for ColorButton[src]
impl Default for ColorButtonAuto Trait Implementations
impl !Send for ColorButton
impl !Send for ColorButtonimpl !Sync for ColorButton
impl !Sync for ColorButton