Struct gtk::ColorChooserDialog [−]
pub struct ColorChooserDialog(_, _);
Methods
impl ColorChooserDialog[src]
impl ColorChooserDialogpub fn new<'a, 'b, P: Into<Option<&'a str>>, Q: IsA<Window> + 'b, R: Into<Option<&'b Q>>>(
title: P,
parent: R
) -> ColorChooserDialog[src]
pub fn new<'a, 'b, P: Into<Option<&'a str>>, Q: IsA<Window> + 'b, R: Into<Option<&'b Q>>>(
title: P,
parent: R
) -> ColorChooserDialogTrait Implementations
impl Clone for ColorChooserDialog
impl Clone for ColorChooserDialogfn clone(&self) -> ColorChooserDialog
fn clone(&self) -> ColorChooserDialogReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ColorChooserDialog
impl Hash for ColorChooserDialogfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ColorChooserDialog
impl Ord for ColorChooserDialogfn cmp(&self, other: &ColorChooserDialog) -> Ordering
fn cmp(&self, other: &ColorChooserDialog) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ColorChooserDialog
impl StaticType for ColorChooserDialogfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ColorChooserDialog
impl<T: IsA<Object>> PartialEq<T> for ColorChooserDialogfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ColorChooserDialog
impl Eq for ColorChooserDialogimpl<T: IsA<Object>> PartialOrd<T> for ColorChooserDialog
impl<T: IsA<Object>> PartialOrd<T> for ColorChooserDialogfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ColorChooserDialog
impl Debug for ColorChooserDialogimpl IsA<Dialog> for ColorChooserDialog
impl IsA<Dialog> for ColorChooserDialogimpl IsA<Window> for ColorChooserDialog
impl IsA<Window> for ColorChooserDialogimpl IsA<Bin> for ColorChooserDialog
impl IsA<Bin> for ColorChooserDialogimpl IsA<Container> for ColorChooserDialog
impl IsA<Container> for ColorChooserDialogimpl IsA<Widget> for ColorChooserDialog
impl IsA<Widget> for ColorChooserDialogimpl IsA<Buildable> for ColorChooserDialog
impl IsA<Buildable> for ColorChooserDialogimpl IsA<ColorChooser> for ColorChooserDialog
impl IsA<ColorChooser> for ColorChooserDialogimpl IsA<Object> for ColorChooserDialog
impl IsA<Object> for ColorChooserDialogAuto Trait Implementations
impl !Send for ColorChooserDialog
impl !Send for ColorChooserDialogimpl !Sync for ColorChooserDialog
impl !Sync for ColorChooserDialog