Struct gtk::CssSection [−]
pub struct CssSection(_);
Methods
impl CssSection[src]
impl CssSectionpub fn get_end_line(&self) -> u32[src]
pub fn get_end_line(&self) -> u32pub fn get_end_position(&self) -> u32[src]
pub fn get_end_position(&self) -> u32pub fn get_file(&self) -> Option<File>[src]
pub fn get_file(&self) -> Option<File>pub fn get_parent(&self) -> Option<CssSection>[src]
pub fn get_parent(&self) -> Option<CssSection>pub fn get_section_type(&self) -> CssSectionType[src]
pub fn get_section_type(&self) -> CssSectionTypepub fn get_start_line(&self) -> u32[src]
pub fn get_start_line(&self) -> u32pub fn get_start_position(&self) -> u32[src]
pub fn get_start_position(&self) -> u32Trait Implementations
impl Debug for CssSection[src]
impl Debug for CssSectionfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for CssSection[src]
impl PartialEq for CssSectionfn eq(&self, other: &CssSection) -> bool[src]
fn eq(&self, other: &CssSection) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &CssSection) -> bool[src]
fn ne(&self, other: &CssSection) -> boolThis method tests for !=.
impl Eq for CssSection[src]
impl Eq for CssSectionimpl PartialOrd for CssSection[src]
impl PartialOrd for CssSectionfn partial_cmp(&self, other: &CssSection) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &CssSection) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &CssSection) -> bool[src]
fn lt(&self, other: &CssSection) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &CssSection) -> bool[src]
fn le(&self, other: &CssSection) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &CssSection) -> bool[src]
fn gt(&self, other: &CssSection) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &CssSection) -> bool[src]
fn ge(&self, other: &CssSection) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for CssSection[src]
impl Ord for CssSectionfn cmp(&self, other: &CssSection) -> Ordering[src]
fn cmp(&self, other: &CssSection) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for CssSection[src]
impl Hash for CssSectionfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for CssSection
impl Clone for CssSectionfn clone(&self) -> CssSection
fn clone(&self) -> CssSectionReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for CssSection
impl StaticType for CssSectionfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.