Struct gtk::DestDefaults [−]
pub struct DestDefaults { /* fields omitted */ }Methods
impl DestDefaults
impl DestDefaultspub const MOTION: DestDefaults
MOTION: DestDefaults = DestDefaults{bits: 1,}
pub const HIGHLIGHT: DestDefaults
HIGHLIGHT: DestDefaults = DestDefaults{bits: 2,}
pub const DROP: DestDefaults
DROP: DestDefaults = DestDefaults{bits: 4,}
pub const ALL: DestDefaults
ALL: DestDefaults = DestDefaults{bits: 7,}
pub fn empty() -> DestDefaults
pub fn empty() -> DestDefaultsReturns an empty set of flags.
pub fn all() -> DestDefaults
pub fn all() -> DestDefaultsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<DestDefaults>
pub fn from_bits(bits: u32) -> Option<DestDefaults>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> DestDefaults
pub fn from_bits_truncate(bits: u32) -> DestDefaultsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: DestDefaults) -> bool
pub fn intersects(&self, other: DestDefaults) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: DestDefaults) -> bool
pub fn contains(&self, other: DestDefaults) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: DestDefaults)
pub fn insert(&mut self, other: DestDefaults)Inserts the specified flags in-place.
pub fn remove(&mut self, other: DestDefaults)
pub fn remove(&mut self, other: DestDefaults)Removes the specified flags in-place.
pub fn toggle(&mut self, other: DestDefaults)
pub fn toggle(&mut self, other: DestDefaults)Toggles the specified flags in-place.
pub fn set(&mut self, other: DestDefaults, value: bool)
pub fn set(&mut self, other: DestDefaults, value: bool)Inserts or removes the specified flags depending on the passed value.