Struct gtk::Dialog [−]
pub struct Dialog(_, _);
Methods
impl Dialog[src]
impl Dialogimpl Dialog[src]
impl DialogTrait Implementations
impl IsA<Dialog> for AboutDialog
impl IsA<Dialog> for AboutDialogimpl IsA<Dialog> for AppChooserDialog
impl IsA<Dialog> for AppChooserDialogimpl IsA<Dialog> for ColorChooserDialog
impl IsA<Dialog> for ColorChooserDialogimpl Clone for Dialog
impl Clone for Dialogfn clone(&self) -> Dialog
fn clone(&self) -> DialogReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Dialog
impl Hash for Dialogfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Dialog
impl Ord for Dialogfn cmp(&self, other: &Dialog) -> Ordering
fn cmp(&self, other: &Dialog) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Dialog
impl StaticType for Dialogfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Dialog
impl<T: IsA<Object>> PartialEq<T> for Dialogfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Dialog
impl Eq for Dialogimpl<T: IsA<Object>> PartialOrd<T> for Dialog
impl<T: IsA<Object>> PartialOrd<T> for Dialogfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Dialog
impl Debug for Dialogimpl IsA<Window> for Dialog
impl IsA<Window> for Dialogimpl IsA<Bin> for Dialog
impl IsA<Bin> for Dialogimpl IsA<Container> for Dialog
impl IsA<Container> for Dialogimpl IsA<Widget> for Dialog
impl IsA<Widget> for Dialogimpl IsA<Buildable> for Dialog
impl IsA<Buildable> for Dialogimpl IsA<Object> for Dialog
impl IsA<Object> for Dialogimpl Default for Dialog[src]
impl Default for Dialogimpl IsA<Dialog> for FileChooserDialog
impl IsA<Dialog> for FileChooserDialogimpl IsA<Dialog> for FontChooserDialog
impl IsA<Dialog> for FontChooserDialogimpl IsA<Dialog> for MessageDialog
impl IsA<Dialog> for MessageDialogimpl IsA<Dialog> for RecentChooserDialog
impl IsA<Dialog> for RecentChooserDialog