Struct gtk::DialogFlags [−]
pub struct DialogFlags { /* fields omitted */ }Methods
impl DialogFlags
impl DialogFlagspub const MODAL: DialogFlags
MODAL: DialogFlags = DialogFlags{bits: 1,}
pub const DESTROY_WITH_PARENT: DialogFlags
DESTROY_WITH_PARENT: DialogFlags = DialogFlags{bits: 2,}
pub const USE_HEADER_BAR: DialogFlags
USE_HEADER_BAR: DialogFlags = DialogFlags{bits: 4,}
pub fn empty() -> DialogFlags
pub fn empty() -> DialogFlagsReturns an empty set of flags.
pub fn all() -> DialogFlags
pub fn all() -> DialogFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<DialogFlags>
pub fn from_bits(bits: u32) -> Option<DialogFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> DialogFlags
pub fn from_bits_truncate(bits: u32) -> DialogFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: DialogFlags) -> bool
pub fn intersects(&self, other: DialogFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: DialogFlags) -> bool
pub fn contains(&self, other: DialogFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: DialogFlags)
pub fn insert(&mut self, other: DialogFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: DialogFlags)
pub fn remove(&mut self, other: DialogFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: DialogFlags)
pub fn toggle(&mut self, other: DialogFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: DialogFlags, value: bool)
pub fn set(&mut self, other: DialogFlags, value: bool)Inserts or removes the specified flags depending on the passed value.