Struct gtk::DrawingArea [−]
pub struct DrawingArea(_, _);
Methods
impl DrawingArea[src]
impl DrawingAreapub fn new() -> DrawingArea[src]
pub fn new() -> DrawingAreaTrait Implementations
impl Clone for DrawingArea
impl Clone for DrawingAreafn clone(&self) -> DrawingArea
fn clone(&self) -> DrawingAreaReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for DrawingArea
impl Hash for DrawingAreafn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for DrawingArea
impl Ord for DrawingAreafn cmp(&self, other: &DrawingArea) -> Ordering
fn cmp(&self, other: &DrawingArea) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for DrawingArea
impl StaticType for DrawingAreafn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for DrawingArea
impl<T: IsA<Object>> PartialEq<T> for DrawingAreafn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for DrawingArea
impl Eq for DrawingAreaimpl<T: IsA<Object>> PartialOrd<T> for DrawingArea
impl<T: IsA<Object>> PartialOrd<T> for DrawingAreafn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for DrawingArea
impl Debug for DrawingAreaimpl IsA<Widget> for DrawingArea
impl IsA<Widget> for DrawingAreaimpl IsA<Buildable> for DrawingArea
impl IsA<Buildable> for DrawingAreaimpl IsA<Object> for DrawingArea
impl IsA<Object> for DrawingAreaimpl Default for DrawingArea[src]
impl Default for DrawingAreaAuto Trait Implementations
impl !Send for DrawingArea
impl !Send for DrawingAreaimpl !Sync for DrawingArea
impl !Sync for DrawingArea