Struct gtk::Entry [−]
pub struct Entry(_, _);
Methods
impl Entry[src]
impl Entrypub fn new() -> Entry[src]
pub fn new() -> Entrypub fn new_with_buffer(buffer: &EntryBuffer) -> Entry[src]
pub fn new_with_buffer(buffer: &EntryBuffer) -> EntryTrait Implementations
impl Clone for Entry
impl Clone for Entryfn clone(&self) -> Entry
fn clone(&self) -> EntryReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Entry
impl Hash for Entryfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Entry
impl Ord for Entryfn cmp(&self, other: &Entry) -> Ordering
fn cmp(&self, other: &Entry) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Entry
impl StaticType for Entryfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Entry
impl<T: IsA<Object>> PartialEq<T> for Entryfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Entry
impl Eq for Entryimpl<T: IsA<Object>> PartialOrd<T> for Entry
impl<T: IsA<Object>> PartialOrd<T> for Entryfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Entry
impl Debug for Entryimpl IsA<Widget> for Entry
impl IsA<Widget> for Entryimpl IsA<Buildable> for Entry
impl IsA<Buildable> for Entryimpl IsA<CellEditable> for Entry
impl IsA<CellEditable> for Entryimpl IsA<Editable> for Entry
impl IsA<Editable> for Entryimpl IsA<Object> for Entry
impl IsA<Object> for Entryimpl Default for Entry[src]
impl Default for Entryimpl IsA<Entry> for SearchEntry
impl IsA<Entry> for SearchEntryimpl IsA<Entry> for SpinButton
impl IsA<Entry> for SpinButton