Struct gtk::EntryCompletion [−]
pub struct EntryCompletion(_, _);
Methods
impl EntryCompletion[src]
impl EntryCompletionpub fn new() -> EntryCompletion[src]
pub fn new() -> EntryCompletionpub fn new_with_area<P: IsA<CellArea>>(area: &P) -> EntryCompletion[src]
pub fn new_with_area<P: IsA<CellArea>>(area: &P) -> EntryCompletionTrait Implementations
impl Clone for EntryCompletion
impl Clone for EntryCompletionfn clone(&self) -> EntryCompletion
fn clone(&self) -> EntryCompletionReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for EntryCompletion
impl Hash for EntryCompletionfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for EntryCompletion
impl Ord for EntryCompletionfn cmp(&self, other: &EntryCompletion) -> Ordering
fn cmp(&self, other: &EntryCompletion) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for EntryCompletion
impl StaticType for EntryCompletionfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for EntryCompletion
impl<T: IsA<Object>> PartialEq<T> for EntryCompletionfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for EntryCompletion
impl Eq for EntryCompletionimpl<T: IsA<Object>> PartialOrd<T> for EntryCompletion
impl<T: IsA<Object>> PartialOrd<T> for EntryCompletionfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for EntryCompletion
impl Debug for EntryCompletionimpl IsA<Buildable> for EntryCompletion
impl IsA<Buildable> for EntryCompletionimpl IsA<CellLayout> for EntryCompletion
impl IsA<CellLayout> for EntryCompletionimpl IsA<Object> for EntryCompletion
impl IsA<Object> for EntryCompletionimpl Default for EntryCompletion[src]
impl Default for EntryCompletionAuto Trait Implementations
impl !Send for EntryCompletion
impl !Send for EntryCompletionimpl !Sync for EntryCompletion
impl !Sync for EntryCompletion