Struct gtk::EventBox [−]
pub struct EventBox(_, _);
Methods
impl EventBox[src]
impl EventBoxTrait Implementations
impl Clone for EventBox
impl Clone for EventBoxfn clone(&self) -> EventBox
fn clone(&self) -> EventBoxReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for EventBox
impl Hash for EventBoxfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for EventBox
impl Ord for EventBoxfn cmp(&self, other: &EventBox) -> Ordering
fn cmp(&self, other: &EventBox) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for EventBox
impl StaticType for EventBoxfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for EventBox
impl<T: IsA<Object>> PartialEq<T> for EventBoxfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for EventBox
impl Eq for EventBoximpl<T: IsA<Object>> PartialOrd<T> for EventBox
impl<T: IsA<Object>> PartialOrd<T> for EventBoxfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for EventBox
impl Debug for EventBoximpl IsA<Bin> for EventBox
impl IsA<Bin> for EventBoximpl IsA<Container> for EventBox
impl IsA<Container> for EventBoximpl IsA<Widget> for EventBox
impl IsA<Widget> for EventBoximpl IsA<Buildable> for EventBox
impl IsA<Buildable> for EventBoximpl IsA<Object> for EventBox
impl IsA<Object> for EventBoximpl Default for EventBox[src]
impl Default for EventBox