Struct gtk::Expander [−]
pub struct Expander(_, _);
Methods
impl Expander[src]
impl Expanderpub fn new<'a, P: Into<Option<&'a str>>>(label: P) -> Expander[src]
pub fn new<'a, P: Into<Option<&'a str>>>(label: P) -> Expanderpub fn new_with_mnemonic(label: &str) -> Expander[src]
pub fn new_with_mnemonic(label: &str) -> ExpanderTrait Implementations
impl Clone for Expander
impl Clone for Expanderfn clone(&self) -> Expander
fn clone(&self) -> ExpanderReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Expander
impl Hash for Expanderfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Expander
impl Ord for Expanderfn cmp(&self, other: &Expander) -> Ordering
fn cmp(&self, other: &Expander) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Expander
impl StaticType for Expanderfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Expander
impl<T: IsA<Object>> PartialEq<T> for Expanderfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Expander
impl Eq for Expanderimpl<T: IsA<Object>> PartialOrd<T> for Expander
impl<T: IsA<Object>> PartialOrd<T> for Expanderfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Expander
impl Debug for Expanderimpl IsA<Bin> for Expander
impl IsA<Bin> for Expanderimpl IsA<Container> for Expander
impl IsA<Container> for Expanderimpl IsA<Widget> for Expander
impl IsA<Widget> for Expanderimpl IsA<Buildable> for Expander
impl IsA<Buildable> for Expanderimpl IsA<Object> for Expander
impl IsA<Object> for Expander