Struct gtk::FileChooserButton [−]
pub struct FileChooserButton(_, _);
Methods
impl FileChooserButton[src]
impl FileChooserButtonpub fn new(title: &str, action: FileChooserAction) -> FileChooserButton[src]
pub fn new(title: &str, action: FileChooserAction) -> FileChooserButtonpub fn new_with_dialog<P: IsA<Dialog>>(dialog: &P) -> FileChooserButton[src]
pub fn new_with_dialog<P: IsA<Dialog>>(dialog: &P) -> FileChooserButtonTrait Implementations
impl Clone for FileChooserButton
impl Clone for FileChooserButtonfn clone(&self) -> FileChooserButton
fn clone(&self) -> FileChooserButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for FileChooserButton
impl Hash for FileChooserButtonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for FileChooserButton
impl Ord for FileChooserButtonfn cmp(&self, other: &FileChooserButton) -> Ordering
fn cmp(&self, other: &FileChooserButton) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for FileChooserButton
impl StaticType for FileChooserButtonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for FileChooserButton
impl<T: IsA<Object>> PartialEq<T> for FileChooserButtonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for FileChooserButton
impl Eq for FileChooserButtonimpl<T: IsA<Object>> PartialOrd<T> for FileChooserButton
impl<T: IsA<Object>> PartialOrd<T> for FileChooserButtonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for FileChooserButton
impl Debug for FileChooserButtonimpl IsA<Box> for FileChooserButton
impl IsA<Box> for FileChooserButtonimpl IsA<Container> for FileChooserButton
impl IsA<Container> for FileChooserButtonimpl IsA<Widget> for FileChooserButton
impl IsA<Widget> for FileChooserButtonimpl IsA<Buildable> for FileChooserButton
impl IsA<Buildable> for FileChooserButtonimpl IsA<Orientable> for FileChooserButton
impl IsA<Orientable> for FileChooserButtonimpl IsA<FileChooser> for FileChooserButton
impl IsA<FileChooser> for FileChooserButtonimpl IsA<Object> for FileChooserButton
impl IsA<Object> for FileChooserButtonAuto Trait Implementations
impl !Send for FileChooserButton
impl !Send for FileChooserButtonimpl !Sync for FileChooserButton
impl !Sync for FileChooserButton