Struct gtk::FileChooserDialog [−]
pub struct FileChooserDialog(_, _);
Methods
impl FileChooserDialog[src]
impl FileChooserDialogpub fn new<T: IsA<Window>>(
title: Option<&str>,
parent: Option<&T>,
action: FileChooserAction
) -> FileChooserDialog[src]
pub fn new<T: IsA<Window>>(
title: Option<&str>,
parent: Option<&T>,
action: FileChooserAction
) -> FileChooserDialogTrait Implementations
impl Clone for FileChooserDialog
impl Clone for FileChooserDialogfn clone(&self) -> FileChooserDialog
fn clone(&self) -> FileChooserDialogReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for FileChooserDialog
impl Hash for FileChooserDialogfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for FileChooserDialog
impl Ord for FileChooserDialogfn cmp(&self, other: &FileChooserDialog) -> Ordering
fn cmp(&self, other: &FileChooserDialog) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for FileChooserDialog
impl StaticType for FileChooserDialogfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for FileChooserDialog
impl<T: IsA<Object>> PartialEq<T> for FileChooserDialogfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for FileChooserDialog
impl Eq for FileChooserDialogimpl<T: IsA<Object>> PartialOrd<T> for FileChooserDialog
impl<T: IsA<Object>> PartialOrd<T> for FileChooserDialogfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for FileChooserDialog
impl Debug for FileChooserDialogimpl IsA<Dialog> for FileChooserDialog
impl IsA<Dialog> for FileChooserDialogimpl IsA<Window> for FileChooserDialog
impl IsA<Window> for FileChooserDialogimpl IsA<Bin> for FileChooserDialog
impl IsA<Bin> for FileChooserDialogimpl IsA<Container> for FileChooserDialog
impl IsA<Container> for FileChooserDialogimpl IsA<Widget> for FileChooserDialog
impl IsA<Widget> for FileChooserDialogimpl IsA<Buildable> for FileChooserDialog
impl IsA<Buildable> for FileChooserDialogimpl IsA<FileChooser> for FileChooserDialog
impl IsA<FileChooser> for FileChooserDialogimpl IsA<Object> for FileChooserDialog
impl IsA<Object> for FileChooserDialogAuto Trait Implementations
impl !Send for FileChooserDialog
impl !Send for FileChooserDialogimpl !Sync for FileChooserDialog
impl !Sync for FileChooserDialog