Struct gtk::FileFilter [−]
pub struct FileFilter(_, _);
Methods
impl FileFilter[src]
impl FileFilterpub fn new() -> FileFilter[src]
pub fn new() -> FileFilterTrait Implementations
impl Clone for FileFilter
impl Clone for FileFilterfn clone(&self) -> FileFilter
fn clone(&self) -> FileFilterReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for FileFilter
impl Hash for FileFilterfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for FileFilter
impl Ord for FileFilterfn cmp(&self, other: &FileFilter) -> Ordering
fn cmp(&self, other: &FileFilter) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for FileFilter
impl StaticType for FileFilterfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for FileFilter
impl<T: IsA<Object>> PartialEq<T> for FileFilterfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for FileFilter
impl Eq for FileFilterimpl<T: IsA<Object>> PartialOrd<T> for FileFilter
impl<T: IsA<Object>> PartialOrd<T> for FileFilterfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for FileFilter
impl Debug for FileFilterimpl IsA<Buildable> for FileFilter
impl IsA<Buildable> for FileFilterimpl IsA<Object> for FileFilter
impl IsA<Object> for FileFilterimpl Default for FileFilter[src]
impl Default for FileFilterAuto Trait Implementations
impl !Send for FileFilter
impl !Send for FileFilterimpl !Sync for FileFilter
impl !Sync for FileFilter