Struct gtk::FileFilterFlags [−]
pub struct FileFilterFlags { /* fields omitted */ }Methods
impl FileFilterFlags
impl FileFilterFlagspub const FILENAME: FileFilterFlags
FILENAME: FileFilterFlags = FileFilterFlags{bits: 1,}
pub const URI: FileFilterFlags
URI: FileFilterFlags = FileFilterFlags{bits: 2,}
pub const DISPLAY_NAME: FileFilterFlags
DISPLAY_NAME: FileFilterFlags = FileFilterFlags{bits: 4,}
pub const MIME_TYPE: FileFilterFlags
MIME_TYPE: FileFilterFlags = FileFilterFlags{bits: 8,}
pub fn empty() -> FileFilterFlags
pub fn empty() -> FileFilterFlagsReturns an empty set of flags.
pub fn all() -> FileFilterFlags
pub fn all() -> FileFilterFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<FileFilterFlags>
pub fn from_bits(bits: u32) -> Option<FileFilterFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> FileFilterFlags
pub fn from_bits_truncate(bits: u32) -> FileFilterFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: FileFilterFlags) -> bool
pub fn intersects(&self, other: FileFilterFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: FileFilterFlags) -> bool
pub fn contains(&self, other: FileFilterFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: FileFilterFlags)
pub fn insert(&mut self, other: FileFilterFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: FileFilterFlags)
pub fn remove(&mut self, other: FileFilterFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: FileFilterFlags)
pub fn toggle(&mut self, other: FileFilterFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: FileFilterFlags, value: bool)
pub fn set(&mut self, other: FileFilterFlags, value: bool)Inserts or removes the specified flags depending on the passed value.