Struct gtk::FontButton [−]
pub struct FontButton(_, _);
Methods
impl FontButton[src]
impl FontButtonpub fn new() -> FontButton[src]
pub fn new() -> FontButtonpub fn new_with_font(fontname: &str) -> FontButton[src]
pub fn new_with_font(fontname: &str) -> FontButtonTrait Implementations
impl Clone for FontButton
impl Clone for FontButtonfn clone(&self) -> FontButton
fn clone(&self) -> FontButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for FontButton
impl Hash for FontButtonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for FontButton
impl Ord for FontButtonfn cmp(&self, other: &FontButton) -> Ordering
fn cmp(&self, other: &FontButton) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for FontButton
impl StaticType for FontButtonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for FontButton
impl<T: IsA<Object>> PartialEq<T> for FontButtonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for FontButton
impl Eq for FontButtonimpl<T: IsA<Object>> PartialOrd<T> for FontButton
impl<T: IsA<Object>> PartialOrd<T> for FontButtonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for FontButton
impl Debug for FontButtonimpl IsA<Button> for FontButton
impl IsA<Button> for FontButtonimpl IsA<Bin> for FontButton
impl IsA<Bin> for FontButtonimpl IsA<Container> for FontButton
impl IsA<Container> for FontButtonimpl IsA<Widget> for FontButton
impl IsA<Widget> for FontButtonimpl IsA<Buildable> for FontButton
impl IsA<Buildable> for FontButtonimpl IsA<Actionable> for FontButton
impl IsA<Actionable> for FontButtonimpl IsA<FontChooser> for FontButton
impl IsA<FontChooser> for FontButtonimpl IsA<Object> for FontButton
impl IsA<Object> for FontButtonimpl Default for FontButton[src]
impl Default for FontButtonAuto Trait Implementations
impl !Send for FontButton
impl !Send for FontButtonimpl !Sync for FontButton
impl !Sync for FontButton