Struct gtk::FontChooserDialog [−]
pub struct FontChooserDialog(_, _);
Methods
impl FontChooserDialog[src]
impl FontChooserDialogpub fn new<'a, 'b, P: Into<Option<&'a str>>, Q: IsA<Window> + 'b, R: Into<Option<&'b Q>>>(
title: P,
parent: R
) -> FontChooserDialog[src]
pub fn new<'a, 'b, P: Into<Option<&'a str>>, Q: IsA<Window> + 'b, R: Into<Option<&'b Q>>>(
title: P,
parent: R
) -> FontChooserDialogTrait Implementations
impl Clone for FontChooserDialog
impl Clone for FontChooserDialogfn clone(&self) -> FontChooserDialog
fn clone(&self) -> FontChooserDialogReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for FontChooserDialog
impl Hash for FontChooserDialogfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for FontChooserDialog
impl Ord for FontChooserDialogfn cmp(&self, other: &FontChooserDialog) -> Ordering
fn cmp(&self, other: &FontChooserDialog) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for FontChooserDialog
impl StaticType for FontChooserDialogfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for FontChooserDialog
impl<T: IsA<Object>> PartialEq<T> for FontChooserDialogfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for FontChooserDialog
impl Eq for FontChooserDialogimpl<T: IsA<Object>> PartialOrd<T> for FontChooserDialog
impl<T: IsA<Object>> PartialOrd<T> for FontChooserDialogfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for FontChooserDialog
impl Debug for FontChooserDialogimpl IsA<Dialog> for FontChooserDialog
impl IsA<Dialog> for FontChooserDialogimpl IsA<Window> for FontChooserDialog
impl IsA<Window> for FontChooserDialogimpl IsA<Bin> for FontChooserDialog
impl IsA<Bin> for FontChooserDialogimpl IsA<Container> for FontChooserDialog
impl IsA<Container> for FontChooserDialogimpl IsA<Widget> for FontChooserDialog
impl IsA<Widget> for FontChooserDialogimpl IsA<Buildable> for FontChooserDialog
impl IsA<Buildable> for FontChooserDialogimpl IsA<FontChooser> for FontChooserDialog
impl IsA<FontChooser> for FontChooserDialogimpl IsA<Object> for FontChooserDialog
impl IsA<Object> for FontChooserDialogAuto Trait Implementations
impl !Send for FontChooserDialog
impl !Send for FontChooserDialogimpl !Sync for FontChooserDialog
impl !Sync for FontChooserDialog