Struct gtk::FontChooserWidget [−]
pub struct FontChooserWidget(_, _);
Methods
impl FontChooserWidget[src]
impl FontChooserWidgetpub fn new() -> FontChooserWidget[src]
pub fn new() -> FontChooserWidgetTrait Implementations
impl Clone for FontChooserWidget
impl Clone for FontChooserWidgetfn clone(&self) -> FontChooserWidget
fn clone(&self) -> FontChooserWidgetReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for FontChooserWidget
impl Hash for FontChooserWidgetfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for FontChooserWidget
impl Ord for FontChooserWidgetfn cmp(&self, other: &FontChooserWidget) -> Ordering
fn cmp(&self, other: &FontChooserWidget) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for FontChooserWidget
impl StaticType for FontChooserWidgetfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for FontChooserWidget
impl<T: IsA<Object>> PartialEq<T> for FontChooserWidgetfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for FontChooserWidget
impl Eq for FontChooserWidgetimpl<T: IsA<Object>> PartialOrd<T> for FontChooserWidget
impl<T: IsA<Object>> PartialOrd<T> for FontChooserWidgetfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for FontChooserWidget
impl Debug for FontChooserWidgetimpl IsA<Box> for FontChooserWidget
impl IsA<Box> for FontChooserWidgetimpl IsA<Container> for FontChooserWidget
impl IsA<Container> for FontChooserWidgetimpl IsA<Widget> for FontChooserWidget
impl IsA<Widget> for FontChooserWidgetimpl IsA<Buildable> for FontChooserWidget
impl IsA<Buildable> for FontChooserWidgetimpl IsA<Orientable> for FontChooserWidget
impl IsA<Orientable> for FontChooserWidgetimpl IsA<FontChooser> for FontChooserWidget
impl IsA<FontChooser> for FontChooserWidgetimpl IsA<Object> for FontChooserWidget
impl IsA<Object> for FontChooserWidgetimpl Default for FontChooserWidget[src]
impl Default for FontChooserWidgetAuto Trait Implementations
impl !Send for FontChooserWidget
impl !Send for FontChooserWidgetimpl !Sync for FontChooserWidget
impl !Sync for FontChooserWidget