Struct gtk::Frame [−]
pub struct Frame(_, _);
Methods
impl Frame[src]
impl FrameTrait Implementations
impl IsA<Frame> for AspectFrame
impl IsA<Frame> for AspectFrameimpl Clone for Frame
impl Clone for Framefn clone(&self) -> Frame
fn clone(&self) -> FrameReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Frame
impl Hash for Framefn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Frame
impl Ord for Framefn cmp(&self, other: &Frame) -> Ordering
fn cmp(&self, other: &Frame) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Frame
impl StaticType for Framefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Frame
impl<T: IsA<Object>> PartialEq<T> for Framefn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Frame
impl Eq for Frameimpl<T: IsA<Object>> PartialOrd<T> for Frame
impl<T: IsA<Object>> PartialOrd<T> for Framefn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Frame
impl Debug for Frameimpl IsA<Bin> for Frame
impl IsA<Bin> for Frameimpl IsA<Container> for Frame
impl IsA<Container> for Frameimpl IsA<Widget> for Frame
impl IsA<Widget> for Frameimpl IsA<Buildable> for Frame
impl IsA<Buildable> for Frameimpl IsA<Object> for Frame
impl IsA<Object> for Frame