Struct gtk::IconFactory [−]
pub struct IconFactory(_, _);
Methods
impl IconFactory[src]
impl IconFactorypub fn new() -> IconFactory[src]
pub fn new() -> IconFactorypub fn lookup_default(stock_id: &str) -> Option<IconSet>[src]
pub fn lookup_default(stock_id: &str) -> Option<IconSet>Trait Implementations
impl Clone for IconFactory
impl Clone for IconFactoryfn clone(&self) -> IconFactory
fn clone(&self) -> IconFactoryReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for IconFactory
impl Hash for IconFactoryfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for IconFactory
impl Ord for IconFactoryfn cmp(&self, other: &IconFactory) -> Ordering
fn cmp(&self, other: &IconFactory) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for IconFactory
impl StaticType for IconFactoryfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for IconFactory
impl<T: IsA<Object>> PartialEq<T> for IconFactoryfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for IconFactory
impl Eq for IconFactoryimpl<T: IsA<Object>> PartialOrd<T> for IconFactory
impl<T: IsA<Object>> PartialOrd<T> for IconFactoryfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for IconFactory
impl Debug for IconFactoryimpl IsA<Buildable> for IconFactory
impl IsA<Buildable> for IconFactoryimpl IsA<Object> for IconFactory
impl IsA<Object> for IconFactoryimpl Default for IconFactory[src]
impl Default for IconFactoryAuto Trait Implementations
impl !Send for IconFactory
impl !Send for IconFactoryimpl !Sync for IconFactory
impl !Sync for IconFactory