Struct gtk::IconLookupFlags [−]
pub struct IconLookupFlags { /* fields omitted */ }Methods
impl IconLookupFlags
impl IconLookupFlagspub const NO_SVG: IconLookupFlags
NO_SVG: IconLookupFlags = IconLookupFlags{bits: 1,}
pub const FORCE_SVG: IconLookupFlags
FORCE_SVG: IconLookupFlags = IconLookupFlags{bits: 2,}
pub const USE_BUILTIN: IconLookupFlags
USE_BUILTIN: IconLookupFlags = IconLookupFlags{bits: 4,}
pub const GENERIC_FALLBACK: IconLookupFlags
GENERIC_FALLBACK: IconLookupFlags = IconLookupFlags{bits: 8,}
pub const FORCE_SIZE: IconLookupFlags
FORCE_SIZE: IconLookupFlags = IconLookupFlags{bits: 16,}
pub const FORCE_REGULAR: IconLookupFlags
FORCE_REGULAR: IconLookupFlags = IconLookupFlags{bits: 32,}
pub const FORCE_SYMBOLIC: IconLookupFlags
FORCE_SYMBOLIC: IconLookupFlags = IconLookupFlags{bits: 64,}
pub const DIR_LTR: IconLookupFlags
DIR_LTR: IconLookupFlags = IconLookupFlags{bits: 128,}
pub const DIR_RTL: IconLookupFlags
DIR_RTL: IconLookupFlags = IconLookupFlags{bits: 256,}
pub fn empty() -> IconLookupFlags
pub fn empty() -> IconLookupFlagsReturns an empty set of flags.
pub fn all() -> IconLookupFlags
pub fn all() -> IconLookupFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<IconLookupFlags>
pub fn from_bits(bits: u32) -> Option<IconLookupFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> IconLookupFlags
pub fn from_bits_truncate(bits: u32) -> IconLookupFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: IconLookupFlags) -> bool
pub fn intersects(&self, other: IconLookupFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: IconLookupFlags) -> bool
pub fn contains(&self, other: IconLookupFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: IconLookupFlags)
pub fn insert(&mut self, other: IconLookupFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: IconLookupFlags)
pub fn remove(&mut self, other: IconLookupFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: IconLookupFlags)
pub fn toggle(&mut self, other: IconLookupFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: IconLookupFlags, value: bool)
pub fn set(&mut self, other: IconLookupFlags, value: bool)Inserts or removes the specified flags depending on the passed value.