Struct gtk::IconSet [−]
pub struct IconSet(_);
Methods
impl IconSet[src]
impl IconSetpub fn new() -> IconSet[src]
pub fn new() -> IconSetpub fn new_from_pixbuf(pixbuf: &Pixbuf) -> IconSet[src]
pub fn new_from_pixbuf(pixbuf: &Pixbuf) -> IconSetpub fn add_source(&self, source: &IconSource)[src]
pub fn add_source(&self, source: &IconSource)pub fn copy(&self) -> Option<IconSet>[src]
pub fn copy(&self) -> Option<IconSet>pub fn get_sizes(&self) -> Vec<i32>[src]
pub fn get_sizes(&self) -> Vec<i32>pub fn render_icon_pixbuf(
&self,
context: &StyleContext,
size: i32
) -> Option<Pixbuf>[src]
pub fn render_icon_pixbuf(
&self,
context: &StyleContext,
size: i32
) -> Option<Pixbuf>pub fn render_icon_surface<'a, P: Into<Option<&'a Window>>>(
&self,
context: &StyleContext,
size: i32,
scale: i32,
for_window: P
) -> Option<Surface>[src]
pub fn render_icon_surface<'a, P: Into<Option<&'a Window>>>(
&self,
context: &StyleContext,
size: i32,
scale: i32,
for_window: P
) -> Option<Surface>Trait Implementations
impl Debug for IconSet[src]
impl Debug for IconSetfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for IconSet[src]
impl PartialEq for IconSetfn eq(&self, other: &IconSet) -> bool[src]
fn eq(&self, other: &IconSet) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IconSet) -> bool[src]
fn ne(&self, other: &IconSet) -> boolThis method tests for !=.
impl Eq for IconSet[src]
impl Eq for IconSetimpl PartialOrd for IconSet[src]
impl PartialOrd for IconSetfn partial_cmp(&self, other: &IconSet) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &IconSet) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &IconSet) -> bool[src]
fn lt(&self, other: &IconSet) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &IconSet) -> bool[src]
fn le(&self, other: &IconSet) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &IconSet) -> bool[src]
fn gt(&self, other: &IconSet) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &IconSet) -> bool[src]
fn ge(&self, other: &IconSet) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for IconSet[src]
impl Ord for IconSetfn cmp(&self, other: &IconSet) -> Ordering[src]
fn cmp(&self, other: &IconSet) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for IconSet[src]
impl Hash for IconSetfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for IconSet
impl Clone for IconSetfn clone(&self) -> IconSet
fn clone(&self) -> IconSetReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for IconSet
impl StaticType for IconSetfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Default for IconSet[src]
impl Default for IconSet