Struct gtk::IconSource [−]
pub struct IconSource(_);
Methods
impl IconSource[src]
impl IconSourcepub fn new() -> IconSource[src]
pub fn new() -> IconSourcepub fn get_direction(&self) -> TextDirection[src]
pub fn get_direction(&self) -> TextDirectionpub fn get_direction_wildcarded(&self) -> bool[src]
pub fn get_direction_wildcarded(&self) -> boolpub fn get_filename(&self) -> Option<PathBuf>[src]
pub fn get_filename(&self) -> Option<PathBuf>pub fn get_icon_name(&self) -> Option<String>[src]
pub fn get_icon_name(&self) -> Option<String>pub fn get_pixbuf(&self) -> Option<Pixbuf>[src]
pub fn get_pixbuf(&self) -> Option<Pixbuf>pub fn get_size(&self) -> i32[src]
pub fn get_size(&self) -> i32pub fn get_size_wildcarded(&self) -> bool[src]
pub fn get_size_wildcarded(&self) -> boolpub fn get_state(&self) -> StateType[src]
pub fn get_state(&self) -> StateTypepub fn get_state_wildcarded(&self) -> bool[src]
pub fn get_state_wildcarded(&self) -> boolpub fn set_direction(&mut self, direction: TextDirection)[src]
pub fn set_direction(&mut self, direction: TextDirection)pub fn set_direction_wildcarded(&mut self, setting: bool)[src]
pub fn set_direction_wildcarded(&mut self, setting: bool)pub fn set_filename<P: AsRef<Path>>(&mut self, filename: P)[src]
pub fn set_filename<P: AsRef<Path>>(&mut self, filename: P)pub fn set_icon_name<'a, P: Into<Option<&'a str>>>(&mut self, icon_name: P)[src]
pub fn set_icon_name<'a, P: Into<Option<&'a str>>>(&mut self, icon_name: P)pub fn set_pixbuf(&mut self, pixbuf: &Pixbuf)[src]
pub fn set_pixbuf(&mut self, pixbuf: &Pixbuf)pub fn set_size(&mut self, size: i32)[src]
pub fn set_size(&mut self, size: i32)pub fn set_size_wildcarded(&mut self, setting: bool)[src]
pub fn set_size_wildcarded(&mut self, setting: bool)pub fn set_state(&mut self, state: StateType)[src]
pub fn set_state(&mut self, state: StateType)pub fn set_state_wildcarded(&mut self, setting: bool)[src]
pub fn set_state_wildcarded(&mut self, setting: bool)Trait Implementations
impl Debug for IconSource[src]
impl Debug for IconSourcefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for IconSource[src]
impl PartialEq for IconSourcefn eq(&self, other: &IconSource) -> bool[src]
fn eq(&self, other: &IconSource) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IconSource) -> bool[src]
fn ne(&self, other: &IconSource) -> boolThis method tests for !=.
impl Eq for IconSource[src]
impl Eq for IconSourceimpl PartialOrd for IconSource[src]
impl PartialOrd for IconSourcefn partial_cmp(&self, other: &IconSource) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &IconSource) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &IconSource) -> bool[src]
fn lt(&self, other: &IconSource) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &IconSource) -> bool[src]
fn le(&self, other: &IconSource) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &IconSource) -> bool[src]
fn gt(&self, other: &IconSource) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &IconSource) -> bool[src]
fn ge(&self, other: &IconSource) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for IconSource[src]
impl Ord for IconSourcefn cmp(&self, other: &IconSource) -> Ordering[src]
fn cmp(&self, other: &IconSource) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for IconSource[src]
impl Hash for IconSourcefn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for IconSource
impl Clone for IconSourcefn clone(&self) -> IconSource
fn clone(&self) -> IconSourceReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for IconSource
impl StaticType for IconSourcefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Default for IconSource[src]
impl Default for IconSourceAuto Trait Implementations
impl !Send for IconSource
impl !Send for IconSourceimpl !Sync for IconSource
impl !Sync for IconSource