Struct gtk::IconTheme [−]
pub struct IconTheme(_, _);
Methods
impl IconTheme[src]
impl IconThemepub fn new() -> IconTheme[src]
pub fn new() -> IconThemepub fn add_builtin_icon(icon_name: &str, size: i32, pixbuf: &Pixbuf)[src]
pub fn add_builtin_icon(icon_name: &str, size: i32, pixbuf: &Pixbuf)pub fn get_default() -> Option<IconTheme>[src]
pub fn get_default() -> Option<IconTheme>pub fn get_for_screen(screen: &Screen) -> Option<IconTheme>[src]
pub fn get_for_screen(screen: &Screen) -> Option<IconTheme>Trait Implementations
impl Clone for IconTheme
impl Clone for IconThemefn clone(&self) -> IconTheme
fn clone(&self) -> IconThemeReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for IconTheme
impl Hash for IconThemefn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for IconTheme
impl Ord for IconThemefn cmp(&self, other: &IconTheme) -> Ordering
fn cmp(&self, other: &IconTheme) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for IconTheme
impl StaticType for IconThemefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for IconTheme
impl<T: IsA<Object>> PartialEq<T> for IconThemefn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for IconTheme
impl Eq for IconThemeimpl<T: IsA<Object>> PartialOrd<T> for IconTheme
impl<T: IsA<Object>> PartialOrd<T> for IconThemefn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for IconTheme
impl Debug for IconThemeimpl IsA<Object> for IconTheme
impl IsA<Object> for IconThemeimpl Default for IconTheme[src]
impl Default for IconTheme