Struct gtk::Image [−]
pub struct Image(_, _);
Methods
impl Image[src]
impl Imagepub fn new() -> Image[src]
pub fn new() -> Imagepub fn new_from_animation<P: IsA<PixbufAnimation>>(animation: &P) -> Image[src]
pub fn new_from_animation<P: IsA<PixbufAnimation>>(animation: &P) -> Imagepub fn new_from_file<P: AsRef<Path>>(filename: P) -> Image[src]
pub fn new_from_file<P: AsRef<Path>>(filename: P) -> Imagepub fn new_from_gicon<P: IsA<Icon>>(icon: &P, size: i32) -> Image[src]
pub fn new_from_gicon<P: IsA<Icon>>(icon: &P, size: i32) -> Imagepub fn new_from_icon_name<'a, P: Into<Option<&'a str>>>(
icon_name: P,
size: i32
) -> Image[src]
pub fn new_from_icon_name<'a, P: Into<Option<&'a str>>>(
icon_name: P,
size: i32
) -> Imagepub fn new_from_icon_set(icon_set: &IconSet, size: i32) -> Image[src]
pub fn new_from_icon_set(icon_set: &IconSet, size: i32) -> Imagepub fn new_from_pixbuf<'a, P: Into<Option<&'a Pixbuf>>>(pixbuf: P) -> Image[src]
pub fn new_from_pixbuf<'a, P: Into<Option<&'a Pixbuf>>>(pixbuf: P) -> Imagepub fn new_from_resource(resource_path: &str) -> Image[src]
pub fn new_from_resource(resource_path: &str) -> Imagepub fn new_from_stock(stock_id: &str, size: i32) -> Image[src]
pub fn new_from_stock(stock_id: &str, size: i32) -> Imagepub fn new_from_surface<'a, P: Into<Option<&'a Surface>>>(surface: P) -> Image[src]
pub fn new_from_surface<'a, P: Into<Option<&'a Surface>>>(surface: P) -> ImageTrait Implementations
impl Clone for Image
impl Clone for Imagefn clone(&self) -> Image
fn clone(&self) -> ImageReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Image
impl Hash for Imagefn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Image
impl Ord for Imagefn cmp(&self, other: &Image) -> Ordering
fn cmp(&self, other: &Image) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Image
impl StaticType for Imagefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Image
impl<T: IsA<Object>> PartialEq<T> for Imagefn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Image
impl Eq for Imageimpl<T: IsA<Object>> PartialOrd<T> for Image
impl<T: IsA<Object>> PartialOrd<T> for Imagefn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Image
impl Debug for Imageimpl IsA<Misc> for Image
impl IsA<Misc> for Imageimpl IsA<Widget> for Image
impl IsA<Widget> for Imageimpl IsA<Buildable> for Image
impl IsA<Buildable> for Imageimpl IsA<Object> for Image
impl IsA<Object> for Imageimpl Default for Image[src]
impl Default for Image