Struct gtk::InfoBar [−]
pub struct InfoBar(_, _);
Methods
impl InfoBar[src]
impl InfoBarTrait Implementations
impl Clone for InfoBar
impl Clone for InfoBarfn clone(&self) -> InfoBar
fn clone(&self) -> InfoBarReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for InfoBar
impl Hash for InfoBarfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for InfoBar
impl Ord for InfoBarfn cmp(&self, other: &InfoBar) -> Ordering
fn cmp(&self, other: &InfoBar) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for InfoBar
impl StaticType for InfoBarfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for InfoBar
impl<T: IsA<Object>> PartialEq<T> for InfoBarfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for InfoBar
impl Eq for InfoBarimpl<T: IsA<Object>> PartialOrd<T> for InfoBar
impl<T: IsA<Object>> PartialOrd<T> for InfoBarfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for InfoBar
impl Debug for InfoBarimpl IsA<Box> for InfoBar
impl IsA<Box> for InfoBarimpl IsA<Container> for InfoBar
impl IsA<Container> for InfoBarimpl IsA<Widget> for InfoBar
impl IsA<Widget> for InfoBarimpl IsA<Buildable> for InfoBar
impl IsA<Buildable> for InfoBarimpl IsA<Orientable> for InfoBar
impl IsA<Orientable> for InfoBarimpl IsA<Object> for InfoBar
impl IsA<Object> for InfoBarimpl Default for InfoBar[src]
impl Default for InfoBar