Struct gtk::InputHints [−]
pub struct InputHints { /* fields omitted */ }Methods
impl InputHints
impl InputHintspub const NONE: InputHints
NONE: InputHints = InputHints{bits: 0,}
pub const SPELLCHECK: InputHints
SPELLCHECK: InputHints = InputHints{bits: 1,}
pub const NO_SPELLCHECK: InputHints
NO_SPELLCHECK: InputHints = InputHints{bits: 2,}
pub const WORD_COMPLETION: InputHints
WORD_COMPLETION: InputHints = InputHints{bits: 4,}
pub const LOWERCASE: InputHints
LOWERCASE: InputHints = InputHints{bits: 8,}
pub const UPPERCASE_CHARS: InputHints
UPPERCASE_CHARS: InputHints = InputHints{bits: 16,}
pub const UPPERCASE_WORDS: InputHints
UPPERCASE_WORDS: InputHints = InputHints{bits: 32,}
pub const UPPERCASE_SENTENCES: InputHints
UPPERCASE_SENTENCES: InputHints = InputHints{bits: 64,}
pub const INHIBIT_OSK: InputHints
INHIBIT_OSK: InputHints = InputHints{bits: 128,}
pub const VERTICAL_WRITING: InputHints
VERTICAL_WRITING: InputHints = InputHints{bits: 256,}
pub fn empty() -> InputHints
pub fn empty() -> InputHintsReturns an empty set of flags.
pub fn all() -> InputHints
pub fn all() -> InputHintsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<InputHints>
pub fn from_bits(bits: u32) -> Option<InputHints>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> InputHints
pub fn from_bits_truncate(bits: u32) -> InputHintsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: InputHints) -> bool
pub fn intersects(&self, other: InputHints) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: InputHints) -> bool
pub fn contains(&self, other: InputHints) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: InputHints)
pub fn insert(&mut self, other: InputHints)Inserts the specified flags in-place.
pub fn remove(&mut self, other: InputHints)
pub fn remove(&mut self, other: InputHints)Removes the specified flags in-place.
pub fn toggle(&mut self, other: InputHints)
pub fn toggle(&mut self, other: InputHints)Toggles the specified flags in-place.
pub fn set(&mut self, other: InputHints, value: bool)
pub fn set(&mut self, other: InputHints, value: bool)Inserts or removes the specified flags depending on the passed value.