Struct gtk::Invisible [−]
pub struct Invisible(_, _);
Methods
impl Invisible[src]
impl InvisibleTrait Implementations
impl Clone for Invisible
impl Clone for Invisiblefn clone(&self) -> Invisible
fn clone(&self) -> InvisibleReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Invisible
impl Hash for Invisiblefn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Invisible
impl Ord for Invisiblefn cmp(&self, other: &Invisible) -> Ordering
fn cmp(&self, other: &Invisible) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Invisible
impl StaticType for Invisiblefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Invisible
impl<T: IsA<Object>> PartialEq<T> for Invisiblefn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Invisible
impl Eq for Invisibleimpl<T: IsA<Object>> PartialOrd<T> for Invisible
impl<T: IsA<Object>> PartialOrd<T> for Invisiblefn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Invisible
impl Debug for Invisibleimpl IsA<Widget> for Invisible
impl IsA<Widget> for Invisibleimpl IsA<Buildable> for Invisible
impl IsA<Buildable> for Invisibleimpl IsA<Object> for Invisible
impl IsA<Object> for Invisibleimpl Default for Invisible[src]
impl Default for Invisibleimpl InvisibleExtManual for Invisible[src]
impl InvisibleExtManual for Invisiblefn get_screen(&self) -> Option<Screen>[src]
fn get_screen(&self) -> Option<Screen>