Struct gtk::JunctionSides [−]
pub struct JunctionSides { /* fields omitted */ }Methods
impl JunctionSides
impl JunctionSidespub const NONE: JunctionSides
NONE: JunctionSides = JunctionSides{bits: 0,}
pub const CORNER_TOPLEFT: JunctionSides
CORNER_TOPLEFT: JunctionSides = JunctionSides{bits: 1,}
pub const CORNER_TOPRIGHT: JunctionSides
CORNER_TOPRIGHT: JunctionSides = JunctionSides{bits: 2,}
pub const CORNER_BOTTOMLEFT: JunctionSides
CORNER_BOTTOMLEFT: JunctionSides = JunctionSides{bits: 4,}
pub const CORNER_BOTTOMRIGHT: JunctionSides
CORNER_BOTTOMRIGHT: JunctionSides = JunctionSides{bits: 8,}
pub const TOP: JunctionSides
TOP: JunctionSides = JunctionSides{bits: 3,}
pub const BOTTOM: JunctionSides
BOTTOM: JunctionSides = JunctionSides{bits: 12,}
pub const LEFT: JunctionSides
LEFT: JunctionSides = JunctionSides{bits: 5,}
pub const RIGHT: JunctionSides
RIGHT: JunctionSides = JunctionSides{bits: 10,}
pub fn empty() -> JunctionSides
pub fn empty() -> JunctionSidesReturns an empty set of flags.
pub fn all() -> JunctionSides
pub fn all() -> JunctionSidesReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<JunctionSides>
pub fn from_bits(bits: u32) -> Option<JunctionSides>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> JunctionSides
pub fn from_bits_truncate(bits: u32) -> JunctionSidesConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: JunctionSides) -> bool
pub fn intersects(&self, other: JunctionSides) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: JunctionSides) -> bool
pub fn contains(&self, other: JunctionSides) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: JunctionSides)
pub fn insert(&mut self, other: JunctionSides)Inserts the specified flags in-place.
pub fn remove(&mut self, other: JunctionSides)
pub fn remove(&mut self, other: JunctionSides)Removes the specified flags in-place.
pub fn toggle(&mut self, other: JunctionSides)
pub fn toggle(&mut self, other: JunctionSides)Toggles the specified flags in-place.
pub fn set(&mut self, other: JunctionSides, value: bool)
pub fn set(&mut self, other: JunctionSides, value: bool)Inserts or removes the specified flags depending on the passed value.