Struct gtk::Label [−]
pub struct Label(_, _);
Methods
impl Label[src]
impl Labelpub fn new<'a, P: Into<Option<&'a str>>>(str: P) -> Label[src]
pub fn new<'a, P: Into<Option<&'a str>>>(str: P) -> Labelpub fn new_with_mnemonic<'a, P: Into<Option<&'a str>>>(str: P) -> Label[src]
pub fn new_with_mnemonic<'a, P: Into<Option<&'a str>>>(str: P) -> LabelTrait Implementations
impl IsA<Label> for AccelLabel
impl IsA<Label> for AccelLabelimpl Clone for Label
impl Clone for Labelfn clone(&self) -> Label
fn clone(&self) -> LabelReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Label
impl Hash for Labelfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Label
impl Ord for Labelfn cmp(&self, other: &Label) -> Ordering
fn cmp(&self, other: &Label) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Label
impl StaticType for Labelfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Label
impl<T: IsA<Object>> PartialEq<T> for Labelfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Label
impl Eq for Labelimpl<T: IsA<Object>> PartialOrd<T> for Label
impl<T: IsA<Object>> PartialOrd<T> for Labelfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Label
impl Debug for Labelimpl IsA<Misc> for Label
impl IsA<Misc> for Labelimpl IsA<Widget> for Label
impl IsA<Widget> for Labelimpl IsA<Buildable> for Label
impl IsA<Buildable> for Labelimpl IsA<Object> for Label
impl IsA<Object> for Label