Struct gtk::LevelBar [−]
pub struct LevelBar(_, _);
Methods
impl LevelBar[src]
impl LevelBarpub fn new() -> LevelBar[src]
pub fn new() -> LevelBarpub fn new_for_interval(min_value: f64, max_value: f64) -> LevelBar[src]
pub fn new_for_interval(min_value: f64, max_value: f64) -> LevelBarTrait Implementations
impl Clone for LevelBar
impl Clone for LevelBarfn clone(&self) -> LevelBar
fn clone(&self) -> LevelBarReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for LevelBar
impl Hash for LevelBarfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for LevelBar
impl Ord for LevelBarfn cmp(&self, other: &LevelBar) -> Ordering
fn cmp(&self, other: &LevelBar) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for LevelBar
impl StaticType for LevelBarfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for LevelBar
impl<T: IsA<Object>> PartialEq<T> for LevelBarfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for LevelBar
impl Eq for LevelBarimpl<T: IsA<Object>> PartialOrd<T> for LevelBar
impl<T: IsA<Object>> PartialOrd<T> for LevelBarfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for LevelBar
impl Debug for LevelBarimpl IsA<Widget> for LevelBar
impl IsA<Widget> for LevelBarimpl IsA<Buildable> for LevelBar
impl IsA<Buildable> for LevelBarimpl IsA<Orientable> for LevelBar
impl IsA<Orientable> for LevelBarimpl IsA<Object> for LevelBar
impl IsA<Object> for LevelBarimpl Default for LevelBar[src]
impl Default for LevelBar