Struct gtk::LinkButton [−]
pub struct LinkButton(_, _);
Methods
impl LinkButton[src]
impl LinkButtonpub fn new(uri: &str) -> LinkButton[src]
pub fn new(uri: &str) -> LinkButtonpub fn new_with_label<'a, P: Into<Option<&'a str>>>(
uri: &str,
label: P
) -> LinkButton[src]
pub fn new_with_label<'a, P: Into<Option<&'a str>>>(
uri: &str,
label: P
) -> LinkButtonTrait Implementations
impl Clone for LinkButton
impl Clone for LinkButtonfn clone(&self) -> LinkButton
fn clone(&self) -> LinkButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for LinkButton
impl Hash for LinkButtonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for LinkButton
impl Ord for LinkButtonfn cmp(&self, other: &LinkButton) -> Ordering
fn cmp(&self, other: &LinkButton) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for LinkButton
impl StaticType for LinkButtonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for LinkButton
impl<T: IsA<Object>> PartialEq<T> for LinkButtonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for LinkButton
impl Eq for LinkButtonimpl<T: IsA<Object>> PartialOrd<T> for LinkButton
impl<T: IsA<Object>> PartialOrd<T> for LinkButtonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for LinkButton
impl Debug for LinkButtonimpl IsA<Button> for LinkButton
impl IsA<Button> for LinkButtonimpl IsA<Bin> for LinkButton
impl IsA<Bin> for LinkButtonimpl IsA<Container> for LinkButton
impl IsA<Container> for LinkButtonimpl IsA<Widget> for LinkButton
impl IsA<Widget> for LinkButtonimpl IsA<Buildable> for LinkButton
impl IsA<Buildable> for LinkButtonimpl IsA<Actionable> for LinkButton
impl IsA<Actionable> for LinkButtonimpl IsA<Object> for LinkButton
impl IsA<Object> for LinkButtonAuto Trait Implementations
impl !Send for LinkButton
impl !Send for LinkButtonimpl !Sync for LinkButton
impl !Sync for LinkButton