Struct gtk::ListBoxRow [−]
pub struct ListBoxRow(_, _);
Methods
impl ListBoxRow[src]
impl ListBoxRowpub fn new() -> ListBoxRow[src]
pub fn new() -> ListBoxRowTrait Implementations
impl Clone for ListBoxRow
impl Clone for ListBoxRowfn clone(&self) -> ListBoxRow
fn clone(&self) -> ListBoxRowReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ListBoxRow
impl Hash for ListBoxRowfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ListBoxRow
impl Ord for ListBoxRowfn cmp(&self, other: &ListBoxRow) -> Ordering
fn cmp(&self, other: &ListBoxRow) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ListBoxRow
impl StaticType for ListBoxRowfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ListBoxRow
impl<T: IsA<Object>> PartialEq<T> for ListBoxRowfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ListBoxRow
impl Eq for ListBoxRowimpl<T: IsA<Object>> PartialOrd<T> for ListBoxRow
impl<T: IsA<Object>> PartialOrd<T> for ListBoxRowfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ListBoxRow
impl Debug for ListBoxRowimpl IsA<Bin> for ListBoxRow
impl IsA<Bin> for ListBoxRowimpl IsA<Container> for ListBoxRow
impl IsA<Container> for ListBoxRowimpl IsA<Widget> for ListBoxRow
impl IsA<Widget> for ListBoxRowimpl IsA<Buildable> for ListBoxRow
impl IsA<Buildable> for ListBoxRowimpl IsA<Actionable> for ListBoxRow
impl IsA<Actionable> for ListBoxRowimpl IsA<Object> for ListBoxRow
impl IsA<Object> for ListBoxRowimpl Default for ListBoxRow[src]
impl Default for ListBoxRowAuto Trait Implementations
impl !Send for ListBoxRow
impl !Send for ListBoxRowimpl !Sync for ListBoxRow
impl !Sync for ListBoxRow