Struct gtk::ListStore [−]
pub struct ListStore(_, _);
Methods
impl ListStore[src]
impl ListStoreTrait Implementations
impl Clone for ListStore
impl Clone for ListStorefn clone(&self) -> ListStore
fn clone(&self) -> ListStoreReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ListStore
impl Hash for ListStorefn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ListStore
impl Ord for ListStorefn cmp(&self, other: &ListStore) -> Ordering
fn cmp(&self, other: &ListStore) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ListStore
impl StaticType for ListStorefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ListStore
impl<T: IsA<Object>> PartialEq<T> for ListStorefn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ListStore
impl Eq for ListStoreimpl<T: IsA<Object>> PartialOrd<T> for ListStore
impl<T: IsA<Object>> PartialOrd<T> for ListStorefn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ListStore
impl Debug for ListStoreimpl IsA<Buildable> for ListStore
impl IsA<Buildable> for ListStoreimpl IsA<TreeDragDest> for ListStore
impl IsA<TreeDragDest> for ListStoreimpl IsA<TreeDragSource> for ListStore
impl IsA<TreeDragSource> for ListStoreimpl IsA<TreeModel> for ListStore
impl IsA<TreeModel> for ListStoreimpl IsA<TreeSortable> for ListStore
impl IsA<TreeSortable> for ListStoreimpl IsA<Object> for ListStore
impl IsA<Object> for ListStore