Struct gtk::LockButton [−]
pub struct LockButton(_, _);
Methods
impl LockButton[src]
impl LockButtonpub fn new<'a, P: IsA<Permission> + 'a, Q: Into<Option<&'a P>>>(
permission: Q
) -> LockButton[src]
pub fn new<'a, P: IsA<Permission> + 'a, Q: Into<Option<&'a P>>>(
permission: Q
) -> LockButtonTrait Implementations
impl Clone for LockButton
impl Clone for LockButtonfn clone(&self) -> LockButton
fn clone(&self) -> LockButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for LockButton
impl Hash for LockButtonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for LockButton
impl Ord for LockButtonfn cmp(&self, other: &LockButton) -> Ordering
fn cmp(&self, other: &LockButton) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for LockButton
impl StaticType for LockButtonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for LockButton
impl<T: IsA<Object>> PartialEq<T> for LockButtonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for LockButton
impl Eq for LockButtonimpl<T: IsA<Object>> PartialOrd<T> for LockButton
impl<T: IsA<Object>> PartialOrd<T> for LockButtonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for LockButton
impl Debug for LockButtonimpl IsA<Button> for LockButton
impl IsA<Button> for LockButtonimpl IsA<Bin> for LockButton
impl IsA<Bin> for LockButtonimpl IsA<Container> for LockButton
impl IsA<Container> for LockButtonimpl IsA<Widget> for LockButton
impl IsA<Widget> for LockButtonimpl IsA<Buildable> for LockButton
impl IsA<Buildable> for LockButtonimpl IsA<Actionable> for LockButton
impl IsA<Actionable> for LockButtonimpl IsA<Object> for LockButton
impl IsA<Object> for LockButtonAuto Trait Implementations
impl !Send for LockButton
impl !Send for LockButtonimpl !Sync for LockButton
impl !Sync for LockButton