Struct gtk::MenuToolButton [−]
pub struct MenuToolButton(_, _);
Methods
impl MenuToolButton[src]
impl MenuToolButtonpub fn new<'a, 'b, P: IsA<Widget> + 'a, Q: Into<Option<&'a P>>, R: Into<Option<&'b str>>>(
icon_widget: Q,
label: R
) -> MenuToolButton[src]
pub fn new<'a, 'b, P: IsA<Widget> + 'a, Q: Into<Option<&'a P>>, R: Into<Option<&'b str>>>(
icon_widget: Q,
label: R
) -> MenuToolButtonpub fn new_from_stock(stock_id: &str) -> MenuToolButton[src]
pub fn new_from_stock(stock_id: &str) -> MenuToolButtonTrait Implementations
impl Clone for MenuToolButton
impl Clone for MenuToolButtonfn clone(&self) -> MenuToolButton
fn clone(&self) -> MenuToolButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for MenuToolButton
impl Hash for MenuToolButtonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for MenuToolButton
impl Ord for MenuToolButtonfn cmp(&self, other: &MenuToolButton) -> Ordering
fn cmp(&self, other: &MenuToolButton) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for MenuToolButton
impl StaticType for MenuToolButtonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for MenuToolButton
impl<T: IsA<Object>> PartialEq<T> for MenuToolButtonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for MenuToolButton
impl Eq for MenuToolButtonimpl<T: IsA<Object>> PartialOrd<T> for MenuToolButton
impl<T: IsA<Object>> PartialOrd<T> for MenuToolButtonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for MenuToolButton
impl Debug for MenuToolButtonimpl IsA<ToolButton> for MenuToolButton
impl IsA<ToolButton> for MenuToolButtonimpl IsA<ToolItem> for MenuToolButton
impl IsA<ToolItem> for MenuToolButtonimpl IsA<Bin> for MenuToolButton
impl IsA<Bin> for MenuToolButtonimpl IsA<Container> for MenuToolButton
impl IsA<Container> for MenuToolButtonimpl IsA<Widget> for MenuToolButton
impl IsA<Widget> for MenuToolButtonimpl IsA<Buildable> for MenuToolButton
impl IsA<Buildable> for MenuToolButtonimpl IsA<Actionable> for MenuToolButton
impl IsA<Actionable> for MenuToolButtonimpl IsA<Object> for MenuToolButton
impl IsA<Object> for MenuToolButtonAuto Trait Implementations
impl !Send for MenuToolButton
impl !Send for MenuToolButtonimpl !Sync for MenuToolButton
impl !Sync for MenuToolButton