Struct gtk::MessageDialog [−]
pub struct MessageDialog(_, _);
Methods
impl MessageDialog[src]
impl MessageDialogpub fn new<T: IsA<Window>>(
parent: Option<&T>,
flags: DialogFlags,
type_: MessageType,
buttons: ButtonsType,
message: &str
) -> MessageDialog[src]
pub fn new<T: IsA<Window>>(
parent: Option<&T>,
flags: DialogFlags,
type_: MessageType,
buttons: ButtonsType,
message: &str
) -> MessageDialogTrait Implementations
impl Clone for MessageDialog
impl Clone for MessageDialogfn clone(&self) -> MessageDialog
fn clone(&self) -> MessageDialogReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for MessageDialog
impl Hash for MessageDialogfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for MessageDialog
impl Ord for MessageDialogfn cmp(&self, other: &MessageDialog) -> Ordering
fn cmp(&self, other: &MessageDialog) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for MessageDialog
impl StaticType for MessageDialogfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for MessageDialog
impl<T: IsA<Object>> PartialEq<T> for MessageDialogfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for MessageDialog
impl Eq for MessageDialogimpl<T: IsA<Object>> PartialOrd<T> for MessageDialog
impl<T: IsA<Object>> PartialOrd<T> for MessageDialogfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for MessageDialog
impl Debug for MessageDialogimpl IsA<Dialog> for MessageDialog
impl IsA<Dialog> for MessageDialogimpl IsA<Window> for MessageDialog
impl IsA<Window> for MessageDialogimpl IsA<Bin> for MessageDialog
impl IsA<Bin> for MessageDialogimpl IsA<Container> for MessageDialog
impl IsA<Container> for MessageDialogimpl IsA<Widget> for MessageDialog
impl IsA<Widget> for MessageDialogimpl IsA<Buildable> for MessageDialog
impl IsA<Buildable> for MessageDialogimpl IsA<Object> for MessageDialog
impl IsA<Object> for MessageDialogAuto Trait Implementations
impl !Send for MessageDialog
impl !Send for MessageDialogimpl !Sync for MessageDialog
impl !Sync for MessageDialog