Struct gtk::Overlay [−]
pub struct Overlay(_, _);
Methods
impl Overlay[src]
impl OverlayTrait Implementations
impl Clone for Overlay
impl Clone for Overlayfn clone(&self) -> Overlay
fn clone(&self) -> OverlayReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Overlay
impl Hash for Overlayfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Overlay
impl Ord for Overlayfn cmp(&self, other: &Overlay) -> Ordering
fn cmp(&self, other: &Overlay) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Overlay
impl StaticType for Overlayfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Overlay
impl<T: IsA<Object>> PartialEq<T> for Overlayfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Overlay
impl Eq for Overlayimpl<T: IsA<Object>> PartialOrd<T> for Overlay
impl<T: IsA<Object>> PartialOrd<T> for Overlayfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Overlay
impl Debug for Overlayimpl IsA<Bin> for Overlay
impl IsA<Bin> for Overlayimpl IsA<Container> for Overlay
impl IsA<Container> for Overlayimpl IsA<Widget> for Overlay
impl IsA<Widget> for Overlayimpl IsA<Buildable> for Overlay
impl IsA<Buildable> for Overlayimpl IsA<Object> for Overlay
impl IsA<Object> for Overlayimpl Default for Overlay[src]
impl Default for Overlay