Struct gtk::PageSetup [−]
pub struct PageSetup(_, _);
Methods
impl PageSetup[src]
impl PageSetuppub fn new() -> PageSetup[src]
pub fn new() -> PageSetuppub fn new_from_file<P: AsRef<Path>>(file_name: P) -> Result<PageSetup, Error>[src]
pub fn new_from_file<P: AsRef<Path>>(file_name: P) -> Result<PageSetup, Error>pub fn new_from_key_file<'a, P: Into<Option<&'a str>>>(
key_file: &KeyFile,
group_name: P
) -> Result<PageSetup, Error>[src]
pub fn new_from_key_file<'a, P: Into<Option<&'a str>>>(
key_file: &KeyFile,
group_name: P
) -> Result<PageSetup, Error>Trait Implementations
impl Clone for PageSetup
impl Clone for PageSetupfn clone(&self) -> PageSetup
fn clone(&self) -> PageSetupReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for PageSetup
impl Hash for PageSetupfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for PageSetup
impl Ord for PageSetupfn cmp(&self, other: &PageSetup) -> Ordering
fn cmp(&self, other: &PageSetup) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for PageSetup
impl StaticType for PageSetupfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for PageSetup
impl<T: IsA<Object>> PartialEq<T> for PageSetupfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for PageSetup
impl Eq for PageSetupimpl<T: IsA<Object>> PartialOrd<T> for PageSetup
impl<T: IsA<Object>> PartialOrd<T> for PageSetupfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for PageSetup
impl Debug for PageSetupimpl IsA<Object> for PageSetup
impl IsA<Object> for PageSetupimpl Default for PageSetup[src]
impl Default for PageSetup