Struct gtk::Paned [−]
pub struct Paned(_, _);
Methods
impl Paned[src]
impl Panedpub fn new(orientation: Orientation) -> Paned[src]
pub fn new(orientation: Orientation) -> PanedTrait Implementations
impl Clone for Paned
impl Clone for Panedfn clone(&self) -> Paned
fn clone(&self) -> PanedReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Paned
impl Hash for Panedfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Paned
impl Ord for Panedfn cmp(&self, other: &Paned) -> Ordering
fn cmp(&self, other: &Paned) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Paned
impl StaticType for Panedfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Paned
impl<T: IsA<Object>> PartialEq<T> for Panedfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Paned
impl Eq for Panedimpl<T: IsA<Object>> PartialOrd<T> for Paned
impl<T: IsA<Object>> PartialOrd<T> for Panedfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Paned
impl Debug for Panedimpl IsA<Container> for Paned
impl IsA<Container> for Panedimpl IsA<Widget> for Paned
impl IsA<Widget> for Panedimpl IsA<Buildable> for Paned
impl IsA<Buildable> for Panedimpl IsA<Orientable> for Paned
impl IsA<Orientable> for Panedimpl IsA<Object> for Paned
impl IsA<Object> for Paned