Struct gtk::PaperSize [−]
pub struct PaperSize(_);
Methods
impl PaperSize[src]
impl PaperSizepub fn new<'a, P: Into<Option<&'a str>>>(name: P) -> PaperSize[src]
pub fn new<'a, P: Into<Option<&'a str>>>(name: P) -> PaperSizepub fn new_custom(
name: &str,
display_name: &str,
width: f64,
height: f64,
unit: Unit
) -> PaperSize[src]
pub fn new_custom(
name: &str,
display_name: &str,
width: f64,
height: f64,
unit: Unit
) -> PaperSizepub fn new_from_key_file(
key_file: &KeyFile,
group_name: &str
) -> Result<PaperSize, Error>[src]
pub fn new_from_key_file(
key_file: &KeyFile,
group_name: &str
) -> Result<PaperSize, Error>pub fn new_from_ppd(
ppd_name: &str,
ppd_display_name: &str,
width: f64,
height: f64
) -> PaperSize[src]
pub fn new_from_ppd(
ppd_name: &str,
ppd_display_name: &str,
width: f64,
height: f64
) -> PaperSizepub fn get_default_bottom_margin(&self, unit: Unit) -> f64[src]
pub fn get_default_bottom_margin(&self, unit: Unit) -> f64pub fn get_default_left_margin(&self, unit: Unit) -> f64[src]
pub fn get_default_left_margin(&self, unit: Unit) -> f64pub fn get_default_right_margin(&self, unit: Unit) -> f64[src]
pub fn get_default_right_margin(&self, unit: Unit) -> f64pub fn get_default_top_margin(&self, unit: Unit) -> f64[src]
pub fn get_default_top_margin(&self, unit: Unit) -> f64pub fn get_display_name(&self) -> Option<String>[src]
pub fn get_display_name(&self) -> Option<String>pub fn get_height(&self, unit: Unit) -> f64[src]
pub fn get_height(&self, unit: Unit) -> f64pub fn get_name(&self) -> Option<String>[src]
pub fn get_name(&self) -> Option<String>pub fn get_ppd_name(&self) -> Option<String>[src]
pub fn get_ppd_name(&self) -> Option<String>pub fn get_width(&self, unit: Unit) -> f64[src]
pub fn get_width(&self, unit: Unit) -> f64pub fn is_custom(&self) -> bool[src]
pub fn is_custom(&self) -> boolpub fn set_size(&mut self, width: f64, height: f64, unit: Unit)[src]
pub fn set_size(&mut self, width: f64, height: f64, unit: Unit)pub fn to_key_file(&mut self, key_file: &KeyFile, group_name: &str)[src]
pub fn to_key_file(&mut self, key_file: &KeyFile, group_name: &str)pub fn get_default() -> Option<String>[src]
pub fn get_default() -> Option<String>pub fn get_paper_sizes(include_custom: bool) -> Vec<PaperSize>[src]
pub fn get_paper_sizes(include_custom: bool) -> Vec<PaperSize>Trait Implementations
impl Debug for PaperSize[src]
impl Debug for PaperSizefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialOrd for PaperSize[src]
impl PartialOrd for PaperSizefn partial_cmp(&self, other: &PaperSize) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &PaperSize) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &PaperSize) -> bool[src]
fn lt(&self, other: &PaperSize) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &PaperSize) -> bool[src]
fn le(&self, other: &PaperSize) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &PaperSize) -> bool[src]
fn gt(&self, other: &PaperSize) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &PaperSize) -> bool[src]
fn ge(&self, other: &PaperSize) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for PaperSize[src]
impl Ord for PaperSizefn cmp(&self, other: &PaperSize) -> Ordering[src]
fn cmp(&self, other: &PaperSize) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for PaperSize[src]
impl Hash for PaperSizefn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for PaperSize
impl Clone for PaperSizefn clone(&self) -> PaperSize
fn clone(&self) -> PaperSizeReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for PaperSize
impl StaticType for PaperSizefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl PartialEq for PaperSize[src]
impl PartialEq for PaperSizefn eq(&self, other: &Self) -> bool[src]
fn eq(&self, other: &Self) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for PaperSize[src]
impl Eq for PaperSize