Struct gtk::PlacesOpenFlags [−]
pub struct PlacesOpenFlags { /* fields omitted */ }Methods
impl PlacesOpenFlags
impl PlacesOpenFlagspub const NORMAL: PlacesOpenFlags
NORMAL: PlacesOpenFlags = PlacesOpenFlags{bits: 1,}
pub const NEW_TAB: PlacesOpenFlags
NEW_TAB: PlacesOpenFlags = PlacesOpenFlags{bits: 2,}
pub const NEW_WINDOW: PlacesOpenFlags
NEW_WINDOW: PlacesOpenFlags = PlacesOpenFlags{bits: 4,}
pub fn empty() -> PlacesOpenFlags
pub fn empty() -> PlacesOpenFlagsReturns an empty set of flags.
pub fn all() -> PlacesOpenFlags
pub fn all() -> PlacesOpenFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<PlacesOpenFlags>
pub fn from_bits(bits: u32) -> Option<PlacesOpenFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> PlacesOpenFlags
pub fn from_bits_truncate(bits: u32) -> PlacesOpenFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: PlacesOpenFlags) -> bool
pub fn intersects(&self, other: PlacesOpenFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: PlacesOpenFlags) -> bool
pub fn contains(&self, other: PlacesOpenFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: PlacesOpenFlags)
pub fn insert(&mut self, other: PlacesOpenFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: PlacesOpenFlags)
pub fn remove(&mut self, other: PlacesOpenFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: PlacesOpenFlags)
pub fn toggle(&mut self, other: PlacesOpenFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: PlacesOpenFlags, value: bool)
pub fn set(&mut self, other: PlacesOpenFlags, value: bool)Inserts or removes the specified flags depending on the passed value.