Struct gtk::PlacesSidebar [−]
pub struct PlacesSidebar(_, _);
Methods
impl PlacesSidebar[src]
impl PlacesSidebarpub fn new() -> PlacesSidebar[src]
pub fn new() -> PlacesSidebarTrait Implementations
impl Clone for PlacesSidebar
impl Clone for PlacesSidebarfn clone(&self) -> PlacesSidebar
fn clone(&self) -> PlacesSidebarReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for PlacesSidebar
impl Hash for PlacesSidebarfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for PlacesSidebar
impl Ord for PlacesSidebarfn cmp(&self, other: &PlacesSidebar) -> Ordering
fn cmp(&self, other: &PlacesSidebar) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for PlacesSidebar
impl StaticType for PlacesSidebarfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for PlacesSidebar
impl<T: IsA<Object>> PartialEq<T> for PlacesSidebarfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for PlacesSidebar
impl Eq for PlacesSidebarimpl<T: IsA<Object>> PartialOrd<T> for PlacesSidebar
impl<T: IsA<Object>> PartialOrd<T> for PlacesSidebarfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for PlacesSidebar
impl Debug for PlacesSidebarimpl IsA<ScrolledWindow> for PlacesSidebar
impl IsA<ScrolledWindow> for PlacesSidebarimpl IsA<Bin> for PlacesSidebar
impl IsA<Bin> for PlacesSidebarimpl IsA<Container> for PlacesSidebar
impl IsA<Container> for PlacesSidebarimpl IsA<Widget> for PlacesSidebar
impl IsA<Widget> for PlacesSidebarimpl IsA<Buildable> for PlacesSidebar
impl IsA<Buildable> for PlacesSidebarimpl IsA<Object> for PlacesSidebar
impl IsA<Object> for PlacesSidebarimpl Default for PlacesSidebar[src]
impl Default for PlacesSidebarAuto Trait Implementations
impl !Send for PlacesSidebar
impl !Send for PlacesSidebarimpl !Sync for PlacesSidebar
impl !Sync for PlacesSidebar