Struct gtk::PrintSettings [−]
pub struct PrintSettings(_, _);
Methods
impl PrintSettings[src]
impl PrintSettingspub fn new() -> PrintSettings[src]
pub fn new() -> PrintSettingspub fn new_from_file<P: AsRef<Path>>(
file_name: P
) -> Result<PrintSettings, Error>[src]
pub fn new_from_file<P: AsRef<Path>>(
file_name: P
) -> Result<PrintSettings, Error>pub fn new_from_key_file<'a, P: Into<Option<&'a str>>>(
key_file: &KeyFile,
group_name: P
) -> Result<PrintSettings, Error>[src]
pub fn new_from_key_file<'a, P: Into<Option<&'a str>>>(
key_file: &KeyFile,
group_name: P
) -> Result<PrintSettings, Error>Trait Implementations
impl Clone for PrintSettings
impl Clone for PrintSettingsfn clone(&self) -> PrintSettings
fn clone(&self) -> PrintSettingsReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for PrintSettings
impl Hash for PrintSettingsfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for PrintSettings
impl Ord for PrintSettingsfn cmp(&self, other: &PrintSettings) -> Ordering
fn cmp(&self, other: &PrintSettings) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for PrintSettings
impl StaticType for PrintSettingsfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for PrintSettings
impl<T: IsA<Object>> PartialEq<T> for PrintSettingsfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for PrintSettings
impl Eq for PrintSettingsimpl<T: IsA<Object>> PartialOrd<T> for PrintSettings
impl<T: IsA<Object>> PartialOrd<T> for PrintSettingsfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for PrintSettings
impl Debug for PrintSettingsimpl IsA<Object> for PrintSettings
impl IsA<Object> for PrintSettingsimpl Default for PrintSettings[src]
impl Default for PrintSettingsAuto Trait Implementations
impl !Send for PrintSettings
impl !Send for PrintSettingsimpl !Sync for PrintSettings
impl !Sync for PrintSettings