Struct gtk::RadioButton [−]
pub struct RadioButton(_, _);
Methods
impl RadioButton[src]
impl RadioButtonpub fn new_from_widget(radio_group_member: &RadioButton) -> RadioButton[src]
pub fn new_from_widget(radio_group_member: &RadioButton) -> RadioButtonpub fn new_with_label_from_widget(
radio_group_member: &RadioButton,
label: &str
) -> RadioButton[src]
pub fn new_with_label_from_widget(
radio_group_member: &RadioButton,
label: &str
) -> RadioButtonpub fn new_with_mnemonic_from_widget(
radio_group_member: &RadioButton,
label: &str
) -> RadioButton[src]
pub fn new_with_mnemonic_from_widget(
radio_group_member: &RadioButton,
label: &str
) -> RadioButtonimpl RadioButton[src]
impl RadioButtonpub fn new() -> RadioButton[src]
pub fn new() -> RadioButtonpub fn new_with_label(label: &str) -> RadioButton[src]
pub fn new_with_label(label: &str) -> RadioButtonpub fn new_with_mnemonic(label: &str) -> RadioButton[src]
pub fn new_with_mnemonic(label: &str) -> RadioButtonTrait Implementations
impl Clone for RadioButton
impl Clone for RadioButtonfn clone(&self) -> RadioButton
fn clone(&self) -> RadioButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for RadioButton
impl Hash for RadioButtonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for RadioButton
impl Ord for RadioButtonfn cmp(&self, other: &RadioButton) -> Ordering
fn cmp(&self, other: &RadioButton) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for RadioButton
impl StaticType for RadioButtonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for RadioButton
impl<T: IsA<Object>> PartialEq<T> for RadioButtonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for RadioButton
impl Eq for RadioButtonimpl<T: IsA<Object>> PartialOrd<T> for RadioButton
impl<T: IsA<Object>> PartialOrd<T> for RadioButtonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for RadioButton
impl Debug for RadioButtonimpl IsA<CheckButton> for RadioButton
impl IsA<CheckButton> for RadioButtonimpl IsA<ToggleButton> for RadioButton
impl IsA<ToggleButton> for RadioButtonimpl IsA<Button> for RadioButton
impl IsA<Button> for RadioButtonimpl IsA<Bin> for RadioButton
impl IsA<Bin> for RadioButtonimpl IsA<Container> for RadioButton
impl IsA<Container> for RadioButtonimpl IsA<Widget> for RadioButton
impl IsA<Widget> for RadioButtonimpl IsA<Buildable> for RadioButton
impl IsA<Buildable> for RadioButtonimpl IsA<Actionable> for RadioButton
impl IsA<Actionable> for RadioButtonimpl IsA<Object> for RadioButton
impl IsA<Object> for RadioButtonAuto Trait Implementations
impl !Send for RadioButton
impl !Send for RadioButtonimpl !Sync for RadioButton
impl !Sync for RadioButton