Struct gtk::RadioMenuItem [−]
pub struct RadioMenuItem(_, _);
Methods
impl RadioMenuItem[src]
impl RadioMenuItempub fn new_from_widget(group: &RadioMenuItem) -> RadioMenuItem[src]
pub fn new_from_widget(group: &RadioMenuItem) -> RadioMenuItempub fn new_with_label_from_widget<'a, P: Into<Option<&'a str>>>(
group: &RadioMenuItem,
label: P
) -> RadioMenuItem[src]
pub fn new_with_label_from_widget<'a, P: Into<Option<&'a str>>>(
group: &RadioMenuItem,
label: P
) -> RadioMenuItempub fn new_with_mnemonic_from_widget<'a, P: Into<Option<&'a str>>>(
group: &RadioMenuItem,
label: P
) -> RadioMenuItem[src]
pub fn new_with_mnemonic_from_widget<'a, P: Into<Option<&'a str>>>(
group: &RadioMenuItem,
label: P
) -> RadioMenuItemimpl RadioMenuItem[src]
impl RadioMenuItempub fn new() -> RadioMenuItem[src]
pub fn new() -> RadioMenuItempub fn new_with_label(label: &str) -> RadioMenuItem[src]
pub fn new_with_label(label: &str) -> RadioMenuItempub fn new_with_mnemonic(label: &str) -> RadioMenuItem[src]
pub fn new_with_mnemonic(label: &str) -> RadioMenuItemTrait Implementations
impl Clone for RadioMenuItem
impl Clone for RadioMenuItemfn clone(&self) -> RadioMenuItem
fn clone(&self) -> RadioMenuItemReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for RadioMenuItem
impl Hash for RadioMenuItemfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for RadioMenuItem
impl Ord for RadioMenuItemfn cmp(&self, other: &RadioMenuItem) -> Ordering
fn cmp(&self, other: &RadioMenuItem) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for RadioMenuItem
impl StaticType for RadioMenuItemfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for RadioMenuItem
impl<T: IsA<Object>> PartialEq<T> for RadioMenuItemfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for RadioMenuItem
impl Eq for RadioMenuItemimpl<T: IsA<Object>> PartialOrd<T> for RadioMenuItem
impl<T: IsA<Object>> PartialOrd<T> for RadioMenuItemfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for RadioMenuItem
impl Debug for RadioMenuItemimpl IsA<CheckMenuItem> for RadioMenuItem
impl IsA<CheckMenuItem> for RadioMenuItemimpl IsA<MenuItem> for RadioMenuItem
impl IsA<MenuItem> for RadioMenuItemimpl IsA<Bin> for RadioMenuItem
impl IsA<Bin> for RadioMenuItemimpl IsA<Container> for RadioMenuItem
impl IsA<Container> for RadioMenuItemimpl IsA<Widget> for RadioMenuItem
impl IsA<Widget> for RadioMenuItemimpl IsA<Buildable> for RadioMenuItem
impl IsA<Buildable> for RadioMenuItemimpl IsA<Actionable> for RadioMenuItem
impl IsA<Actionable> for RadioMenuItemimpl IsA<Object> for RadioMenuItem
impl IsA<Object> for RadioMenuItemAuto Trait Implementations
impl !Send for RadioMenuItem
impl !Send for RadioMenuItemimpl !Sync for RadioMenuItem
impl !Sync for RadioMenuItem