Struct gtk::RadioToolButton [−]
pub struct RadioToolButton(_, _);
Methods
impl RadioToolButton[src]
impl RadioToolButtonpub fn new_from_widget(group: &RadioToolButton) -> RadioToolButton[src]
pub fn new_from_widget(group: &RadioToolButton) -> RadioToolButtonpub fn new_with_stock_from_widget(
group: &RadioToolButton,
stock_id: &str
) -> RadioToolButton[src]
pub fn new_with_stock_from_widget(
group: &RadioToolButton,
stock_id: &str
) -> RadioToolButtonimpl RadioToolButton[src]
impl RadioToolButtonpub fn new() -> RadioToolButton[src]
pub fn new() -> RadioToolButtonpub fn new_from_stock(stock_id: &str) -> RadioToolButton[src]
pub fn new_from_stock(stock_id: &str) -> RadioToolButtonpub fn join_group<'a, P: Into<Option<&'a RadioToolButton>>>(&self, group: P)[src]
pub fn join_group<'a, P: Into<Option<&'a RadioToolButton>>>(&self, group: P)Trait Implementations
impl Clone for RadioToolButton
impl Clone for RadioToolButtonfn clone(&self) -> RadioToolButton
fn clone(&self) -> RadioToolButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for RadioToolButton
impl Hash for RadioToolButtonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for RadioToolButton
impl Ord for RadioToolButtonfn cmp(&self, other: &RadioToolButton) -> Ordering
fn cmp(&self, other: &RadioToolButton) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for RadioToolButton
impl StaticType for RadioToolButtonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for RadioToolButton
impl<T: IsA<Object>> PartialEq<T> for RadioToolButtonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for RadioToolButton
impl Eq for RadioToolButtonimpl<T: IsA<Object>> PartialOrd<T> for RadioToolButton
impl<T: IsA<Object>> PartialOrd<T> for RadioToolButtonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for RadioToolButton
impl Debug for RadioToolButtonimpl IsA<ToggleToolButton> for RadioToolButton
impl IsA<ToggleToolButton> for RadioToolButtonimpl IsA<ToolButton> for RadioToolButton
impl IsA<ToolButton> for RadioToolButtonimpl IsA<ToolItem> for RadioToolButton
impl IsA<ToolItem> for RadioToolButtonimpl IsA<Bin> for RadioToolButton
impl IsA<Bin> for RadioToolButtonimpl IsA<Container> for RadioToolButton
impl IsA<Container> for RadioToolButtonimpl IsA<Widget> for RadioToolButton
impl IsA<Widget> for RadioToolButtonimpl IsA<Buildable> for RadioToolButton
impl IsA<Buildable> for RadioToolButtonimpl IsA<Actionable> for RadioToolButton
impl IsA<Actionable> for RadioToolButtonimpl IsA<Object> for RadioToolButton
impl IsA<Object> for RadioToolButtonAuto Trait Implementations
impl !Send for RadioToolButton
impl !Send for RadioToolButtonimpl !Sync for RadioToolButton
impl !Sync for RadioToolButton