Struct gtk::RecentChooserDialog [−]
pub struct RecentChooserDialog(_, _);
Methods
impl RecentChooserDialog[src]
impl RecentChooserDialogpub fn new<T: IsA<Window>>(
title: Option<&str>,
parent: Option<&T>
) -> RecentChooserDialog[src]
pub fn new<T: IsA<Window>>(
title: Option<&str>,
parent: Option<&T>
) -> RecentChooserDialogpub fn new_for_manager<T: IsA<Window>>(
title: Option<&str>,
parent: Option<&T>,
manager: &RecentManager
) -> RecentChooserDialog[src]
pub fn new_for_manager<T: IsA<Window>>(
title: Option<&str>,
parent: Option<&T>,
manager: &RecentManager
) -> RecentChooserDialogTrait Implementations
impl Clone for RecentChooserDialog
impl Clone for RecentChooserDialogfn clone(&self) -> RecentChooserDialog
fn clone(&self) -> RecentChooserDialogReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for RecentChooserDialog
impl Hash for RecentChooserDialogfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for RecentChooserDialog
impl Ord for RecentChooserDialogfn cmp(&self, other: &RecentChooserDialog) -> Ordering
fn cmp(&self, other: &RecentChooserDialog) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for RecentChooserDialog
impl StaticType for RecentChooserDialogfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for RecentChooserDialog
impl<T: IsA<Object>> PartialEq<T> for RecentChooserDialogfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for RecentChooserDialog
impl Eq for RecentChooserDialogimpl<T: IsA<Object>> PartialOrd<T> for RecentChooserDialog
impl<T: IsA<Object>> PartialOrd<T> for RecentChooserDialogfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for RecentChooserDialog
impl Debug for RecentChooserDialogimpl IsA<Dialog> for RecentChooserDialog
impl IsA<Dialog> for RecentChooserDialogimpl IsA<Window> for RecentChooserDialog
impl IsA<Window> for RecentChooserDialogimpl IsA<Bin> for RecentChooserDialog
impl IsA<Bin> for RecentChooserDialogimpl IsA<Container> for RecentChooserDialog
impl IsA<Container> for RecentChooserDialogimpl IsA<Widget> for RecentChooserDialog
impl IsA<Widget> for RecentChooserDialogimpl IsA<Buildable> for RecentChooserDialog
impl IsA<Buildable> for RecentChooserDialogimpl IsA<RecentChooser> for RecentChooserDialog
impl IsA<RecentChooser> for RecentChooserDialogimpl IsA<Object> for RecentChooserDialog
impl IsA<Object> for RecentChooserDialogAuto Trait Implementations
impl !Send for RecentChooserDialog
impl !Send for RecentChooserDialogimpl !Sync for RecentChooserDialog
impl !Sync for RecentChooserDialog