Struct gtk::RecentChooserMenu [−]
pub struct RecentChooserMenu(_, _);
Methods
impl RecentChooserMenu[src]
impl RecentChooserMenupub fn new() -> RecentChooserMenu[src]
pub fn new() -> RecentChooserMenupub fn new_for_manager(manager: &RecentManager) -> RecentChooserMenu[src]
pub fn new_for_manager(manager: &RecentManager) -> RecentChooserMenuTrait Implementations
impl Clone for RecentChooserMenu
impl Clone for RecentChooserMenufn clone(&self) -> RecentChooserMenu
fn clone(&self) -> RecentChooserMenuReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for RecentChooserMenu
impl Hash for RecentChooserMenufn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for RecentChooserMenu
impl Ord for RecentChooserMenufn cmp(&self, other: &RecentChooserMenu) -> Ordering
fn cmp(&self, other: &RecentChooserMenu) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for RecentChooserMenu
impl StaticType for RecentChooserMenufn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for RecentChooserMenu
impl<T: IsA<Object>> PartialEq<T> for RecentChooserMenufn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for RecentChooserMenu
impl Eq for RecentChooserMenuimpl<T: IsA<Object>> PartialOrd<T> for RecentChooserMenu
impl<T: IsA<Object>> PartialOrd<T> for RecentChooserMenufn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for RecentChooserMenu
impl Debug for RecentChooserMenuimpl IsA<Menu> for RecentChooserMenu
impl IsA<Menu> for RecentChooserMenuimpl IsA<MenuShell> for RecentChooserMenu
impl IsA<MenuShell> for RecentChooserMenuimpl IsA<Container> for RecentChooserMenu
impl IsA<Container> for RecentChooserMenuimpl IsA<Widget> for RecentChooserMenu
impl IsA<Widget> for RecentChooserMenuimpl IsA<Buildable> for RecentChooserMenu
impl IsA<Buildable> for RecentChooserMenuimpl IsA<RecentChooser> for RecentChooserMenu
impl IsA<RecentChooser> for RecentChooserMenuimpl IsA<Object> for RecentChooserMenu
impl IsA<Object> for RecentChooserMenuimpl Default for RecentChooserMenu[src]
impl Default for RecentChooserMenuAuto Trait Implementations
impl !Send for RecentChooserMenu
impl !Send for RecentChooserMenuimpl !Sync for RecentChooserMenu
impl !Sync for RecentChooserMenu