Struct gtk::RecentChooserWidget [−]
pub struct RecentChooserWidget(_, _);
Methods
impl RecentChooserWidget[src]
impl RecentChooserWidgetpub fn new() -> RecentChooserWidget[src]
pub fn new() -> RecentChooserWidgetpub fn new_for_manager(manager: &RecentManager) -> RecentChooserWidget[src]
pub fn new_for_manager(manager: &RecentManager) -> RecentChooserWidgetTrait Implementations
impl Clone for RecentChooserWidget
impl Clone for RecentChooserWidgetfn clone(&self) -> RecentChooserWidget
fn clone(&self) -> RecentChooserWidgetReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for RecentChooserWidget
impl Hash for RecentChooserWidgetfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for RecentChooserWidget
impl Ord for RecentChooserWidgetfn cmp(&self, other: &RecentChooserWidget) -> Ordering
fn cmp(&self, other: &RecentChooserWidget) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for RecentChooserWidget
impl StaticType for RecentChooserWidgetfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for RecentChooserWidget
impl<T: IsA<Object>> PartialEq<T> for RecentChooserWidgetfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for RecentChooserWidget
impl Eq for RecentChooserWidgetimpl<T: IsA<Object>> PartialOrd<T> for RecentChooserWidget
impl<T: IsA<Object>> PartialOrd<T> for RecentChooserWidgetfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for RecentChooserWidget
impl Debug for RecentChooserWidgetimpl IsA<Box> for RecentChooserWidget
impl IsA<Box> for RecentChooserWidgetimpl IsA<Container> for RecentChooserWidget
impl IsA<Container> for RecentChooserWidgetimpl IsA<Widget> for RecentChooserWidget
impl IsA<Widget> for RecentChooserWidgetimpl IsA<Buildable> for RecentChooserWidget
impl IsA<Buildable> for RecentChooserWidgetimpl IsA<Orientable> for RecentChooserWidget
impl IsA<Orientable> for RecentChooserWidgetimpl IsA<RecentChooser> for RecentChooserWidget
impl IsA<RecentChooser> for RecentChooserWidgetimpl IsA<Object> for RecentChooserWidget
impl IsA<Object> for RecentChooserWidgetimpl Default for RecentChooserWidget[src]
impl Default for RecentChooserWidgetAuto Trait Implementations
impl !Send for RecentChooserWidget
impl !Send for RecentChooserWidgetimpl !Sync for RecentChooserWidget
impl !Sync for RecentChooserWidget