Struct gtk::RecentFilterFlags [−]
pub struct RecentFilterFlags { /* fields omitted */ }Methods
impl RecentFilterFlags
impl RecentFilterFlagspub const URI: RecentFilterFlags
URI: RecentFilterFlags = RecentFilterFlags{bits: 1,}
pub const DISPLAY_NAME: RecentFilterFlags
DISPLAY_NAME: RecentFilterFlags = RecentFilterFlags{bits: 2,}
pub const MIME_TYPE: RecentFilterFlags
MIME_TYPE: RecentFilterFlags = RecentFilterFlags{bits: 4,}
pub const APPLICATION: RecentFilterFlags
APPLICATION: RecentFilterFlags = RecentFilterFlags{bits: 8,}
pub const GROUP: RecentFilterFlags
GROUP: RecentFilterFlags = RecentFilterFlags{bits: 16,}
pub const AGE: RecentFilterFlags
AGE: RecentFilterFlags = RecentFilterFlags{bits: 32,}
pub fn empty() -> RecentFilterFlags
pub fn empty() -> RecentFilterFlagsReturns an empty set of flags.
pub fn all() -> RecentFilterFlags
pub fn all() -> RecentFilterFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<RecentFilterFlags>
pub fn from_bits(bits: u32) -> Option<RecentFilterFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> RecentFilterFlags
pub fn from_bits_truncate(bits: u32) -> RecentFilterFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: RecentFilterFlags) -> bool
pub fn intersects(&self, other: RecentFilterFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: RecentFilterFlags) -> bool
pub fn contains(&self, other: RecentFilterFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: RecentFilterFlags)
pub fn insert(&mut self, other: RecentFilterFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: RecentFilterFlags)
pub fn remove(&mut self, other: RecentFilterFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: RecentFilterFlags)
pub fn toggle(&mut self, other: RecentFilterFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: RecentFilterFlags, value: bool)
pub fn set(&mut self, other: RecentFilterFlags, value: bool)Inserts or removes the specified flags depending on the passed value.