Struct gtk::RecentInfo [−]
pub struct RecentInfo(_);
Methods
impl RecentInfo[src]
impl RecentInfopub fn create_app_info<'a, P: Into<Option<&'a str>>>(
&self,
app_name: P
) -> Result<Option<AppInfo>, Error>[src]
pub fn create_app_info<'a, P: Into<Option<&'a str>>>(
&self,
app_name: P
) -> Result<Option<AppInfo>, Error>pub fn exists(&self) -> bool[src]
pub fn exists(&self) -> boolpub fn get_added(&self) -> c_long[src]
pub fn get_added(&self) -> c_longpub fn get_age(&self) -> i32[src]
pub fn get_age(&self) -> i32pub fn get_application_info(
&self,
app_name: &str
) -> Option<(String, u32, c_long)>[src]
pub fn get_application_info(
&self,
app_name: &str
) -> Option<(String, u32, c_long)>pub fn get_applications(&self) -> Vec<String>[src]
pub fn get_applications(&self) -> Vec<String>pub fn get_description(&self) -> Option<String>[src]
pub fn get_description(&self) -> Option<String>pub fn get_display_name(&self) -> Option<String>[src]
pub fn get_display_name(&self) -> Option<String>pub fn get_gicon(&self) -> Option<Icon>[src]
pub fn get_gicon(&self) -> Option<Icon>pub fn get_groups(&self) -> Vec<String>[src]
pub fn get_groups(&self) -> Vec<String>pub fn get_icon(&self, size: i32) -> Option<Pixbuf>[src]
pub fn get_icon(&self, size: i32) -> Option<Pixbuf>pub fn get_mime_type(&self) -> Option<String>[src]
pub fn get_mime_type(&self) -> Option<String>pub fn get_modified(&self) -> c_long[src]
pub fn get_modified(&self) -> c_longpub fn get_private_hint(&self) -> bool[src]
pub fn get_private_hint(&self) -> boolpub fn get_short_name(&self) -> Option<String>[src]
pub fn get_short_name(&self) -> Option<String>pub fn get_uri(&self) -> Option<String>[src]
pub fn get_uri(&self) -> Option<String>pub fn get_uri_display(&self) -> Option<String>[src]
pub fn get_uri_display(&self) -> Option<String>pub fn get_visited(&self) -> c_long[src]
pub fn get_visited(&self) -> c_longpub fn has_application(&self, app_name: &str) -> bool[src]
pub fn has_application(&self, app_name: &str) -> boolpub fn has_group(&self, group_name: &str) -> bool[src]
pub fn has_group(&self, group_name: &str) -> boolpub fn is_local(&self) -> bool[src]
pub fn is_local(&self) -> boolpub fn last_application(&self) -> Option<String>[src]
pub fn last_application(&self) -> Option<String>pub fn match_(&self, info_b: &RecentInfo) -> bool[src]
pub fn match_(&self, info_b: &RecentInfo) -> boolTrait Implementations
impl Debug for RecentInfo[src]
impl Debug for RecentInfofn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for RecentInfo[src]
impl PartialEq for RecentInfofn eq(&self, other: &RecentInfo) -> bool[src]
fn eq(&self, other: &RecentInfo) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &RecentInfo) -> bool[src]
fn ne(&self, other: &RecentInfo) -> boolThis method tests for !=.
impl Eq for RecentInfo[src]
impl Eq for RecentInfoimpl PartialOrd for RecentInfo[src]
impl PartialOrd for RecentInfofn partial_cmp(&self, other: &RecentInfo) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &RecentInfo) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &RecentInfo) -> bool[src]
fn lt(&self, other: &RecentInfo) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &RecentInfo) -> bool[src]
fn le(&self, other: &RecentInfo) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &RecentInfo) -> bool[src]
fn gt(&self, other: &RecentInfo) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &RecentInfo) -> bool[src]
fn ge(&self, other: &RecentInfo) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for RecentInfo[src]
impl Ord for RecentInfofn cmp(&self, other: &RecentInfo) -> Ordering[src]
fn cmp(&self, other: &RecentInfo) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for RecentInfo[src]
impl Hash for RecentInfofn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for RecentInfo
impl Clone for RecentInfofn clone(&self) -> RecentInfo
fn clone(&self) -> RecentInfoReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for RecentInfo
impl StaticType for RecentInfofn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.