Struct gtk::RecentManager [−]
pub struct RecentManager(_, _);
Methods
impl RecentManager[src]
impl RecentManagerpub fn new() -> RecentManager[src]
pub fn new() -> RecentManagerpub fn get_default() -> Option<RecentManager>[src]
pub fn get_default() -> Option<RecentManager>Trait Implementations
impl Clone for RecentManager
impl Clone for RecentManagerfn clone(&self) -> RecentManager
fn clone(&self) -> RecentManagerReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for RecentManager
impl Hash for RecentManagerfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for RecentManager
impl Ord for RecentManagerfn cmp(&self, other: &RecentManager) -> Ordering
fn cmp(&self, other: &RecentManager) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for RecentManager
impl StaticType for RecentManagerfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for RecentManager
impl<T: IsA<Object>> PartialEq<T> for RecentManagerfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for RecentManager
impl Eq for RecentManagerimpl<T: IsA<Object>> PartialOrd<T> for RecentManager
impl<T: IsA<Object>> PartialOrd<T> for RecentManagerfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for RecentManager
impl Debug for RecentManagerimpl IsA<Object> for RecentManager
impl IsA<Object> for RecentManagerimpl Default for RecentManager[src]
impl Default for RecentManagerAuto Trait Implementations
impl !Send for RecentManager
impl !Send for RecentManagerimpl !Sync for RecentManager
impl !Sync for RecentManager