Struct gtk::RegionFlags [−]
pub struct RegionFlags { /* fields omitted */ }Methods
impl RegionFlags
impl RegionFlagspub const EVEN: RegionFlags
EVEN: RegionFlags = RegionFlags{bits: 1,}
pub const ODD: RegionFlags
ODD: RegionFlags = RegionFlags{bits: 2,}
pub const FIRST: RegionFlags
FIRST: RegionFlags = RegionFlags{bits: 4,}
pub const LAST: RegionFlags
LAST: RegionFlags = RegionFlags{bits: 8,}
pub const ONLY: RegionFlags
ONLY: RegionFlags = RegionFlags{bits: 16,}
pub const SORTED: RegionFlags
SORTED: RegionFlags = RegionFlags{bits: 32,}
pub fn empty() -> RegionFlags
pub fn empty() -> RegionFlagsReturns an empty set of flags.
pub fn all() -> RegionFlags
pub fn all() -> RegionFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<RegionFlags>
pub fn from_bits(bits: u32) -> Option<RegionFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> RegionFlags
pub fn from_bits_truncate(bits: u32) -> RegionFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: RegionFlags) -> bool
pub fn intersects(&self, other: RegionFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: RegionFlags) -> bool
pub fn contains(&self, other: RegionFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: RegionFlags)
pub fn insert(&mut self, other: RegionFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: RegionFlags)
pub fn remove(&mut self, other: RegionFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: RegionFlags)
pub fn toggle(&mut self, other: RegionFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: RegionFlags, value: bool)
pub fn set(&mut self, other: RegionFlags, value: bool)Inserts or removes the specified flags depending on the passed value.