Struct gtk::Revealer [−]
pub struct Revealer(_, _);
Methods
impl Revealer[src]
impl RevealerTrait Implementations
impl Clone for Revealer
impl Clone for Revealerfn clone(&self) -> Revealer
fn clone(&self) -> RevealerReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Revealer
impl Hash for Revealerfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Revealer
impl Ord for Revealerfn cmp(&self, other: &Revealer) -> Ordering
fn cmp(&self, other: &Revealer) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Revealer
impl StaticType for Revealerfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Revealer
impl<T: IsA<Object>> PartialEq<T> for Revealerfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Revealer
impl Eq for Revealerimpl<T: IsA<Object>> PartialOrd<T> for Revealer
impl<T: IsA<Object>> PartialOrd<T> for Revealerfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Revealer
impl Debug for Revealerimpl IsA<Bin> for Revealer
impl IsA<Bin> for Revealerimpl IsA<Container> for Revealer
impl IsA<Container> for Revealerimpl IsA<Widget> for Revealer
impl IsA<Widget> for Revealerimpl IsA<Buildable> for Revealer
impl IsA<Buildable> for Revealerimpl IsA<Object> for Revealer
impl IsA<Object> for Revealerimpl Default for Revealer[src]
impl Default for Revealer