Struct gtk::ScrolledWindow [−]
pub struct ScrolledWindow(_, _);
Methods
impl ScrolledWindow[src]
impl ScrolledWindowpub fn new<'a, 'b, P: Into<Option<&'a Adjustment>>, Q: Into<Option<&'b Adjustment>>>(
hadjustment: P,
vadjustment: Q
) -> ScrolledWindow[src]
pub fn new<'a, 'b, P: Into<Option<&'a Adjustment>>, Q: Into<Option<&'b Adjustment>>>(
hadjustment: P,
vadjustment: Q
) -> ScrolledWindowTrait Implementations
impl IsA<ScrolledWindow> for PlacesSidebar
impl IsA<ScrolledWindow> for PlacesSidebarimpl Clone for ScrolledWindow
impl Clone for ScrolledWindowfn clone(&self) -> ScrolledWindow
fn clone(&self) -> ScrolledWindowReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ScrolledWindow
impl Hash for ScrolledWindowfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ScrolledWindow
impl Ord for ScrolledWindowfn cmp(&self, other: &ScrolledWindow) -> Ordering
fn cmp(&self, other: &ScrolledWindow) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ScrolledWindow
impl StaticType for ScrolledWindowfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ScrolledWindow
impl<T: IsA<Object>> PartialEq<T> for ScrolledWindowfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ScrolledWindow
impl Eq for ScrolledWindowimpl<T: IsA<Object>> PartialOrd<T> for ScrolledWindow
impl<T: IsA<Object>> PartialOrd<T> for ScrolledWindowfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ScrolledWindow
impl Debug for ScrolledWindowimpl IsA<Bin> for ScrolledWindow
impl IsA<Bin> for ScrolledWindowimpl IsA<Container> for ScrolledWindow
impl IsA<Container> for ScrolledWindowimpl IsA<Widget> for ScrolledWindow
impl IsA<Widget> for ScrolledWindowimpl IsA<Buildable> for ScrolledWindow
impl IsA<Buildable> for ScrolledWindowimpl IsA<Object> for ScrolledWindow
impl IsA<Object> for ScrolledWindowAuto Trait Implementations
impl !Send for ScrolledWindow
impl !Send for ScrolledWindowimpl !Sync for ScrolledWindow
impl !Sync for ScrolledWindow