Struct gtk::SelectionData [−]
pub struct SelectionData(_);
Methods
impl SelectionData[src]
impl SelectionDatapub fn get_data_type(&self) -> Atom[src]
pub fn get_data_type(&self) -> Atompub fn get_data_with_length(&self) -> Vec<u8>[src]
pub fn get_data_with_length(&self) -> Vec<u8>pub fn get_display(&self) -> Option<Display>[src]
pub fn get_display(&self) -> Option<Display>pub fn get_format(&self) -> i32[src]
pub fn get_format(&self) -> i32pub fn get_length(&self) -> i32[src]
pub fn get_length(&self) -> i32pub fn get_pixbuf(&self) -> Option<Pixbuf>[src]
pub fn get_pixbuf(&self) -> Option<Pixbuf>pub fn get_selection(&self) -> Atom[src]
pub fn get_selection(&self) -> Atompub fn get_target(&self) -> Atom[src]
pub fn get_target(&self) -> Atompub fn get_targets(&self) -> Option<Vec<Atom>>[src]
pub fn get_targets(&self) -> Option<Vec<Atom>>pub fn get_text(&self) -> Option<String>[src]
pub fn get_text(&self) -> Option<String>pub fn get_uris(&self) -> Vec<String>[src]
pub fn get_uris(&self) -> Vec<String>pub fn set(&mut self, type_: &Atom, format: i32, data: &[u8])[src]
pub fn set(&mut self, type_: &Atom, format: i32, data: &[u8])pub fn set_pixbuf(&self, pixbuf: &Pixbuf) -> bool[src]
pub fn set_pixbuf(&self, pixbuf: &Pixbuf) -> boolpub fn set_text(&self, str: &str) -> bool[src]
pub fn set_text(&self, str: &str) -> boolpub fn set_uris(&self, uris: &[&str]) -> bool[src]
pub fn set_uris(&self, uris: &[&str]) -> boolpub fn targets_include_image(&self, writable: bool) -> bool[src]
pub fn targets_include_image(&self, writable: bool) -> boolpub fn targets_include_rich_text(&self, buffer: &TextBuffer) -> bool[src]
pub fn targets_include_rich_text(&self, buffer: &TextBuffer) -> boolpub fn targets_include_text(&self) -> bool[src]
pub fn targets_include_text(&self) -> boolpub fn targets_include_uri(&self) -> bool[src]
pub fn targets_include_uri(&self) -> boolTrait Implementations
impl Debug for SelectionData[src]
impl Debug for SelectionDatafn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for SelectionData[src]
impl PartialEq for SelectionDatafn eq(&self, other: &SelectionData) -> bool[src]
fn eq(&self, other: &SelectionData) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &SelectionData) -> bool[src]
fn ne(&self, other: &SelectionData) -> boolThis method tests for !=.
impl Eq for SelectionData[src]
impl Eq for SelectionDataimpl PartialOrd for SelectionData[src]
impl PartialOrd for SelectionDatafn partial_cmp(&self, other: &SelectionData) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &SelectionData) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &SelectionData) -> bool[src]
fn lt(&self, other: &SelectionData) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &SelectionData) -> bool[src]
fn le(&self, other: &SelectionData) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &SelectionData) -> bool[src]
fn gt(&self, other: &SelectionData) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &SelectionData) -> bool[src]
fn ge(&self, other: &SelectionData) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for SelectionData[src]
impl Ord for SelectionDatafn cmp(&self, other: &SelectionData) -> Ordering[src]
fn cmp(&self, other: &SelectionData) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for SelectionData[src]
impl Hash for SelectionDatafn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for SelectionData
impl Clone for SelectionDatafn clone(&self) -> SelectionData
fn clone(&self) -> SelectionDataReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for SelectionData
impl StaticType for SelectionDatafn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.