Struct gtk::Separator [−]
pub struct Separator(_, _);
Methods
impl Separator[src]
impl Separatorpub fn new(orientation: Orientation) -> Separator[src]
pub fn new(orientation: Orientation) -> SeparatorTrait Implementations
impl Clone for Separator
impl Clone for Separatorfn clone(&self) -> Separator
fn clone(&self) -> SeparatorReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Separator
impl Hash for Separatorfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Separator
impl Ord for Separatorfn cmp(&self, other: &Separator) -> Ordering
fn cmp(&self, other: &Separator) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Separator
impl StaticType for Separatorfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Separator
impl<T: IsA<Object>> PartialEq<T> for Separatorfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Separator
impl Eq for Separatorimpl<T: IsA<Object>> PartialOrd<T> for Separator
impl<T: IsA<Object>> PartialOrd<T> for Separatorfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Separator
impl Debug for Separatorimpl IsA<Widget> for Separator
impl IsA<Widget> for Separatorimpl IsA<Buildable> for Separator
impl IsA<Buildable> for Separatorimpl IsA<Orientable> for Separator
impl IsA<Orientable> for Separatorimpl IsA<Object> for Separator
impl IsA<Object> for Separator