Struct gtk::SeparatorToolItem [−]
pub struct SeparatorToolItem(_, _);
Methods
impl SeparatorToolItem[src]
impl SeparatorToolItempub fn new() -> SeparatorToolItem[src]
pub fn new() -> SeparatorToolItemTrait Implementations
impl Clone for SeparatorToolItem
impl Clone for SeparatorToolItemfn clone(&self) -> SeparatorToolItem
fn clone(&self) -> SeparatorToolItemReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for SeparatorToolItem
impl Hash for SeparatorToolItemfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for SeparatorToolItem
impl Ord for SeparatorToolItemfn cmp(&self, other: &SeparatorToolItem) -> Ordering
fn cmp(&self, other: &SeparatorToolItem) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for SeparatorToolItem
impl StaticType for SeparatorToolItemfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for SeparatorToolItem
impl<T: IsA<Object>> PartialEq<T> for SeparatorToolItemfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for SeparatorToolItem
impl Eq for SeparatorToolItemimpl<T: IsA<Object>> PartialOrd<T> for SeparatorToolItem
impl<T: IsA<Object>> PartialOrd<T> for SeparatorToolItemfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for SeparatorToolItem
impl Debug for SeparatorToolItemimpl IsA<ToolItem> for SeparatorToolItem
impl IsA<ToolItem> for SeparatorToolItemimpl IsA<Bin> for SeparatorToolItem
impl IsA<Bin> for SeparatorToolItemimpl IsA<Container> for SeparatorToolItem
impl IsA<Container> for SeparatorToolItemimpl IsA<Widget> for SeparatorToolItem
impl IsA<Widget> for SeparatorToolItemimpl IsA<Buildable> for SeparatorToolItem
impl IsA<Buildable> for SeparatorToolItemimpl IsA<Object> for SeparatorToolItem
impl IsA<Object> for SeparatorToolItemimpl Default for SeparatorToolItem[src]
impl Default for SeparatorToolItemAuto Trait Implementations
impl !Send for SeparatorToolItem
impl !Send for SeparatorToolItemimpl !Sync for SeparatorToolItem
impl !Sync for SeparatorToolItem