Struct gtk::StateFlags [−]
pub struct StateFlags { /* fields omitted */ }Methods
impl StateFlags
impl StateFlagspub const NORMAL: StateFlags
NORMAL: StateFlags = StateFlags{bits: 0,}
pub const ACTIVE: StateFlags
ACTIVE: StateFlags = StateFlags{bits: 1,}
pub const PRELIGHT: StateFlags
PRELIGHT: StateFlags = StateFlags{bits: 2,}
pub const SELECTED: StateFlags
SELECTED: StateFlags = StateFlags{bits: 4,}
pub const INSENSITIVE: StateFlags
INSENSITIVE: StateFlags = StateFlags{bits: 8,}
pub const INCONSISTENT: StateFlags
INCONSISTENT: StateFlags = StateFlags{bits: 16,}
pub const FOCUSED: StateFlags
FOCUSED: StateFlags = StateFlags{bits: 32,}
pub const BACKDROP: StateFlags
BACKDROP: StateFlags = StateFlags{bits: 64,}
pub const DIR_LTR: StateFlags
DIR_LTR: StateFlags = StateFlags{bits: 128,}
pub const DIR_RTL: StateFlags
DIR_RTL: StateFlags = StateFlags{bits: 256,}
pub const LINK: StateFlags
LINK: StateFlags = StateFlags{bits: 512,}
pub const VISITED: StateFlags
VISITED: StateFlags = StateFlags{bits: 1024,}
pub const CHECKED: StateFlags
CHECKED: StateFlags = StateFlags{bits: 2048,}
pub const DROP_ACTIVE: StateFlags
DROP_ACTIVE: StateFlags = StateFlags{bits: 4096,}
pub fn empty() -> StateFlags
pub fn empty() -> StateFlagsReturns an empty set of flags.
pub fn all() -> StateFlags
pub fn all() -> StateFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<StateFlags>
pub fn from_bits(bits: u32) -> Option<StateFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> StateFlags
pub fn from_bits_truncate(bits: u32) -> StateFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: StateFlags) -> bool
pub fn intersects(&self, other: StateFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: StateFlags) -> bool
pub fn contains(&self, other: StateFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: StateFlags)
pub fn insert(&mut self, other: StateFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: StateFlags)
pub fn remove(&mut self, other: StateFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: StateFlags)
pub fn toggle(&mut self, other: StateFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: StateFlags, value: bool)
pub fn set(&mut self, other: StateFlags, value: bool)Inserts or removes the specified flags depending on the passed value.