Struct gtk::StyleContext [−]
pub struct StyleContext(_, _);
Methods
impl StyleContext[src]
impl StyleContextpub fn new() -> StyleContext[src]
pub fn new() -> StyleContextpub fn add_provider_for_screen<P: IsA<StyleProvider>>(
screen: &Screen,
provider: &P,
priority: u32
)[src]
pub fn add_provider_for_screen<P: IsA<StyleProvider>>(
screen: &Screen,
provider: &P,
priority: u32
)pub fn remove_provider_for_screen<P: IsA<StyleProvider>>(
screen: &Screen,
provider: &P
)[src]
pub fn remove_provider_for_screen<P: IsA<StyleProvider>>(
screen: &Screen,
provider: &P
)pub fn reset_widgets(screen: &Screen)[src]
pub fn reset_widgets(screen: &Screen)Trait Implementations
impl Clone for StyleContext
impl Clone for StyleContextfn clone(&self) -> StyleContext
fn clone(&self) -> StyleContextReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for StyleContext
impl Hash for StyleContextfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for StyleContext
impl Ord for StyleContextfn cmp(&self, other: &StyleContext) -> Ordering
fn cmp(&self, other: &StyleContext) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for StyleContext
impl StaticType for StyleContextfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for StyleContext
impl<T: IsA<Object>> PartialEq<T> for StyleContextfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for StyleContext
impl Eq for StyleContextimpl<T: IsA<Object>> PartialOrd<T> for StyleContext
impl<T: IsA<Object>> PartialOrd<T> for StyleContextfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for StyleContext
impl Debug for StyleContextimpl IsA<Object> for StyleContext
impl IsA<Object> for StyleContextimpl Default for StyleContext[src]
impl Default for StyleContextAuto Trait Implementations
impl !Send for StyleContext
impl !Send for StyleContextimpl !Sync for StyleContext
impl !Sync for StyleContext