Struct gtk::SymbolicColor [−]
pub struct SymbolicColor(_);
Methods
impl SymbolicColor[src]
impl SymbolicColorpub fn new_alpha(color: &SymbolicColor, factor: f64) -> SymbolicColor[src]
pub fn new_alpha(color: &SymbolicColor, factor: f64) -> SymbolicColorpub fn new_literal(color: &RGBA) -> SymbolicColor[src]
pub fn new_literal(color: &RGBA) -> SymbolicColorpub fn new_mix(
color1: &SymbolicColor,
color2: &SymbolicColor,
factor: f64
) -> SymbolicColor[src]
pub fn new_mix(
color1: &SymbolicColor,
color2: &SymbolicColor,
factor: f64
) -> SymbolicColorpub fn new_name(name: &str) -> SymbolicColor[src]
pub fn new_name(name: &str) -> SymbolicColorpub fn new_shade(color: &SymbolicColor, factor: f64) -> SymbolicColor[src]
pub fn new_shade(color: &SymbolicColor, factor: f64) -> SymbolicColorpub fn new_win32(theme_class: &str, id: i32) -> SymbolicColor[src]
pub fn new_win32(theme_class: &str, id: i32) -> SymbolicColorpub fn resolve<'a, P: Into<Option<&'a StyleProperties>>>(
&self,
props: P
) -> Option<RGBA>[src]
pub fn resolve<'a, P: Into<Option<&'a StyleProperties>>>(
&self,
props: P
) -> Option<RGBA>Trait Implementations
impl Debug for SymbolicColor[src]
impl Debug for SymbolicColorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for SymbolicColor[src]
impl PartialEq for SymbolicColorfn eq(&self, other: &SymbolicColor) -> bool[src]
fn eq(&self, other: &SymbolicColor) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &SymbolicColor) -> bool[src]
fn ne(&self, other: &SymbolicColor) -> boolThis method tests for !=.
impl Eq for SymbolicColor[src]
impl Eq for SymbolicColorimpl PartialOrd for SymbolicColor[src]
impl PartialOrd for SymbolicColorfn partial_cmp(&self, other: &SymbolicColor) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &SymbolicColor) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &SymbolicColor) -> bool[src]
fn lt(&self, other: &SymbolicColor) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &SymbolicColor) -> bool[src]
fn le(&self, other: &SymbolicColor) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &SymbolicColor) -> bool[src]
fn gt(&self, other: &SymbolicColor) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &SymbolicColor) -> bool[src]
fn ge(&self, other: &SymbolicColor) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for SymbolicColor[src]
impl Ord for SymbolicColorfn cmp(&self, other: &SymbolicColor) -> Ordering[src]
fn cmp(&self, other: &SymbolicColor) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for SymbolicColor[src]
impl Hash for SymbolicColorfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for SymbolicColor
impl Clone for SymbolicColorfn clone(&self) -> SymbolicColor
fn clone(&self) -> SymbolicColorReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for SymbolicColor
impl StaticType for SymbolicColorfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Display for SymbolicColor[src]
impl Display for SymbolicColorAuto Trait Implementations
impl !Send for SymbolicColor
impl !Send for SymbolicColorimpl !Sync for SymbolicColor
impl !Sync for SymbolicColor