Struct gtk::TargetFlags [−]
pub struct TargetFlags { /* fields omitted */ }Methods
impl TargetFlags
impl TargetFlagspub const SAME_APP: TargetFlags
SAME_APP: TargetFlags = TargetFlags{bits: 1,}
pub const SAME_WIDGET: TargetFlags
SAME_WIDGET: TargetFlags = TargetFlags{bits: 2,}
pub const OTHER_APP: TargetFlags
OTHER_APP: TargetFlags = TargetFlags{bits: 4,}
pub const OTHER_WIDGET: TargetFlags
OTHER_WIDGET: TargetFlags = TargetFlags{bits: 8,}
pub fn empty() -> TargetFlags
pub fn empty() -> TargetFlagsReturns an empty set of flags.
pub fn all() -> TargetFlags
pub fn all() -> TargetFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<TargetFlags>
pub fn from_bits(bits: u32) -> Option<TargetFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> TargetFlags
pub fn from_bits_truncate(bits: u32) -> TargetFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: TargetFlags) -> bool
pub fn intersects(&self, other: TargetFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: TargetFlags) -> bool
pub fn contains(&self, other: TargetFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: TargetFlags)
pub fn insert(&mut self, other: TargetFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: TargetFlags)
pub fn remove(&mut self, other: TargetFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: TargetFlags)
pub fn toggle(&mut self, other: TargetFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: TargetFlags, value: bool)
pub fn set(&mut self, other: TargetFlags, value: bool)Inserts or removes the specified flags depending on the passed value.