Struct gtk::TargetList [−]
pub struct TargetList(_);
Methods
impl TargetList[src]
impl TargetListpub fn add(&self, target: &Atom, flags: u32, info: u32)[src]
pub fn add(&self, target: &Atom, flags: u32, info: u32)pub fn add_image_targets(&self, info: u32, writable: bool)[src]
pub fn add_image_targets(&self, info: u32, writable: bool)pub fn add_rich_text_targets(
&self,
info: u32,
deserializable: bool,
buffer: &TextBuffer
)[src]
pub fn add_rich_text_targets(
&self,
info: u32,
deserializable: bool,
buffer: &TextBuffer
)pub fn add_text_targets(&self, info: u32)[src]
pub fn add_text_targets(&self, info: u32)pub fn add_uri_targets(&self, info: u32)[src]
pub fn add_uri_targets(&self, info: u32)pub fn find(&self, target: &Atom) -> Option<u32>[src]
pub fn find(&self, target: &Atom) -> Option<u32>pub fn remove(&self, target: &Atom)[src]
pub fn remove(&self, target: &Atom)impl TargetList[src]
impl TargetListpub fn new(targets: &[TargetEntry]) -> Self[src]
pub fn new(targets: &[TargetEntry]) -> SelfTrait Implementations
impl Debug for TargetList[src]
impl Debug for TargetListfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for TargetList[src]
impl PartialEq for TargetListfn eq(&self, other: &TargetList) -> bool[src]
fn eq(&self, other: &TargetList) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &TargetList) -> bool[src]
fn ne(&self, other: &TargetList) -> boolThis method tests for !=.
impl Eq for TargetList[src]
impl Eq for TargetListimpl PartialOrd for TargetList[src]
impl PartialOrd for TargetListfn partial_cmp(&self, other: &TargetList) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &TargetList) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &TargetList) -> bool[src]
fn lt(&self, other: &TargetList) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &TargetList) -> bool[src]
fn le(&self, other: &TargetList) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &TargetList) -> bool[src]
fn gt(&self, other: &TargetList) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &TargetList) -> bool[src]
fn ge(&self, other: &TargetList) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for TargetList[src]
impl Ord for TargetListfn cmp(&self, other: &TargetList) -> Ordering[src]
fn cmp(&self, other: &TargetList) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for TargetList[src]
impl Hash for TargetListfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for TargetList
impl Clone for TargetListfn clone(&self) -> TargetList
fn clone(&self) -> TargetListReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for TargetList
impl StaticType for TargetListfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.