Struct gtk::TextAttributes [−]
pub struct TextAttributes(_);
Methods
impl TextAttributes[src]
impl TextAttributespub fn new() -> TextAttributes[src]
pub fn new() -> TextAttributespub fn copy(&self) -> Option<TextAttributes>[src]
pub fn copy(&self) -> Option<TextAttributes>pub fn copy_values(&self, dest: &TextAttributes)[src]
pub fn copy_values(&self, dest: &TextAttributes)Trait Implementations
impl Debug for TextAttributes[src]
impl Debug for TextAttributesfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for TextAttributes[src]
impl PartialEq for TextAttributesfn eq(&self, other: &TextAttributes) -> bool[src]
fn eq(&self, other: &TextAttributes) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &TextAttributes) -> bool[src]
fn ne(&self, other: &TextAttributes) -> boolThis method tests for !=.
impl Eq for TextAttributes[src]
impl Eq for TextAttributesimpl PartialOrd for TextAttributes[src]
impl PartialOrd for TextAttributesfn partial_cmp(&self, other: &TextAttributes) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &TextAttributes) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &TextAttributes) -> bool[src]
fn lt(&self, other: &TextAttributes) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &TextAttributes) -> bool[src]
fn le(&self, other: &TextAttributes) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &TextAttributes) -> bool[src]
fn gt(&self, other: &TextAttributes) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &TextAttributes) -> bool[src]
fn ge(&self, other: &TextAttributes) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for TextAttributes[src]
impl Ord for TextAttributesfn cmp(&self, other: &TextAttributes) -> Ordering[src]
fn cmp(&self, other: &TextAttributes) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for TextAttributes[src]
impl Hash for TextAttributesfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for TextAttributes
impl Clone for TextAttributesfn clone(&self) -> TextAttributes
fn clone(&self) -> TextAttributesReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for TextAttributes
impl StaticType for TextAttributesfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Default for TextAttributes[src]
impl Default for TextAttributesAuto Trait Implementations
impl !Send for TextAttributes
impl !Send for TextAttributesimpl !Sync for TextAttributes
impl !Sync for TextAttributes