Struct gtk::TextTagTable [−]
pub struct TextTagTable(_, _);
Methods
impl TextTagTable[src]
impl TextTagTablepub fn new() -> TextTagTable[src]
pub fn new() -> TextTagTableTrait Implementations
impl Clone for TextTagTable
impl Clone for TextTagTablefn clone(&self) -> TextTagTable
fn clone(&self) -> TextTagTableReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for TextTagTable
impl Hash for TextTagTablefn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for TextTagTable
impl Ord for TextTagTablefn cmp(&self, other: &TextTagTable) -> Ordering
fn cmp(&self, other: &TextTagTable) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for TextTagTable
impl StaticType for TextTagTablefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for TextTagTable
impl<T: IsA<Object>> PartialEq<T> for TextTagTablefn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for TextTagTable
impl Eq for TextTagTableimpl<T: IsA<Object>> PartialOrd<T> for TextTagTable
impl<T: IsA<Object>> PartialOrd<T> for TextTagTablefn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for TextTagTable
impl Debug for TextTagTableimpl IsA<Buildable> for TextTagTable
impl IsA<Buildable> for TextTagTableimpl IsA<Object> for TextTagTable
impl IsA<Object> for TextTagTableimpl Default for TextTagTable[src]
impl Default for TextTagTableAuto Trait Implementations
impl !Send for TextTagTable
impl !Send for TextTagTableimpl !Sync for TextTagTable
impl !Sync for TextTagTable