Struct gtk::ToggleButton [−]
pub struct ToggleButton(_, _);
Methods
impl ToggleButton[src]
impl ToggleButtonpub fn new() -> ToggleButton[src]
pub fn new() -> ToggleButtonpub fn new_with_label(label: &str) -> ToggleButton[src]
pub fn new_with_label(label: &str) -> ToggleButtonpub fn new_with_mnemonic(label: &str) -> ToggleButton[src]
pub fn new_with_mnemonic(label: &str) -> ToggleButtonTrait Implementations
impl IsA<ToggleButton> for CheckButton
impl IsA<ToggleButton> for CheckButtonimpl IsA<ToggleButton> for MenuButton
impl IsA<ToggleButton> for MenuButtonimpl IsA<ToggleButton> for RadioButton
impl IsA<ToggleButton> for RadioButtonimpl Clone for ToggleButton
impl Clone for ToggleButtonfn clone(&self) -> ToggleButton
fn clone(&self) -> ToggleButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ToggleButton
impl Hash for ToggleButtonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ToggleButton
impl Ord for ToggleButtonfn cmp(&self, other: &ToggleButton) -> Ordering
fn cmp(&self, other: &ToggleButton) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ToggleButton
impl StaticType for ToggleButtonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ToggleButton
impl<T: IsA<Object>> PartialEq<T> for ToggleButtonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ToggleButton
impl Eq for ToggleButtonimpl<T: IsA<Object>> PartialOrd<T> for ToggleButton
impl<T: IsA<Object>> PartialOrd<T> for ToggleButtonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ToggleButton
impl Debug for ToggleButtonimpl IsA<Button> for ToggleButton
impl IsA<Button> for ToggleButtonimpl IsA<Bin> for ToggleButton
impl IsA<Bin> for ToggleButtonimpl IsA<Container> for ToggleButton
impl IsA<Container> for ToggleButtonimpl IsA<Widget> for ToggleButton
impl IsA<Widget> for ToggleButtonimpl IsA<Buildable> for ToggleButton
impl IsA<Buildable> for ToggleButtonimpl IsA<Actionable> for ToggleButton
impl IsA<Actionable> for ToggleButtonimpl IsA<Object> for ToggleButton
impl IsA<Object> for ToggleButtonimpl Default for ToggleButton[src]
impl Default for ToggleButtonAuto Trait Implementations
impl !Send for ToggleButton
impl !Send for ToggleButtonimpl !Sync for ToggleButton
impl !Sync for ToggleButton