Struct gtk::ToolButton [−]
pub struct ToolButton(_, _);
Methods
impl ToolButton[src]
impl ToolButtonpub fn new<'a, 'b, P: IsA<Widget> + 'a, Q: Into<Option<&'a P>>, R: Into<Option<&'b str>>>(
icon_widget: Q,
label: R
) -> ToolButton[src]
pub fn new<'a, 'b, P: IsA<Widget> + 'a, Q: Into<Option<&'a P>>, R: Into<Option<&'b str>>>(
icon_widget: Q,
label: R
) -> ToolButtonpub fn new_from_stock(stock_id: &str) -> ToolButton[src]
pub fn new_from_stock(stock_id: &str) -> ToolButtonTrait Implementations
impl IsA<ToolButton> for MenuToolButton
impl IsA<ToolButton> for MenuToolButtonimpl IsA<ToolButton> for RadioToolButton
impl IsA<ToolButton> for RadioToolButtonimpl IsA<ToolButton> for ToggleToolButton
impl IsA<ToolButton> for ToggleToolButtonimpl Clone for ToolButton
impl Clone for ToolButtonfn clone(&self) -> ToolButton
fn clone(&self) -> ToolButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ToolButton
impl Hash for ToolButtonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ToolButton
impl Ord for ToolButtonfn cmp(&self, other: &ToolButton) -> Ordering
fn cmp(&self, other: &ToolButton) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ToolButton
impl StaticType for ToolButtonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ToolButton
impl<T: IsA<Object>> PartialEq<T> for ToolButtonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ToolButton
impl Eq for ToolButtonimpl<T: IsA<Object>> PartialOrd<T> for ToolButton
impl<T: IsA<Object>> PartialOrd<T> for ToolButtonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ToolButton
impl Debug for ToolButtonimpl IsA<ToolItem> for ToolButton
impl IsA<ToolItem> for ToolButtonimpl IsA<Bin> for ToolButton
impl IsA<Bin> for ToolButtonimpl IsA<Container> for ToolButton
impl IsA<Container> for ToolButtonimpl IsA<Widget> for ToolButton
impl IsA<Widget> for ToolButtonimpl IsA<Buildable> for ToolButton
impl IsA<Buildable> for ToolButtonimpl IsA<Actionable> for ToolButton
impl IsA<Actionable> for ToolButtonimpl IsA<Object> for ToolButton
impl IsA<Object> for ToolButtonAuto Trait Implementations
impl !Send for ToolButton
impl !Send for ToolButtonimpl !Sync for ToolButton
impl !Sync for ToolButton