Struct gtk::ToolItem [−]
pub struct ToolItem(_, _);
Methods
impl ToolItem[src]
impl ToolItemTrait Implementations
impl IsA<ToolItem> for MenuToolButton
impl IsA<ToolItem> for MenuToolButtonimpl IsA<ToolItem> for RadioToolButton
impl IsA<ToolItem> for RadioToolButtonimpl IsA<ToolItem> for SeparatorToolItem
impl IsA<ToolItem> for SeparatorToolItemimpl IsA<ToolItem> for ToggleToolButton
impl IsA<ToolItem> for ToggleToolButtonimpl IsA<ToolItem> for ToolButton
impl IsA<ToolItem> for ToolButtonimpl Clone for ToolItem
impl Clone for ToolItemfn clone(&self) -> ToolItem
fn clone(&self) -> ToolItemReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ToolItem
impl Hash for ToolItemfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ToolItem
impl Ord for ToolItemfn cmp(&self, other: &ToolItem) -> Ordering
fn cmp(&self, other: &ToolItem) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ToolItem
impl StaticType for ToolItemfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ToolItem
impl<T: IsA<Object>> PartialEq<T> for ToolItemfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ToolItem
impl Eq for ToolItemimpl<T: IsA<Object>> PartialOrd<T> for ToolItem
impl<T: IsA<Object>> PartialOrd<T> for ToolItemfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ToolItem
impl Debug for ToolItemimpl IsA<Bin> for ToolItem
impl IsA<Bin> for ToolItemimpl IsA<Container> for ToolItem
impl IsA<Container> for ToolItemimpl IsA<Widget> for ToolItem
impl IsA<Widget> for ToolItemimpl IsA<Buildable> for ToolItem
impl IsA<Buildable> for ToolItemimpl IsA<Object> for ToolItem
impl IsA<Object> for ToolItemimpl Default for ToolItem[src]
impl Default for ToolItem