Struct gtk::ToolPalette [−]
pub struct ToolPalette(_, _);
Methods
impl ToolPalette[src]
impl ToolPalettepub fn new() -> ToolPalette[src]
pub fn new() -> ToolPalettepub fn get_drag_target_group() -> Option<TargetEntry>[src]
pub fn get_drag_target_group() -> Option<TargetEntry>pub fn get_drag_target_item() -> Option<TargetEntry>[src]
pub fn get_drag_target_item() -> Option<TargetEntry>Trait Implementations
impl Clone for ToolPalette
impl Clone for ToolPalettefn clone(&self) -> ToolPalette
fn clone(&self) -> ToolPaletteReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for ToolPalette
impl Hash for ToolPalettefn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for ToolPalette
impl Ord for ToolPalettefn cmp(&self, other: &ToolPalette) -> Ordering
fn cmp(&self, other: &ToolPalette) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for ToolPalette
impl StaticType for ToolPalettefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for ToolPalette
impl<T: IsA<Object>> PartialEq<T> for ToolPalettefn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for ToolPalette
impl Eq for ToolPaletteimpl<T: IsA<Object>> PartialOrd<T> for ToolPalette
impl<T: IsA<Object>> PartialOrd<T> for ToolPalettefn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for ToolPalette
impl Debug for ToolPaletteimpl IsA<Container> for ToolPalette
impl IsA<Container> for ToolPaletteimpl IsA<Widget> for ToolPalette
impl IsA<Widget> for ToolPaletteimpl IsA<Buildable> for ToolPalette
impl IsA<Buildable> for ToolPaletteimpl IsA<Orientable> for ToolPalette
impl IsA<Orientable> for ToolPaletteimpl IsA<Scrollable> for ToolPalette
impl IsA<Scrollable> for ToolPaletteimpl IsA<Object> for ToolPalette
impl IsA<Object> for ToolPaletteimpl Default for ToolPalette[src]
impl Default for ToolPaletteAuto Trait Implementations
impl !Send for ToolPalette
impl !Send for ToolPaletteimpl !Sync for ToolPalette
impl !Sync for ToolPalette