Struct gtk::ToolPaletteDragTargets [−]
pub struct ToolPaletteDragTargets { /* fields omitted */ }Methods
impl ToolPaletteDragTargets
impl ToolPaletteDragTargetspub const ITEMS: ToolPaletteDragTargets
ITEMS: ToolPaletteDragTargets = ToolPaletteDragTargets{bits: 1,}
pub const GROUPS: ToolPaletteDragTargets
GROUPS: ToolPaletteDragTargets = ToolPaletteDragTargets{bits: 2,}
pub fn empty() -> ToolPaletteDragTargets
pub fn empty() -> ToolPaletteDragTargetsReturns an empty set of flags.
pub fn all() -> ToolPaletteDragTargets
pub fn all() -> ToolPaletteDragTargetsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<ToolPaletteDragTargets>
pub fn from_bits(bits: u32) -> Option<ToolPaletteDragTargets>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> ToolPaletteDragTargets
pub fn from_bits_truncate(bits: u32) -> ToolPaletteDragTargetsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: ToolPaletteDragTargets) -> bool
pub fn intersects(&self, other: ToolPaletteDragTargets) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: ToolPaletteDragTargets) -> bool
pub fn contains(&self, other: ToolPaletteDragTargets) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ToolPaletteDragTargets)
pub fn insert(&mut self, other: ToolPaletteDragTargets)Inserts the specified flags in-place.
pub fn remove(&mut self, other: ToolPaletteDragTargets)
pub fn remove(&mut self, other: ToolPaletteDragTargets)Removes the specified flags in-place.
pub fn toggle(&mut self, other: ToolPaletteDragTargets)
pub fn toggle(&mut self, other: ToolPaletteDragTargets)Toggles the specified flags in-place.
pub fn set(&mut self, other: ToolPaletteDragTargets, value: bool)
pub fn set(&mut self, other: ToolPaletteDragTargets, value: bool)Inserts or removes the specified flags depending on the passed value.