Struct gtk::TreeModelFlags [−]
pub struct TreeModelFlags { /* fields omitted */ }Methods
impl TreeModelFlags
impl TreeModelFlagspub const ITERS_PERSIST: TreeModelFlags
ITERS_PERSIST: TreeModelFlags = TreeModelFlags{bits: 1,}
pub const LIST_ONLY: TreeModelFlags
LIST_ONLY: TreeModelFlags = TreeModelFlags{bits: 2,}
pub fn empty() -> TreeModelFlags
pub fn empty() -> TreeModelFlagsReturns an empty set of flags.
pub fn all() -> TreeModelFlags
pub fn all() -> TreeModelFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<TreeModelFlags>
pub fn from_bits(bits: u32) -> Option<TreeModelFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> TreeModelFlags
pub fn from_bits_truncate(bits: u32) -> TreeModelFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: TreeModelFlags) -> bool
pub fn intersects(&self, other: TreeModelFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: TreeModelFlags) -> bool
pub fn contains(&self, other: TreeModelFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: TreeModelFlags)
pub fn insert(&mut self, other: TreeModelFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: TreeModelFlags)
pub fn remove(&mut self, other: TreeModelFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: TreeModelFlags)
pub fn toggle(&mut self, other: TreeModelFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: TreeModelFlags, value: bool)
pub fn set(&mut self, other: TreeModelFlags, value: bool)Inserts or removes the specified flags depending on the passed value.