Struct gtk::TreePath [−]
pub struct TreePath(_);
Methods
impl TreePath[src]
impl TreePathpub fn new() -> TreePath[src]
pub fn new() -> TreePathpub fn new_first() -> TreePath[src]
pub fn new_first() -> TreePathpub fn new_from_string(path: &str) -> TreePath[src]
pub fn new_from_string(path: &str) -> TreePathpub fn append_index(&mut self, index_: i32)[src]
pub fn append_index(&mut self, index_: i32)pub fn down(&mut self)[src]
pub fn down(&mut self)pub fn get_depth(&self) -> i32[src]
pub fn get_depth(&self) -> i32pub fn get_indices_with_depth(&mut self) -> Vec<i32>[src]
pub fn get_indices_with_depth(&mut self) -> Vec<i32>pub fn is_ancestor(&self, descendant: &TreePath) -> bool[src]
pub fn is_ancestor(&self, descendant: &TreePath) -> boolpub fn is_descendant(&self, ancestor: &TreePath) -> bool[src]
pub fn is_descendant(&self, ancestor: &TreePath) -> boolpub fn next(&mut self)[src]
pub fn next(&mut self)pub fn prepend_index(&mut self, index_: i32)[src]
pub fn prepend_index(&mut self, index_: i32)pub fn prev(&mut self) -> bool[src]
pub fn prev(&mut self) -> boolpub fn up(&mut self) -> bool[src]
pub fn up(&mut self) -> boolimpl TreePath[src]
impl TreePathTrait Implementations
impl Debug for TreePath[src]
impl Debug for TreePathfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for TreePath[src]
impl Hash for TreePathfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for TreePath
impl Clone for TreePathfn clone(&self) -> TreePath
fn clone(&self) -> TreePathReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for TreePath
impl StaticType for TreePathfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Default for TreePath[src]
impl Default for TreePathimpl PartialEq for TreePath[src]
impl PartialEq for TreePathfn eq(&self, other: &Self) -> bool[src]
fn eq(&self, other: &Self) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for TreePath[src]
impl Eq for TreePathimpl PartialOrd for TreePath[src]
impl PartialOrd for TreePathfn partial_cmp(&self, other: &Self) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &Self) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for TreePath[src]
impl Ord for TreePathfn cmp(&self, other: &Self) -> Ordering[src]
fn cmp(&self, other: &Self) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Display for TreePath[src]
impl Display for TreePath