Struct gtk::TreeRowReference [−]
pub struct TreeRowReference(_);
Methods
impl TreeRowReference[src]
impl TreeRowReferencepub fn new<P: IsA<TreeModel>>(
model: &P,
path: &TreePath
) -> Option<TreeRowReference>[src]
pub fn new<P: IsA<TreeModel>>(
model: &P,
path: &TreePath
) -> Option<TreeRowReference>pub fn new_proxy<P: IsA<Object>, Q: IsA<TreeModel>>(
proxy: &P,
model: &Q,
path: &TreePath
) -> Option<TreeRowReference>[src]
pub fn new_proxy<P: IsA<Object>, Q: IsA<TreeModel>>(
proxy: &P,
model: &Q,
path: &TreePath
) -> Option<TreeRowReference>pub fn get_model(&self) -> TreeModel[src]
pub fn get_model(&self) -> TreeModelpub fn get_path(&self) -> Option<TreePath>[src]
pub fn get_path(&self) -> Option<TreePath>pub fn valid(&self) -> bool[src]
pub fn valid(&self) -> boolpub fn deleted<P: IsA<Object>>(proxy: &P, path: &TreePath)[src]
pub fn deleted<P: IsA<Object>>(proxy: &P, path: &TreePath)pub fn inserted<P: IsA<Object>>(proxy: &P, path: &TreePath)[src]
pub fn inserted<P: IsA<Object>>(proxy: &P, path: &TreePath)impl TreeRowReference[src]
impl TreeRowReferencepub unsafe fn reordered<T: IsA<Object>>(
proxy: &T,
path: &TreePath,
iter: Option<&TreeIter>,
new_order: &[u32]
)[src]
pub unsafe fn reordered<T: IsA<Object>>(
proxy: &T,
path: &TreePath,
iter: Option<&TreeIter>,
new_order: &[u32]
)Trait Implementations
impl Debug for TreeRowReference[src]
impl Debug for TreeRowReferencefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for TreeRowReference[src]
impl PartialEq for TreeRowReferencefn eq(&self, other: &TreeRowReference) -> bool[src]
fn eq(&self, other: &TreeRowReference) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &TreeRowReference) -> bool[src]
fn ne(&self, other: &TreeRowReference) -> boolThis method tests for !=.
impl Eq for TreeRowReference[src]
impl Eq for TreeRowReferenceimpl PartialOrd for TreeRowReference[src]
impl PartialOrd for TreeRowReferencefn partial_cmp(&self, other: &TreeRowReference) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &TreeRowReference) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &TreeRowReference) -> bool[src]
fn lt(&self, other: &TreeRowReference) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &TreeRowReference) -> bool[src]
fn le(&self, other: &TreeRowReference) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &TreeRowReference) -> bool[src]
fn gt(&self, other: &TreeRowReference) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &TreeRowReference) -> bool[src]
fn ge(&self, other: &TreeRowReference) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for TreeRowReference[src]
impl Ord for TreeRowReferencefn cmp(&self, other: &TreeRowReference) -> Ordering[src]
fn cmp(&self, other: &TreeRowReference) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for TreeRowReference[src]
impl Hash for TreeRowReferencefn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for TreeRowReference
impl Clone for TreeRowReferencefn clone(&self) -> TreeRowReference
fn clone(&self) -> TreeRowReferenceReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for TreeRowReference
impl StaticType for TreeRowReferencefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.