Struct gtk::VolumeButton [−]
pub struct VolumeButton(_, _);
Methods
impl VolumeButton[src]
impl VolumeButtonpub fn new() -> VolumeButton[src]
pub fn new() -> VolumeButtonTrait Implementations
impl Clone for VolumeButton
impl Clone for VolumeButtonfn clone(&self) -> VolumeButton
fn clone(&self) -> VolumeButtonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for VolumeButton
impl Hash for VolumeButtonfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for VolumeButton
impl Ord for VolumeButtonfn cmp(&self, other: &VolumeButton) -> Ordering
fn cmp(&self, other: &VolumeButton) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for VolumeButton
impl StaticType for VolumeButtonfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for VolumeButton
impl<T: IsA<Object>> PartialEq<T> for VolumeButtonfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for VolumeButton
impl Eq for VolumeButtonimpl<T: IsA<Object>> PartialOrd<T> for VolumeButton
impl<T: IsA<Object>> PartialOrd<T> for VolumeButtonfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for VolumeButton
impl Debug for VolumeButtonimpl IsA<ScaleButton> for VolumeButton
impl IsA<ScaleButton> for VolumeButtonimpl IsA<Button> for VolumeButton
impl IsA<Button> for VolumeButtonimpl IsA<Bin> for VolumeButton
impl IsA<Bin> for VolumeButtonimpl IsA<Container> for VolumeButton
impl IsA<Container> for VolumeButtonimpl IsA<Widget> for VolumeButton
impl IsA<Widget> for VolumeButtonimpl IsA<Buildable> for VolumeButton
impl IsA<Buildable> for VolumeButtonimpl IsA<Actionable> for VolumeButton
impl IsA<Actionable> for VolumeButtonimpl IsA<Orientable> for VolumeButton
impl IsA<Orientable> for VolumeButtonimpl IsA<Object> for VolumeButton
impl IsA<Object> for VolumeButtonimpl Default for VolumeButton[src]
impl Default for VolumeButtonAuto Trait Implementations
impl !Send for VolumeButton
impl !Send for VolumeButtonimpl !Sync for VolumeButton
impl !Sync for VolumeButton