Struct gtk::WidgetPath [−]
pub struct WidgetPath(_);
Methods
impl WidgetPath[src]
impl WidgetPathpub fn new() -> WidgetPath[src]
pub fn new() -> WidgetPathpub fn append_for_widget<P: IsA<Widget>>(&self, widget: &P) -> i32[src]
pub fn append_for_widget<P: IsA<Widget>>(&self, widget: &P) -> i32pub fn append_type(&self, type_: Type) -> i32[src]
pub fn append_type(&self, type_: Type) -> i32pub fn append_with_siblings(
&self,
siblings: &WidgetPath,
sibling_index: u32
) -> i32[src]
pub fn append_with_siblings(
&self,
siblings: &WidgetPath,
sibling_index: u32
) -> i32pub fn copy(&self) -> Option<WidgetPath>[src]
pub fn copy(&self) -> Option<WidgetPath>pub fn get_object_type(&self) -> Type[src]
pub fn get_object_type(&self) -> Typepub fn has_parent(&self, type_: Type) -> bool[src]
pub fn has_parent(&self, type_: Type) -> boolpub fn is_type(&self, type_: Type) -> bool[src]
pub fn is_type(&self, type_: Type) -> boolpub fn iter_add_class(&self, pos: i32, name: &str)[src]
pub fn iter_add_class(&self, pos: i32, name: &str)pub fn iter_add_region(&self, pos: i32, name: &str, flags: RegionFlags)[src]
pub fn iter_add_region(&self, pos: i32, name: &str, flags: RegionFlags)pub fn iter_clear_classes(&self, pos: i32)[src]
pub fn iter_clear_classes(&self, pos: i32)pub fn iter_clear_regions(&self, pos: i32)[src]
pub fn iter_clear_regions(&self, pos: i32)pub fn iter_get_name(&self, pos: i32) -> Option<String>[src]
pub fn iter_get_name(&self, pos: i32) -> Option<String>pub fn iter_get_object_type(&self, pos: i32) -> Type[src]
pub fn iter_get_object_type(&self, pos: i32) -> Typepub fn iter_get_sibling_index(&self, pos: i32) -> u32[src]
pub fn iter_get_sibling_index(&self, pos: i32) -> u32pub fn iter_get_siblings(&self, pos: i32) -> Option<WidgetPath>[src]
pub fn iter_get_siblings(&self, pos: i32) -> Option<WidgetPath>pub fn iter_has_class(&self, pos: i32, name: &str) -> bool[src]
pub fn iter_has_class(&self, pos: i32, name: &str) -> boolpub fn iter_has_name(&self, pos: i32, name: &str) -> bool[src]
pub fn iter_has_name(&self, pos: i32, name: &str) -> boolpub fn iter_has_qclass(&self, pos: i32, qname: Quark) -> bool[src]
pub fn iter_has_qclass(&self, pos: i32, qname: Quark) -> boolpub fn iter_has_qname(&self, pos: i32, qname: Quark) -> bool[src]
pub fn iter_has_qname(&self, pos: i32, qname: Quark) -> boolpub fn iter_has_qregion(&self, pos: i32, qname: Quark) -> Option<RegionFlags>[src]
pub fn iter_has_qregion(&self, pos: i32, qname: Quark) -> Option<RegionFlags>pub fn iter_has_region(&self, pos: i32, name: &str) -> Option<RegionFlags>[src]
pub fn iter_has_region(&self, pos: i32, name: &str) -> Option<RegionFlags>pub fn iter_list_classes(&self, pos: i32) -> Vec<String>[src]
pub fn iter_list_classes(&self, pos: i32) -> Vec<String>pub fn iter_list_regions(&self, pos: i32) -> Vec<String>[src]
pub fn iter_list_regions(&self, pos: i32) -> Vec<String>pub fn iter_remove_class(&self, pos: i32, name: &str)[src]
pub fn iter_remove_class(&self, pos: i32, name: &str)pub fn iter_remove_region(&self, pos: i32, name: &str)[src]
pub fn iter_remove_region(&self, pos: i32, name: &str)pub fn iter_set_name(&self, pos: i32, name: &str)[src]
pub fn iter_set_name(&self, pos: i32, name: &str)pub fn iter_set_object_type(&self, pos: i32, type_: Type)[src]
pub fn iter_set_object_type(&self, pos: i32, type_: Type)pub fn length(&self) -> i32[src]
pub fn length(&self) -> i32pub fn prepend_type(&self, type_: Type)[src]
pub fn prepend_type(&self, type_: Type)Trait Implementations
impl Debug for WidgetPath[src]
impl Debug for WidgetPathfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for WidgetPath[src]
impl PartialEq for WidgetPathfn eq(&self, other: &WidgetPath) -> bool[src]
fn eq(&self, other: &WidgetPath) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &WidgetPath) -> bool[src]
fn ne(&self, other: &WidgetPath) -> boolThis method tests for !=.
impl Eq for WidgetPath[src]
impl Eq for WidgetPathimpl PartialOrd for WidgetPath[src]
impl PartialOrd for WidgetPathfn partial_cmp(&self, other: &WidgetPath) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &WidgetPath) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &WidgetPath) -> bool[src]
fn lt(&self, other: &WidgetPath) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &WidgetPath) -> bool[src]
fn le(&self, other: &WidgetPath) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &WidgetPath) -> bool[src]
fn gt(&self, other: &WidgetPath) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &WidgetPath) -> bool[src]
fn ge(&self, other: &WidgetPath) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for WidgetPath[src]
impl Ord for WidgetPathfn cmp(&self, other: &WidgetPath) -> Ordering[src]
fn cmp(&self, other: &WidgetPath) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for WidgetPath[src]
impl Hash for WidgetPathfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for WidgetPath
impl Clone for WidgetPathfn clone(&self) -> WidgetPath
fn clone(&self) -> WidgetPathReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for WidgetPath
impl StaticType for WidgetPathfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Default for WidgetPath[src]
impl Default for WidgetPathimpl Display for WidgetPath[src]
impl Display for WidgetPathAuto Trait Implementations
impl !Send for WidgetPath
impl !Send for WidgetPathimpl !Sync for WidgetPath
impl !Sync for WidgetPath