Struct gtk::Window [−]
pub struct Window(_, _);
Methods
impl Window[src]
impl Windowpub fn new(type_: WindowType) -> Window[src]
pub fn new(type_: WindowType) -> Windowpub fn get_default_icon_list() -> Vec<Pixbuf>[src]
pub fn get_default_icon_list() -> Vec<Pixbuf>pub fn get_default_icon_name() -> Option<String>[src]
pub fn get_default_icon_name() -> Option<String>pub fn list_toplevels() -> Vec<Widget>[src]
pub fn list_toplevels() -> Vec<Widget>pub fn set_auto_startup_notification(setting: bool)[src]
pub fn set_auto_startup_notification(setting: bool)pub fn set_default_icon(icon: &Pixbuf)[src]
pub fn set_default_icon(icon: &Pixbuf)pub fn set_default_icon_from_file<P: AsRef<Path>>(
filename: P
) -> Result<(), Error>[src]
pub fn set_default_icon_from_file<P: AsRef<Path>>(
filename: P
) -> Result<(), Error>pub fn set_default_icon_list(list: &[Pixbuf])[src]
pub fn set_default_icon_list(list: &[Pixbuf])pub fn set_default_icon_name(name: &str)[src]
pub fn set_default_icon_name(name: &str)Trait Implementations
impl IsA<Window> for AboutDialog
impl IsA<Window> for AboutDialogimpl IsA<Window> for AppChooserDialog
impl IsA<Window> for AppChooserDialogimpl IsA<Window> for ApplicationWindow
impl IsA<Window> for ApplicationWindowimpl IsA<Window> for Assistant
impl IsA<Window> for Assistantimpl IsA<Window> for ColorChooserDialog
impl IsA<Window> for ColorChooserDialogimpl IsA<Window> for Dialog
impl IsA<Window> for Dialogimpl IsA<Window> for FileChooserDialog
impl IsA<Window> for FileChooserDialogimpl IsA<Window> for FontChooserDialog
impl IsA<Window> for FontChooserDialogimpl IsA<Window> for MessageDialog
impl IsA<Window> for MessageDialogimpl IsA<Window> for OffscreenWindow
impl IsA<Window> for OffscreenWindowimpl IsA<Window> for Plug
impl IsA<Window> for Plugimpl IsA<Window> for RecentChooserDialog
impl IsA<Window> for RecentChooserDialogimpl Clone for Window
impl Clone for Windowfn clone(&self) -> Window
fn clone(&self) -> WindowReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for Window
impl Hash for Windowfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for Window
impl Ord for Windowfn cmp(&self, other: &Window) -> Ordering
fn cmp(&self, other: &Window) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for Window
impl StaticType for Windowfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Window
impl<T: IsA<Object>> PartialEq<T> for Windowfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Window
impl Eq for Windowimpl<T: IsA<Object>> PartialOrd<T> for Window
impl<T: IsA<Object>> PartialOrd<T> for Windowfn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for Window
impl Debug for Windowimpl IsA<Bin> for Window
impl IsA<Bin> for Windowimpl IsA<Container> for Window
impl IsA<Container> for Windowimpl IsA<Widget> for Window
impl IsA<Widget> for Windowimpl IsA<Buildable> for Window
impl IsA<Buildable> for Windowimpl IsA<Object> for Window
impl IsA<Object> for Window