Struct pango::AttrIterator [−]
pub struct AttrIterator(_);
Methods
impl AttrIterator[src]
impl AttrIteratorpub fn get(&mut self, type_: AttrType) -> Option<Attribute>[src]
pub fn get(&mut self, type_: AttrType) -> Option<Attribute>pub fn get_attrs(&mut self) -> Vec<Attribute>[src]
pub fn get_attrs(&mut self) -> Vec<Attribute>pub fn next(&mut self) -> bool[src]
pub fn next(&mut self) -> boolpub fn range(&mut self) -> (i32, i32)[src]
pub fn range(&mut self) -> (i32, i32)impl AttrIterator[src]
impl AttrIteratorpub fn get_font<'a, P: Into<Option<&'a Language>>>(
&mut self,
desc: &mut FontDescription,
language: P,
extra_attrs: &[&Attribute]
)[src]
pub fn get_font<'a, P: Into<Option<&'a Language>>>(
&mut self,
desc: &mut FontDescription,
language: P,
extra_attrs: &[&Attribute]
)Trait Implementations
impl Debug for AttrIterator[src]
impl Debug for AttrIteratorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for AttrIterator[src]
impl PartialEq for AttrIteratorfn eq(&self, other: &AttrIterator) -> bool[src]
fn eq(&self, other: &AttrIterator) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &AttrIterator) -> bool[src]
fn ne(&self, other: &AttrIterator) -> boolThis method tests for !=.
impl Eq for AttrIterator[src]
impl Eq for AttrIteratorimpl PartialOrd for AttrIterator[src]
impl PartialOrd for AttrIteratorfn partial_cmp(&self, other: &AttrIterator) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &AttrIterator) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &AttrIterator) -> bool[src]
fn lt(&self, other: &AttrIterator) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &AttrIterator) -> bool[src]
fn le(&self, other: &AttrIterator) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &AttrIterator) -> bool[src]
fn gt(&self, other: &AttrIterator) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &AttrIterator) -> bool[src]
fn ge(&self, other: &AttrIterator) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for AttrIterator[src]
impl Ord for AttrIteratorfn cmp(&self, other: &AttrIterator) -> Ordering[src]
fn cmp(&self, other: &AttrIterator) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for AttrIterator[src]
impl Hash for AttrIteratorfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for AttrIterator
impl Clone for AttrIteratorfn clone(&self) -> AttrIterator
fn clone(&self) -> AttrIteratorReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more