Struct pango::AttrList [−]
pub struct AttrList(_);
Methods
impl AttrList[src]
impl AttrListpub fn new() -> AttrList[src]
pub fn new() -> AttrListpub fn copy(&self) -> Option<AttrList>[src]
pub fn copy(&self) -> Option<AttrList>pub fn get_iterator(&self) -> Option<AttrIterator>[src]
pub fn get_iterator(&self) -> Option<AttrIterator>pub fn splice(&self, other: &AttrList, pos: i32, len: i32)[src]
pub fn splice(&self, other: &AttrList, pos: i32, len: i32)impl AttrList[src]
impl AttrListpub fn change(&self, attr: Attribute)[src]
pub fn change(&self, attr: Attribute)pub fn insert(&self, attr: Attribute)[src]
pub fn insert(&self, attr: Attribute)pub fn insert_before(&self, attr: Attribute)[src]
pub fn insert_before(&self, attr: Attribute)Trait Implementations
impl Debug for AttrList[src]
impl Debug for AttrListfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for AttrList[src]
impl PartialEq for AttrListfn eq(&self, other: &AttrList) -> bool[src]
fn eq(&self, other: &AttrList) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &AttrList) -> bool[src]
fn ne(&self, other: &AttrList) -> boolThis method tests for !=.
impl Eq for AttrList[src]
impl Eq for AttrListimpl PartialOrd for AttrList[src]
impl PartialOrd for AttrListfn partial_cmp(&self, other: &AttrList) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &AttrList) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &AttrList) -> bool[src]
fn lt(&self, other: &AttrList) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &AttrList) -> bool[src]
fn le(&self, other: &AttrList) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &AttrList) -> bool[src]
fn gt(&self, other: &AttrList) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &AttrList) -> bool[src]
fn ge(&self, other: &AttrList) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for AttrList[src]
impl Ord for AttrListfn cmp(&self, other: &AttrList) -> Ordering[src]
fn cmp(&self, other: &AttrList) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for AttrList[src]
impl Hash for AttrListfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for AttrList
impl Clone for AttrListfn clone(&self) -> AttrList
fn clone(&self) -> AttrListReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for AttrList
impl StaticType for AttrListfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Default for AttrList[src]
impl Default for AttrList