Struct pango::Attribute [−]
pub struct Attribute(_);
Methods
impl Attribute[src]
impl Attributeimpl Attribute[src]
impl Attributepub fn new_background(red: u16, green: u16, blue: u16) -> Option<Attribute>[src]
pub fn new_background(red: u16, green: u16, blue: u16) -> Option<Attribute>pub fn new_fallback(enable_fallback: bool) -> Option<Attribute>[src]
pub fn new_fallback(enable_fallback: bool) -> Option<Attribute>pub fn new_family(family: &str) -> Option<Attribute>[src]
pub fn new_family(family: &str) -> Option<Attribute>pub fn new_foreground(red: u16, green: u16, blue: u16) -> Option<Attribute>[src]
pub fn new_foreground(red: u16, green: u16, blue: u16) -> Option<Attribute>pub fn new_gravity_hint(hint: GravityHint) -> Option<Attribute>[src]
pub fn new_gravity_hint(hint: GravityHint) -> Option<Attribute>pub fn new_gravity(gravity: Gravity) -> Option<Attribute>[src]
pub fn new_gravity(gravity: Gravity) -> Option<Attribute>pub fn new_letter_spacing(letter_spacing: i32) -> Option<Attribute>[src]
pub fn new_letter_spacing(letter_spacing: i32) -> Option<Attribute>pub fn new_rise(rise: i32) -> Option<Attribute>[src]
pub fn new_rise(rise: i32) -> Option<Attribute>pub fn new_scale(scale_factor: f64) -> Option<Attribute>[src]
pub fn new_scale(scale_factor: f64) -> Option<Attribute>pub fn new_stretch(stretch: Stretch) -> Option<Attribute>[src]
pub fn new_stretch(stretch: Stretch) -> Option<Attribute>pub fn new_strikethrough_color(
red: u16,
green: u16,
blue: u16
) -> Option<Attribute>[src]
pub fn new_strikethrough_color(
red: u16,
green: u16,
blue: u16
) -> Option<Attribute>pub fn new_strikethrough(strikethrough: bool) -> Option<Attribute>[src]
pub fn new_strikethrough(strikethrough: bool) -> Option<Attribute>pub fn new_style(style: Style) -> Option<Attribute>[src]
pub fn new_style(style: Style) -> Option<Attribute>pub fn new_underline_color(red: u16, green: u16, blue: u16) -> Option<Attribute>[src]
pub fn new_underline_color(red: u16, green: u16, blue: u16) -> Option<Attribute>pub fn new_underline(underline: Underline) -> Option<Attribute>[src]
pub fn new_underline(underline: Underline) -> Option<Attribute>pub fn new_variant(variant: Variant) -> Option<Attribute>[src]
pub fn new_variant(variant: Variant) -> Option<Attribute>pub fn new_weight(weight: Weight) -> Option<Attribute>[src]
pub fn new_weight(weight: Weight) -> Option<Attribute>pub fn get_attr_class(&self) -> AttrClass[src]
pub fn get_attr_class(&self) -> AttrClasspub fn get_start_index(&self) -> u32[src]
pub fn get_start_index(&self) -> u32pub fn get_end_index(&self) -> u32[src]
pub fn get_end_index(&self) -> u32pub fn set_start_index(&mut self, index: u32)[src]
pub fn set_start_index(&mut self, index: u32)pub fn set_end_index(&mut self, index: u32)[src]
pub fn set_end_index(&mut self, index: u32)Trait Implementations
impl Debug for Attribute[src]
impl Debug for Attributefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialOrd for Attribute[src]
impl PartialOrd for Attributefn partial_cmp(&self, other: &Attribute) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &Attribute) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Attribute) -> bool[src]
fn lt(&self, other: &Attribute) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Attribute) -> bool[src]
fn le(&self, other: &Attribute) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Attribute) -> bool[src]
fn gt(&self, other: &Attribute) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Attribute) -> bool[src]
fn ge(&self, other: &Attribute) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for Attribute[src]
impl Ord for Attributefn cmp(&self, other: &Attribute) -> Ordering[src]
fn cmp(&self, other: &Attribute) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for Attribute[src]
impl Hash for Attributefn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for Attribute
impl Clone for Attributefn clone(&self) -> Attribute
fn clone(&self) -> AttributeReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl PartialEq for Attribute[src]
impl PartialEq for Attributefn eq(&self, other: &Self) -> bool[src]
fn eq(&self, other: &Self) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Attribute[src]
impl Eq for Attribute