Struct pango::Coverage [−]
pub struct Coverage(_);
Methods
impl Coverage[src]
impl Coveragepub fn copy(&self) -> Option<Coverage>[src]
pub fn copy(&self) -> Option<Coverage>pub fn get(&self, index_: i32) -> CoverageLevel[src]
pub fn get(&self, index_: i32) -> CoverageLevelpub fn max(&self, other: &Coverage)[src]
pub fn max(&self, other: &Coverage)pub fn set(&self, index_: i32, level: CoverageLevel)[src]
pub fn set(&self, index_: i32, level: CoverageLevel)pub fn to_bytes(&self) -> Vec<u8>[src]
pub fn to_bytes(&self) -> Vec<u8>pub fn from_bytes(bytes: &[u8]) -> Option<Coverage>[src]
pub fn from_bytes(bytes: &[u8]) -> Option<Coverage>pub fn new() -> Coverage[src]
pub fn new() -> CoverageTrait Implementations
impl Debug for Coverage[src]
impl Debug for Coveragefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for Coverage[src]
impl PartialEq for Coveragefn eq(&self, other: &Coverage) -> bool[src]
fn eq(&self, other: &Coverage) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Coverage) -> bool[src]
fn ne(&self, other: &Coverage) -> boolThis method tests for !=.
impl Eq for Coverage[src]
impl Eq for Coverageimpl PartialOrd for Coverage[src]
impl PartialOrd for Coveragefn partial_cmp(&self, other: &Coverage) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &Coverage) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Coverage) -> bool[src]
fn lt(&self, other: &Coverage) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Coverage) -> bool[src]
fn le(&self, other: &Coverage) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Coverage) -> bool[src]
fn gt(&self, other: &Coverage) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Coverage) -> bool[src]
fn ge(&self, other: &Coverage) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for Coverage[src]
impl Ord for Coveragefn cmp(&self, other: &Coverage) -> Ordering[src]
fn cmp(&self, other: &Coverage) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for Coverage[src]
impl Hash for Coveragefn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for Coverage
impl Clone for Coveragefn clone(&self) -> Coverage
fn clone(&self) -> CoverageReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Default for Coverage[src]
impl Default for Coverage