Struct pango::FontDescription [−]
pub struct FontDescription(_);
Methods
impl FontDescription[src]
impl FontDescriptionpub fn new() -> FontDescription[src]
pub fn new() -> FontDescriptionpub fn better_match<'a, P: Into<Option<&'a FontDescription>>>(
&self,
old_match: P,
new_match: &FontDescription
) -> bool[src]
pub fn better_match<'a, P: Into<Option<&'a FontDescription>>>(
&self,
old_match: P,
new_match: &FontDescription
) -> boolpub fn get_family(&self) -> Option<String>[src]
pub fn get_family(&self) -> Option<String>pub fn get_gravity(&self) -> Gravity[src]
pub fn get_gravity(&self) -> Gravitypub fn get_set_fields(&self) -> FontMask[src]
pub fn get_set_fields(&self) -> FontMaskpub fn get_size(&self) -> i32[src]
pub fn get_size(&self) -> i32pub fn get_size_is_absolute(&self) -> bool[src]
pub fn get_size_is_absolute(&self) -> boolpub fn get_stretch(&self) -> Stretch[src]
pub fn get_stretch(&self) -> Stretchpub fn get_style(&self) -> Style[src]
pub fn get_style(&self) -> Stylepub fn get_variant(&self) -> Variant[src]
pub fn get_variant(&self) -> Variantpub fn get_weight(&self) -> Weight[src]
pub fn get_weight(&self) -> Weightpub fn merge<'a, P: Into<Option<&'a FontDescription>>>(
&mut self,
desc_to_merge: P,
replace_existing: bool
)[src]
pub fn merge<'a, P: Into<Option<&'a FontDescription>>>(
&mut self,
desc_to_merge: P,
replace_existing: bool
)pub fn set_absolute_size(&mut self, size: f64)[src]
pub fn set_absolute_size(&mut self, size: f64)pub fn set_family(&mut self, family: &str)[src]
pub fn set_family(&mut self, family: &str)pub fn set_gravity(&mut self, gravity: Gravity)[src]
pub fn set_gravity(&mut self, gravity: Gravity)pub fn set_size(&mut self, size: i32)[src]
pub fn set_size(&mut self, size: i32)pub fn set_stretch(&mut self, stretch: Stretch)[src]
pub fn set_stretch(&mut self, stretch: Stretch)pub fn set_style(&mut self, style: Style)[src]
pub fn set_style(&mut self, style: Style)pub fn set_variant(&mut self, variant: Variant)[src]
pub fn set_variant(&mut self, variant: Variant)pub fn set_weight(&mut self, weight: Weight)[src]
pub fn set_weight(&mut self, weight: Weight)pub fn to_filename(&self) -> Option<String>[src]
pub fn to_filename(&self) -> Option<String>pub fn unset_fields(&mut self, to_unset: FontMask)[src]
pub fn unset_fields(&mut self, to_unset: FontMask)pub fn from_string(str: &str) -> FontDescription[src]
pub fn from_string(str: &str) -> FontDescriptionimpl FontDescription[src]
impl FontDescriptionpub fn set_family_static(&mut self, family: &'static str)[src]
pub fn set_family_static(&mut self, family: &'static str)Trait Implementations
impl Debug for FontDescription[src]
impl Debug for FontDescriptionfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialOrd for FontDescription[src]
impl PartialOrd for FontDescriptionfn partial_cmp(&self, other: &FontDescription) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &FontDescription) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &FontDescription) -> bool[src]
fn lt(&self, other: &FontDescription) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &FontDescription) -> bool[src]
fn le(&self, other: &FontDescription) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &FontDescription) -> bool[src]
fn gt(&self, other: &FontDescription) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &FontDescription) -> bool[src]
fn ge(&self, other: &FontDescription) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for FontDescription[src]
impl Ord for FontDescriptionfn cmp(&self, other: &FontDescription) -> Ordering[src]
fn cmp(&self, other: &FontDescription) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Clone for FontDescription
impl Clone for FontDescriptionfn clone(&self) -> FontDescription
fn clone(&self) -> FontDescriptionReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for FontDescription
impl StaticType for FontDescriptionfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Default for FontDescription[src]
impl Default for FontDescriptionimpl PartialEq for FontDescription[src]
impl PartialEq for FontDescriptionfn eq(&self, other: &Self) -> bool[src]
fn eq(&self, other: &Self) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for FontDescription[src]
impl Eq for FontDescriptionimpl Display for FontDescription[src]
impl Display for FontDescriptionfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for FontDescription[src]
impl Hash for FontDescriptionAuto Trait Implementations
impl !Send for FontDescription
impl !Send for FontDescriptionimpl !Sync for FontDescription
impl !Sync for FontDescription