Struct pango::FontMask [−]
pub struct FontMask { /* fields omitted */ }Methods
impl FontMask
impl FontMaskpub const FAMILY: FontMask
FAMILY: FontMask = FontMask{bits: 1,}
pub const STYLE: FontMask
STYLE: FontMask = FontMask{bits: 2,}
pub const VARIANT: FontMask
VARIANT: FontMask = FontMask{bits: 4,}
pub const WEIGHT: FontMask
WEIGHT: FontMask = FontMask{bits: 8,}
pub const STRETCH: FontMask
STRETCH: FontMask = FontMask{bits: 16,}
pub const SIZE: FontMask
SIZE: FontMask = FontMask{bits: 32,}
pub const GRAVITY: FontMask
GRAVITY: FontMask = FontMask{bits: 64,}
pub fn empty() -> FontMask
pub fn empty() -> FontMaskReturns an empty set of flags.
pub fn all() -> FontMask
pub fn all() -> FontMaskReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<FontMask>
pub fn from_bits(bits: u32) -> Option<FontMask>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> FontMask
pub fn from_bits_truncate(bits: u32) -> FontMaskConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: FontMask) -> bool
pub fn intersects(&self, other: FontMask) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: FontMask) -> bool
pub fn contains(&self, other: FontMask) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: FontMask)
pub fn insert(&mut self, other: FontMask)Inserts the specified flags in-place.
pub fn remove(&mut self, other: FontMask)
pub fn remove(&mut self, other: FontMask)Removes the specified flags in-place.
pub fn toggle(&mut self, other: FontMask)
pub fn toggle(&mut self, other: FontMask)Toggles the specified flags in-place.
pub fn set(&mut self, other: FontMask, value: bool)
pub fn set(&mut self, other: FontMask, value: bool)Inserts or removes the specified flags depending on the passed value.