Struct pango::FontMetrics [−]
pub struct FontMetrics(_);
Methods
impl FontMetrics[src]
impl FontMetricspub fn new() -> FontMetrics[src]
pub fn new() -> FontMetricspub fn get_approximate_char_width(&self) -> i32[src]
pub fn get_approximate_char_width(&self) -> i32pub fn get_approximate_digit_width(&self) -> i32[src]
pub fn get_approximate_digit_width(&self) -> i32pub fn get_ascent(&self) -> i32[src]
pub fn get_ascent(&self) -> i32pub fn get_descent(&self) -> i32[src]
pub fn get_descent(&self) -> i32pub fn get_strikethrough_position(&self) -> i32[src]
pub fn get_strikethrough_position(&self) -> i32pub fn get_strikethrough_thickness(&self) -> i32[src]
pub fn get_strikethrough_thickness(&self) -> i32pub fn get_underline_position(&self) -> i32[src]
pub fn get_underline_position(&self) -> i32pub fn get_underline_thickness(&self) -> i32[src]
pub fn get_underline_thickness(&self) -> i32Trait Implementations
impl Debug for FontMetrics[src]
impl Debug for FontMetricsfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for FontMetrics[src]
impl PartialEq for FontMetricsfn eq(&self, other: &FontMetrics) -> bool[src]
fn eq(&self, other: &FontMetrics) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &FontMetrics) -> bool[src]
fn ne(&self, other: &FontMetrics) -> boolThis method tests for !=.
impl Eq for FontMetrics[src]
impl Eq for FontMetricsimpl PartialOrd for FontMetrics[src]
impl PartialOrd for FontMetricsfn partial_cmp(&self, other: &FontMetrics) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &FontMetrics) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &FontMetrics) -> bool[src]
fn lt(&self, other: &FontMetrics) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &FontMetrics) -> bool[src]
fn le(&self, other: &FontMetrics) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &FontMetrics) -> bool[src]
fn gt(&self, other: &FontMetrics) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &FontMetrics) -> bool[src]
fn ge(&self, other: &FontMetrics) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for FontMetrics[src]
impl Ord for FontMetricsfn cmp(&self, other: &FontMetrics) -> Ordering[src]
fn cmp(&self, other: &FontMetrics) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for FontMetrics[src]
impl Hash for FontMetricsfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for FontMetrics
impl Clone for FontMetricsfn clone(&self) -> FontMetrics
fn clone(&self) -> FontMetricsReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for FontMetrics
impl StaticType for FontMetricsfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Default for FontMetrics[src]
impl Default for FontMetricsAuto Trait Implementations
impl !Send for FontMetrics
impl !Send for FontMetricsimpl !Sync for FontMetrics
impl !Sync for FontMetrics