Struct pango::GlyphItemIter [−]
pub struct GlyphItemIter(_);
Methods
impl GlyphItemIter[src]
impl GlyphItemIterpub fn init_end(&mut self, glyph_item: &mut GlyphItem, text: &str) -> bool[src]
pub fn init_end(&mut self, glyph_item: &mut GlyphItem, text: &str) -> boolpub fn init_start(&mut self, glyph_item: &mut GlyphItem, text: &str) -> bool[src]
pub fn init_start(&mut self, glyph_item: &mut GlyphItem, text: &str) -> boolpub fn next_cluster(&mut self) -> bool[src]
pub fn next_cluster(&mut self) -> boolpub fn prev_cluster(&mut self) -> bool[src]
pub fn prev_cluster(&mut self) -> boolTrait Implementations
impl Debug for GlyphItemIter[src]
impl Debug for GlyphItemIterfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for GlyphItemIter[src]
impl PartialEq for GlyphItemIterfn eq(&self, other: &GlyphItemIter) -> bool[src]
fn eq(&self, other: &GlyphItemIter) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &GlyphItemIter) -> bool[src]
fn ne(&self, other: &GlyphItemIter) -> boolThis method tests for !=.
impl Eq for GlyphItemIter[src]
impl Eq for GlyphItemIterimpl PartialOrd for GlyphItemIter[src]
impl PartialOrd for GlyphItemIterfn partial_cmp(&self, other: &GlyphItemIter) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &GlyphItemIter) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &GlyphItemIter) -> bool[src]
fn lt(&self, other: &GlyphItemIter) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &GlyphItemIter) -> bool[src]
fn le(&self, other: &GlyphItemIter) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &GlyphItemIter) -> bool[src]
fn gt(&self, other: &GlyphItemIter) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &GlyphItemIter) -> bool[src]
fn ge(&self, other: &GlyphItemIter) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for GlyphItemIter[src]
impl Ord for GlyphItemIterfn cmp(&self, other: &GlyphItemIter) -> Ordering[src]
fn cmp(&self, other: &GlyphItemIter) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for GlyphItemIter[src]
impl Hash for GlyphItemIterfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for GlyphItemIter
impl Clone for GlyphItemIterfn clone(&self) -> GlyphItemIter
fn clone(&self) -> GlyphItemIterReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for GlyphItemIter
impl StaticType for GlyphItemIterfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.