Struct pango::GlyphString [−]
pub struct GlyphString(_);
Methods
impl GlyphString[src]
impl GlyphStringpub fn new() -> GlyphString[src]
pub fn new() -> GlyphStringpub fn extents(&mut self, font: &Font) -> (Rectangle, Rectangle)[src]
pub fn extents(&mut self, font: &Font) -> (Rectangle, Rectangle)pub fn extents_range(
&mut self,
start: i32,
end: i32,
font: &Font
) -> (Rectangle, Rectangle)[src]
pub fn extents_range(
&mut self,
start: i32,
end: i32,
font: &Font
) -> (Rectangle, Rectangle)pub fn get_width(&mut self) -> i32[src]
pub fn get_width(&mut self) -> i32pub fn index_to_x(
&mut self,
text: &str,
analysis: &mut Analysis,
index_: i32,
trailing: bool
) -> i32[src]
pub fn index_to_x(
&mut self,
text: &str,
analysis: &mut Analysis,
index_: i32,
trailing: bool
) -> i32pub fn set_size(&mut self, new_len: i32)[src]
pub fn set_size(&mut self, new_len: i32)pub fn x_to_index(
&mut self,
text: &str,
analysis: &mut Analysis,
x_pos: i32
) -> (i32, i32)[src]
pub fn x_to_index(
&mut self,
text: &str,
analysis: &mut Analysis,
x_pos: i32
) -> (i32, i32)Trait Implementations
impl Debug for GlyphString[src]
impl Debug for GlyphStringfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for GlyphString[src]
impl PartialEq for GlyphStringfn eq(&self, other: &GlyphString) -> bool[src]
fn eq(&self, other: &GlyphString) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &GlyphString) -> bool[src]
fn ne(&self, other: &GlyphString) -> boolThis method tests for !=.
impl Eq for GlyphString[src]
impl Eq for GlyphStringimpl PartialOrd for GlyphString[src]
impl PartialOrd for GlyphStringfn partial_cmp(&self, other: &GlyphString) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &GlyphString) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &GlyphString) -> bool[src]
fn lt(&self, other: &GlyphString) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &GlyphString) -> bool[src]
fn le(&self, other: &GlyphString) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &GlyphString) -> bool[src]
fn gt(&self, other: &GlyphString) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &GlyphString) -> bool[src]
fn ge(&self, other: &GlyphString) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for GlyphString[src]
impl Ord for GlyphStringfn cmp(&self, other: &GlyphString) -> Ordering[src]
fn cmp(&self, other: &GlyphString) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for GlyphString[src]
impl Hash for GlyphStringfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for GlyphString
impl Clone for GlyphStringfn clone(&self) -> GlyphString
fn clone(&self) -> GlyphStringReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for GlyphString
impl StaticType for GlyphStringfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Default for GlyphString[src]
impl Default for GlyphStringAuto Trait Implementations
impl !Send for GlyphString
impl !Send for GlyphStringimpl !Sync for GlyphString
impl !Sync for GlyphString