Struct pango::Item [−]
pub struct Item(_);
Methods
impl Item[src]
impl Itempub fn new() -> Item[src]
pub fn new() -> Itempub fn split(&mut self, split_index: i32, split_offset: i32) -> Option<Item>[src]
pub fn split(&mut self, split_index: i32, split_offset: i32) -> Option<Item>impl Item[src]
impl Itempub fn offset(&self) -> i32[src]
pub fn offset(&self) -> i32pub fn length(&self) -> i32[src]
pub fn length(&self) -> i32pub fn num_chars(&self) -> i32[src]
pub fn num_chars(&self) -> i32pub fn analysis(&self) -> &Analysis[src]
pub fn analysis(&self) -> &AnalysisTrait Implementations
impl Debug for Item[src]
impl Debug for Itemfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for Item[src]
impl PartialEq for Itemfn eq(&self, other: &Item) -> bool[src]
fn eq(&self, other: &Item) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Item) -> bool[src]
fn ne(&self, other: &Item) -> boolThis method tests for !=.
impl Eq for Item[src]
impl Eq for Itemimpl PartialOrd for Item[src]
impl PartialOrd for Itemfn partial_cmp(&self, other: &Item) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &Item) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Item) -> bool[src]
fn lt(&self, other: &Item) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Item) -> bool[src]
fn le(&self, other: &Item) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Item) -> bool[src]
fn gt(&self, other: &Item) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Item) -> bool[src]
fn ge(&self, other: &Item) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for Item[src]
impl Ord for Itemfn cmp(&self, other: &Item) -> Ordering[src]
fn cmp(&self, other: &Item) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for Item[src]
impl Hash for Itemfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for Item
impl Clone for Itemfn clone(&self) -> Item
fn clone(&self) -> ItemReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for Item
impl StaticType for Itemfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl Default for Item[src]
impl Default for Item