Struct pango::LayoutIter [−]
pub struct LayoutIter(_);
Methods
impl LayoutIter[src]
impl LayoutIterpub fn at_last_line(&mut self) -> bool[src]
pub fn at_last_line(&mut self) -> boolpub fn get_baseline(&mut self) -> i32[src]
pub fn get_baseline(&mut self) -> i32pub fn get_char_extents(&mut self) -> Rectangle[src]
pub fn get_char_extents(&mut self) -> Rectanglepub fn get_cluster_extents(&mut self) -> (Rectangle, Rectangle)[src]
pub fn get_cluster_extents(&mut self) -> (Rectangle, Rectangle)pub fn get_index(&mut self) -> i32[src]
pub fn get_index(&mut self) -> i32pub fn get_layout(&mut self) -> Option<Layout>[src]
pub fn get_layout(&mut self) -> Option<Layout>pub fn get_layout_extents(&mut self) -> (Rectangle, Rectangle)[src]
pub fn get_layout_extents(&mut self) -> (Rectangle, Rectangle)pub fn get_line(&mut self) -> Option<LayoutLine>[src]
pub fn get_line(&mut self) -> Option<LayoutLine>pub fn get_line_extents(&mut self) -> (Rectangle, Rectangle)[src]
pub fn get_line_extents(&mut self) -> (Rectangle, Rectangle)pub fn get_line_readonly(&mut self) -> Option<LayoutLine>[src]
pub fn get_line_readonly(&mut self) -> Option<LayoutLine>pub fn get_line_yrange(&mut self) -> (i32, i32)[src]
pub fn get_line_yrange(&mut self) -> (i32, i32)pub fn get_run(&mut self) -> Option<LayoutRun>[src]
pub fn get_run(&mut self) -> Option<LayoutRun>pub fn get_run_extents(&mut self) -> (Rectangle, Rectangle)[src]
pub fn get_run_extents(&mut self) -> (Rectangle, Rectangle)pub fn get_run_readonly(&mut self) -> Option<LayoutRun>[src]
pub fn get_run_readonly(&mut self) -> Option<LayoutRun>pub fn next_char(&mut self) -> bool[src]
pub fn next_char(&mut self) -> boolpub fn next_cluster(&mut self) -> bool[src]
pub fn next_cluster(&mut self) -> boolpub fn next_line(&mut self) -> bool[src]
pub fn next_line(&mut self) -> boolpub fn next_run(&mut self) -> bool[src]
pub fn next_run(&mut self) -> boolTrait Implementations
impl Debug for LayoutIter[src]
impl Debug for LayoutIterfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for LayoutIter[src]
impl PartialEq for LayoutIterfn eq(&self, other: &LayoutIter) -> bool[src]
fn eq(&self, other: &LayoutIter) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &LayoutIter) -> bool[src]
fn ne(&self, other: &LayoutIter) -> boolThis method tests for !=.
impl Eq for LayoutIter[src]
impl Eq for LayoutIterimpl PartialOrd for LayoutIter[src]
impl PartialOrd for LayoutIterfn partial_cmp(&self, other: &LayoutIter) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &LayoutIter) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &LayoutIter) -> bool[src]
fn lt(&self, other: &LayoutIter) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &LayoutIter) -> bool[src]
fn le(&self, other: &LayoutIter) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &LayoutIter) -> bool[src]
fn gt(&self, other: &LayoutIter) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &LayoutIter) -> bool[src]
fn ge(&self, other: &LayoutIter) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for LayoutIter[src]
impl Ord for LayoutIterfn cmp(&self, other: &LayoutIter) -> Ordering[src]
fn cmp(&self, other: &LayoutIter) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for LayoutIter[src]
impl Hash for LayoutIterfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for LayoutIter
impl Clone for LayoutIterfn clone(&self) -> LayoutIter
fn clone(&self) -> LayoutIterReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for LayoutIter
impl StaticType for LayoutIterfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.