Struct pango::LayoutLine [−]
pub struct LayoutLine(_);
Methods
impl LayoutLine[src]
impl LayoutLinepub fn get_extents(&self) -> (Rectangle, Rectangle)[src]
pub fn get_extents(&self) -> (Rectangle, Rectangle)pub fn get_pixel_extents(&self) -> (Rectangle, Rectangle)[src]
pub fn get_pixel_extents(&self) -> (Rectangle, Rectangle)pub fn get_x_ranges(&self, start_index: i32, end_index: i32) -> Vec<i32>[src]
pub fn get_x_ranges(&self, start_index: i32, end_index: i32) -> Vec<i32>pub fn index_to_x(&self, index_: i32, trailing: bool) -> i32[src]
pub fn index_to_x(&self, index_: i32, trailing: bool) -> i32pub fn x_to_index(&self, x_pos: i32) -> Option<(i32, i32)>[src]
pub fn x_to_index(&self, x_pos: i32) -> Option<(i32, i32)>Trait Implementations
impl Debug for LayoutLine[src]
impl Debug for LayoutLinefn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for LayoutLine[src]
impl PartialEq for LayoutLinefn eq(&self, other: &LayoutLine) -> bool[src]
fn eq(&self, other: &LayoutLine) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &LayoutLine) -> bool[src]
fn ne(&self, other: &LayoutLine) -> boolThis method tests for !=.
impl Eq for LayoutLine[src]
impl Eq for LayoutLineimpl PartialOrd for LayoutLine[src]
impl PartialOrd for LayoutLinefn partial_cmp(&self, other: &LayoutLine) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &LayoutLine) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &LayoutLine) -> bool[src]
fn lt(&self, other: &LayoutLine) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &LayoutLine) -> bool[src]
fn le(&self, other: &LayoutLine) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &LayoutLine) -> bool[src]
fn gt(&self, other: &LayoutLine) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &LayoutLine) -> bool[src]
fn ge(&self, other: &LayoutLine) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for LayoutLine[src]
impl Ord for LayoutLinefn cmp(&self, other: &LayoutLine) -> Ordering[src]
fn cmp(&self, other: &LayoutLine) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for LayoutLine[src]
impl Hash for LayoutLinefn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for LayoutLine
impl Clone for LayoutLinefn clone(&self) -> LayoutLine
fn clone(&self) -> LayoutLineReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for LayoutLine
impl StaticType for LayoutLinefn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.