Struct pango::Matrix [−]
pub struct Matrix(_);
Methods
impl Matrix[src]
impl Matrixpub fn concat(&mut self, new_matrix: &Matrix)[src]
pub fn concat(&mut self, new_matrix: &Matrix)pub fn get_font_scale_factor(&self) -> f64[src]
pub fn get_font_scale_factor(&self) -> f64pub fn rotate(&mut self, degrees: f64)[src]
pub fn rotate(&mut self, degrees: f64)pub fn scale(&mut self, scale_x: f64, scale_y: f64)[src]
pub fn scale(&mut self, scale_x: f64, scale_y: f64)pub fn transform_distance(&self, dx: &mut f64, dy: &mut f64)[src]
pub fn transform_distance(&self, dx: &mut f64, dy: &mut f64)pub fn transform_point(&self, x: &mut f64, y: &mut f64)[src]
pub fn transform_point(&self, x: &mut f64, y: &mut f64)pub fn translate(&mut self, tx: f64, ty: f64)[src]
pub fn translate(&mut self, tx: f64, ty: f64)Trait Implementations
impl Debug for Matrix[src]
impl Debug for Matrixfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for Matrix[src]
impl PartialEq for Matrixfn eq(&self, other: &Matrix) -> bool[src]
fn eq(&self, other: &Matrix) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Matrix) -> bool[src]
fn ne(&self, other: &Matrix) -> boolThis method tests for !=.
impl Eq for Matrix[src]
impl Eq for Matriximpl PartialOrd for Matrix[src]
impl PartialOrd for Matrixfn partial_cmp(&self, other: &Matrix) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &Matrix) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Matrix) -> bool[src]
fn lt(&self, other: &Matrix) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Matrix) -> bool[src]
fn le(&self, other: &Matrix) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Matrix) -> bool[src]
fn gt(&self, other: &Matrix) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Matrix) -> bool[src]
fn ge(&self, other: &Matrix) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for Matrix[src]
impl Ord for Matrixfn cmp(&self, other: &Matrix) -> Ordering[src]
fn cmp(&self, other: &Matrix) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for Matrix[src]
impl Hash for Matrixfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for Matrix
impl Clone for Matrixfn clone(&self) -> Matrix
fn clone(&self) -> MatrixReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for Matrix
impl StaticType for Matrixfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.