Struct pango::TabArray [−]
pub struct TabArray(_);
Methods
impl TabArray[src]
impl TabArraypub fn new(initial_size: i32, positions_in_pixels: bool) -> TabArray[src]
pub fn new(initial_size: i32, positions_in_pixels: bool) -> TabArraypub fn get_positions_in_pixels(&mut self) -> bool[src]
pub fn get_positions_in_pixels(&mut self) -> boolpub fn get_size(&mut self) -> i32[src]
pub fn get_size(&mut self) -> i32pub fn get_tab(&mut self, tab_index: i32) -> (TabAlign, i32)[src]
pub fn get_tab(&mut self, tab_index: i32) -> (TabAlign, i32)pub fn resize(&mut self, new_size: i32)[src]
pub fn resize(&mut self, new_size: i32)pub fn set_tab(&mut self, tab_index: i32, alignment: TabAlign, location: i32)[src]
pub fn set_tab(&mut self, tab_index: i32, alignment: TabAlign, location: i32)Trait Implementations
impl Debug for TabArray[src]
impl Debug for TabArrayfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for TabArray[src]
impl PartialEq for TabArrayfn eq(&self, other: &TabArray) -> bool[src]
fn eq(&self, other: &TabArray) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &TabArray) -> bool[src]
fn ne(&self, other: &TabArray) -> boolThis method tests for !=.
impl Eq for TabArray[src]
impl Eq for TabArrayimpl PartialOrd for TabArray[src]
impl PartialOrd for TabArrayfn partial_cmp(&self, other: &TabArray) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &TabArray) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &TabArray) -> bool[src]
fn lt(&self, other: &TabArray) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &TabArray) -> bool[src]
fn le(&self, other: &TabArray) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &TabArray) -> bool[src]
fn gt(&self, other: &TabArray) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &TabArray) -> bool[src]
fn ge(&self, other: &TabArray) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for TabArray[src]
impl Ord for TabArrayfn cmp(&self, other: &TabArray) -> Ordering[src]
fn cmp(&self, other: &TabArray) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for TabArray[src]
impl Hash for TabArrayfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Clone for TabArray
impl Clone for TabArrayfn clone(&self) -> TabArray
fn clone(&self) -> TabArrayReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl StaticType for TabArray
impl StaticType for TabArrayfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.