pub trait DeviceProviderExtManual: IsA<DeviceProvider> + 'static {
// Provided methods
fn metadata<'a>(&self, key: &str) -> Option<&'a str> { ... }
fn devices(&self) -> List<Device> { ... }
}Provided Methods
Sourcefn devices(&self) -> List<Device>
fn devices(&self) -> List<Device>
Gets a list of devices that this provider understands. This may actually probe the hardware if the provider is not currently started.
If the provider has been started, this will return the same Device
objects that have been returned by the GST_MESSAGE_DEVICE_ADDED messages.
Returns
a GList of
Device
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.