[−][src]Struct gstreamer::ClockTime
Methods
impl ClockTime[src]
pub fn hours(&self) -> Option<u64>[src]
pub fn minutes(&self) -> Option<u64>[src]
pub fn seconds(&self) -> Option<u64>[src]
pub fn mseconds(&self) -> Option<u64>[src]
pub fn useconds(&self) -> Option<u64>[src]
pub fn nseconds(&self) -> Option<u64>[src]
pub fn nanoseconds(&self) -> Option<u64>[src]
pub fn from_seconds(seconds: u64) -> ClockTime[src]
pub fn from_mseconds(mseconds: u64) -> ClockTime[src]
pub fn from_useconds(useconds: u64) -> ClockTime[src]
pub fn from_nseconds(nseconds: u64) -> ClockTime[src]
pub fn none() -> ClockTime[src]
Methods from Deref<Target = Option<u64>>
pub fn is_some(&self) -> bool1.0.0[src]
Returns true if the option is a Some value.
Examples
let x: Option<u32> = Some(2); assert_eq!(x.is_some(), true); let x: Option<u32> = None; assert_eq!(x.is_some(), false);
pub fn is_none(&self) -> bool1.0.0[src]
Returns true if the option is a None value.
Examples
let x: Option<u32> = Some(2); assert_eq!(x.is_none(), false); let x: Option<u32> = None; assert_eq!(x.is_none(), true);
pub fn as_ref(&self) -> Option<&T>1.0.0[src]
Converts from Option<T> to Option<&T>.
Examples
Converts an Option<String> into an Option<usize>, preserving the original.
The map method takes the self argument by value, consuming the original,
so this technique uses as_ref to first take an Option to a reference
to the value inside the original.
let text: Option<String> = Some("Hello, world!".to_string()); // First, cast `Option<String>` to `Option<&String>` with `as_ref`, // then consume *that* with `map`, leaving `text` on the stack. let text_length: Option<usize> = text.as_ref().map(|s| s.len()); println!("still can print text: {:?}", text);
pub fn as_mut(&mut self) -> Option<&mut T>1.0.0[src]
Converts from Option<T> to Option<&mut T>.
Examples
let mut x = Some(2); match x.as_mut() { Some(v) => *v = 42, None => {}, } assert_eq!(x, Some(42));
pub fn as_pin_ref(self: Pin<&'a Option<T>>) -> Option<Pin<&'a T>>1.33.0[src]
Converts from Pin<&Option<T>> to Option<Pin<&T>>
pub fn as_pin_mut(self: Pin<&'a mut Option<T>>) -> Option<Pin<&'a mut T>>1.33.0[src]
Converts from Pin<&mut Option<T>> to Option<Pin<&mut T>>
pub fn iter(&self) -> Iter<T>1.0.0[src]
Returns an iterator over the possibly contained value.
Examples
let x = Some(4); assert_eq!(x.iter().next(), Some(&4)); let x: Option<u32> = None; assert_eq!(x.iter().next(), None);
pub fn iter_mut(&mut self) -> IterMut<T>1.0.0[src]
Returns a mutable iterator over the possibly contained value.
Examples
let mut x = Some(4); match x.iter_mut().next() { Some(v) => *v = 42, None => {}, } assert_eq!(x, Some(42)); let mut x: Option<u32> = None; assert_eq!(x.iter_mut().next(), None);
pub fn get_or_insert(&mut self, v: T) -> &mut T1.20.0[src]
Inserts v into the option if it is None, then
returns a mutable reference to the contained value.
Examples
let mut x = None; { let y: &mut u32 = x.get_or_insert(5); assert_eq!(y, &5); *y = 7; } assert_eq!(x, Some(7));
pub fn get_or_insert_with<F>(&mut self, f: F) -> &mut T where
F: FnOnce() -> T, 1.20.0[src]
F: FnOnce() -> T,
Inserts a value computed from f into the option if it is None, then
returns a mutable reference to the contained value.
Examples
let mut x = None; { let y: &mut u32 = x.get_or_insert_with(|| 5); assert_eq!(y, &5); *y = 7; } assert_eq!(x, Some(7));
pub fn take(&mut self) -> Option<T>1.0.0[src]
Takes the value out of the option, leaving a None in its place.
Examples
let mut x = Some(2); let y = x.take(); assert_eq!(x, None); assert_eq!(y, Some(2)); let mut x: Option<u32> = None; let y = x.take(); assert_eq!(x, None); assert_eq!(y, None);
pub fn replace(&mut self, value: T) -> Option<T>1.31.0[src]
Replaces the actual value in the option by the value given in parameter,
returning the old value if present,
leaving a Some in its place without deinitializing either one.
Examples
let mut x = Some(2); let old = x.replace(5); assert_eq!(x, Some(5)); assert_eq!(old, Some(2)); let mut x = None; let old = x.replace(3); assert_eq!(x, Some(3)); assert_eq!(old, None);
pub fn deref(&self) -> Option<&<T as Deref>::Target>[src]
🔬 This is a nightly-only experimental API. (inner_deref)
newly added
Converts from &Option<T> to Option<&T::Target>.
Leaves the original Option in-place, creating a new one with a reference
to the original one, additionally coercing the contents via Deref.