Struct gstreamer_pbutils::DiscovererAudioInfo [−]
pub struct DiscovererAudioInfo(_, _);
DiscovererStreamInfo specific to audio streams.
Implements
Methods
impl DiscovererAudioInfo[src]
impl DiscovererAudioInfopub fn get_bitrate(&self) -> u32[src]
pub fn get_bitrate(&self) -> u32Returns
the average or nominal bitrate of the stream in bits/second.
pub fn get_channel_mask(&self) -> u64[src]
pub fn get_channel_mask(&self) -> u64Feature: v1_14
Returns
the channel-mask of the stream, refer to
gst_audio_channel_positions_from_mask for more
information.
pub fn get_channels(&self) -> u32[src]
pub fn get_channels(&self) -> u32Returns
the number of channels in the stream.
pub fn get_depth(&self) -> u32[src]
pub fn get_depth(&self) -> u32Returns
the number of bits used per sample in each channel.
pub fn get_language(&self) -> Option<String>[src]
pub fn get_language(&self) -> Option<String>Returns
the language of the stream, or NULL if unknown.
pub fn get_max_bitrate(&self) -> u32[src]
pub fn get_max_bitrate(&self) -> u32Returns
the maximum bitrate of the stream in bits/second.
pub fn get_sample_rate(&self) -> u32[src]
pub fn get_sample_rate(&self) -> u32Returns
the sample rate of the stream in Hertz.