Struct gstreamer_pbutils::DiscovererSerializeFlags [−]
pub struct DiscovererSerializeFlags { /* fields omitted */ }Methods
impl DiscovererSerializeFlags
impl DiscovererSerializeFlagspub const BASIC: DiscovererSerializeFlags
BASIC: DiscovererSerializeFlags = DiscovererSerializeFlags{bits: 0,}
pub const CAPS: DiscovererSerializeFlags
CAPS: DiscovererSerializeFlags = DiscovererSerializeFlags{bits: 1,}
pub const TAGS: DiscovererSerializeFlags
TAGS: DiscovererSerializeFlags = DiscovererSerializeFlags{bits: 2,}
pub const MISC: DiscovererSerializeFlags
MISC: DiscovererSerializeFlags = DiscovererSerializeFlags{bits: 4,}
pub const ALL: DiscovererSerializeFlags
ALL: DiscovererSerializeFlags = DiscovererSerializeFlags{bits: 7,}
pub fn empty() -> DiscovererSerializeFlags
pub fn empty() -> DiscovererSerializeFlagsReturns an empty set of flags.
pub fn all() -> DiscovererSerializeFlags
pub fn all() -> DiscovererSerializeFlagsReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<DiscovererSerializeFlags>
pub fn from_bits(bits: u32) -> Option<DiscovererSerializeFlags>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> DiscovererSerializeFlags
pub fn from_bits_truncate(bits: u32) -> DiscovererSerializeFlagsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: DiscovererSerializeFlags) -> bool
pub fn intersects(&self, other: DiscovererSerializeFlags) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: DiscovererSerializeFlags) -> bool
pub fn contains(&self, other: DiscovererSerializeFlags) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: DiscovererSerializeFlags)
pub fn insert(&mut self, other: DiscovererSerializeFlags)Inserts the specified flags in-place.
pub fn remove(&mut self, other: DiscovererSerializeFlags)
pub fn remove(&mut self, other: DiscovererSerializeFlags)Removes the specified flags in-place.
pub fn toggle(&mut self, other: DiscovererSerializeFlags)
pub fn toggle(&mut self, other: DiscovererSerializeFlags)Toggles the specified flags in-place.
pub fn set(&mut self, other: DiscovererSerializeFlags, value: bool)
pub fn set(&mut self, other: DiscovererSerializeFlags, value: bool)Inserts or removes the specified flags depending on the passed value.