Struct gstreamer_pbutils::DiscovererStreamInfo [−]
pub struct DiscovererStreamInfo(_, _);
Base structure for information concerning a media stream. Depending on the
stream type, one can find more media-specific information in
DiscovererAudioInfo, DiscovererVideoInfo, and
DiscovererContainerInfo.
The DiscovererStreamInfo represents the topology of the stream. Siblings
can be iterated over with DiscovererStreamInfoExt::get_next and
DiscovererStreamInfoExt::get_previous. Children (sub-streams) of a
stream can be accessed using the DiscovererContainerInfo API.
As a simple example, if you run Discoverer on an AVI file with one audio
and one video stream, you will get a DiscovererContainerInfo
corresponding to the AVI container, which in turn will have a
DiscovererAudioInfo sub-stream and a DiscovererVideoInfo sub-stream
for the audio and video streams respectively.
Implements
Methods
impl DiscovererStreamInfo[src]
impl DiscovererStreamInfoⓘImportant traits for Iterpub fn next_iter(&self) -> Iter[src]
pub fn next_iter(&self) -> IterⓘImportant traits for Iterpub fn previous_iter(&self) -> Iter[src]
pub fn previous_iter(&self) -> IterTrait Implementations
impl IsA<DiscovererStreamInfo> for DiscovererAudioInfo
impl IsA<DiscovererStreamInfo> for DiscovererAudioInfoimpl IsA<DiscovererStreamInfo> for DiscovererContainerInfo
impl IsA<DiscovererStreamInfo> for DiscovererContainerInfoimpl Clone for DiscovererStreamInfo
impl Clone for DiscovererStreamInfofn clone(&self) -> DiscovererStreamInfo
fn clone(&self) -> DiscovererStreamInfoReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for DiscovererStreamInfo
impl Hash for DiscovererStreamInfofn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for DiscovererStreamInfo
impl Ord for DiscovererStreamInfofn cmp(&self, other: &DiscovererStreamInfo) -> Ordering
fn cmp(&self, other: &DiscovererStreamInfo) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for DiscovererStreamInfo
impl StaticType for DiscovererStreamInfofn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for DiscovererStreamInfo
impl<T: IsA<Object>> PartialEq<T> for DiscovererStreamInfofn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for DiscovererStreamInfo
impl Eq for DiscovererStreamInfoimpl<T: IsA<Object>> PartialOrd<T> for DiscovererStreamInfo
impl<T: IsA<Object>> PartialOrd<T> for DiscovererStreamInfofn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for DiscovererStreamInfo
impl Debug for DiscovererStreamInfoimpl IsA<Object> for DiscovererStreamInfo
impl IsA<Object> for DiscovererStreamInfoimpl Send for DiscovererStreamInfo[src]
impl Send for DiscovererStreamInfoimpl Sync for DiscovererStreamInfo[src]
impl Sync for DiscovererStreamInfoimpl IsA<DiscovererStreamInfo> for DiscovererSubtitleInfo
impl IsA<DiscovererStreamInfo> for DiscovererSubtitleInfoimpl IsA<DiscovererStreamInfo> for DiscovererVideoInfo
impl IsA<DiscovererStreamInfo> for DiscovererVideoInfo