Struct gstreamer_pbutils::DiscovererVideoInfo [−]
pub struct DiscovererVideoInfo(_, _);
DiscovererStreamInfo specific to video streams (this includes images).
Implements
Methods
impl DiscovererVideoInfo[src]
impl DiscovererVideoInfopub fn get_bitrate(&self) -> u32[src]
pub fn get_bitrate(&self) -> u32Returns
the average or nominal bitrate of the video stream in bits/second.
pub fn get_depth(&self) -> u32[src]
pub fn get_depth(&self) -> u32Returns
the depth in bits of the video stream.
pub fn get_height(&self) -> u32[src]
pub fn get_height(&self) -> u32Returns
the height of the video stream in pixels.
pub fn get_max_bitrate(&self) -> u32[src]
pub fn get_max_bitrate(&self) -> u32Returns
the maximum bitrate of the video stream in bits/second.
pub fn get_width(&self) -> u32[src]
pub fn get_width(&self) -> u32Returns
the width of the video stream in pixels.
pub fn is_image(&self) -> bool[src]
pub fn is_image(&self) -> boolReturns
true if the video stream corresponds to an image (i.e. only contains
one frame).
pub fn is_interlaced(&self) -> bool[src]
pub fn is_interlaced(&self) -> boolReturns
true if the stream is interlaced, else false.
impl DiscovererVideoInfo[src]
impl DiscovererVideoInfoTrait Implementations
impl Clone for DiscovererVideoInfo
impl Clone for DiscovererVideoInfofn clone(&self) -> DiscovererVideoInfo
fn clone(&self) -> DiscovererVideoInfoReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Hash for DiscovererVideoInfo
impl Hash for DiscovererVideoInfofn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Ord for DiscovererVideoInfo
impl Ord for DiscovererVideoInfofn cmp(&self, other: &DiscovererVideoInfo) -> Ordering
fn cmp(&self, other: &DiscovererVideoInfo) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl StaticType for DiscovererVideoInfo
impl StaticType for DiscovererVideoInfofn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for DiscovererVideoInfo
impl<T: IsA<Object>> PartialEq<T> for DiscovererVideoInfofn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for DiscovererVideoInfo
impl Eq for DiscovererVideoInfoimpl<T: IsA<Object>> PartialOrd<T> for DiscovererVideoInfo
impl<T: IsA<Object>> PartialOrd<T> for DiscovererVideoInfofn partial_cmp(&self, other: &T) -> Option<Ordering>
fn partial_cmp(&self, other: &T) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
#[must_use]
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]
fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
#[must_use]
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
#[must_use]
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Debug for DiscovererVideoInfo
impl Debug for DiscovererVideoInfoimpl IsA<DiscovererStreamInfo> for DiscovererVideoInfo
impl IsA<DiscovererStreamInfo> for DiscovererVideoInfoimpl IsA<Object> for DiscovererVideoInfo
impl IsA<Object> for DiscovererVideoInfoimpl Send for DiscovererVideoInfo[src]
impl Send for DiscovererVideoInfoimpl Sync for DiscovererVideoInfo[src]
impl Sync for DiscovererVideoInfo