Struct gstreamer::Object [−]
pub struct Object(_, _);
Methods
impl Object[src]
impl ObjectTrait Implementations
impl IsA<Object> for Bin
impl IsA<Object> for Binimpl IsA<Object> for BufferPool
impl IsA<Object> for BufferPoolimpl IsA<Object> for Bus
impl IsA<Object> for Busimpl IsA<Object> for Clock
impl IsA<Object> for Clockimpl IsA<Object> for Device
impl IsA<Object> for Deviceimpl IsA<Object> for DeviceMonitor
impl IsA<Object> for DeviceMonitorimpl IsA<Object> for DeviceProvider
impl IsA<Object> for DeviceProviderimpl IsA<Object> for DeviceProviderFactory
impl IsA<Object> for DeviceProviderFactoryimpl IsA<Object> for Element
impl IsA<Object> for Elementimpl IsA<Object> for ElementFactory
impl IsA<Object> for ElementFactoryimpl IsA<Object> for GhostPad
impl IsA<Object> for GhostPadimpl Clone for Object
impl Clone for Objectfn clone(&self) -> Object
fn clone(&self) -> ObjectReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Debug for Object
impl Debug for Objectimpl Hash for Object
impl Hash for Objectfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl StaticType for Object
impl StaticType for Objectfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for Object
impl<T: IsA<Object>> PartialEq<T> for Objectfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
fn ne(&self, other: &Rhs) -> bool1.0.0
[src]This method tests for !=.
impl Eq for Object
impl Eq for Objectimpl IsA<Object> for Object
impl IsA<Object> for Objectimpl Send for Object[src]
impl Send for Objectimpl Sync for Object[src]
impl Sync for Objectimpl IsA<Object> for Pad
impl IsA<Object> for Padimpl IsA<Object> for PadTemplate
impl IsA<Object> for PadTemplateimpl IsA<Object> for Pipeline
impl IsA<Object> for Pipelineimpl IsA<Object> for Plugin
impl IsA<Object> for Pluginimpl IsA<Object> for PluginFeature
impl IsA<Object> for PluginFeatureimpl IsA<Object> for ProxyPad
impl IsA<Object> for ProxyPadimpl IsA<Object> for Registry
impl IsA<Object> for Registryimpl IsA<Object> for SystemClock
impl IsA<Object> for SystemClockimpl IsA<Object> for TagSetter
impl IsA<Object> for TagSetterimpl IsA<Object> for TocSetter
impl IsA<Object> for TocSetterimpl IsA<Object> for TypeFindFactory
impl IsA<Object> for TypeFindFactory