Struct gstreamer::TypeFindFactory [−]
pub struct TypeFindFactory(_, _);
Methods
impl TypeFindFactory[src]
impl TypeFindFactorypub fn get_caps(&self) -> Option<Caps>[src]
pub fn get_caps(&self) -> Option<Caps>pub fn get_extensions(&self) -> Vec<String>[src]
pub fn get_extensions(&self) -> Vec<String>pub fn has_function(&self) -> bool[src]
pub fn has_function(&self) -> boolpub fn get_list() -> Vec<TypeFindFactory>[src]
pub fn get_list() -> Vec<TypeFindFactory>impl TypeFindFactory[src]
impl TypeFindFactorypub fn call_function(&self, find: &mut TypeFindImpl)[src]
pub fn call_function(&self, find: &mut TypeFindImpl)Trait Implementations
impl Clone for TypeFindFactory
impl Clone for TypeFindFactoryfn clone(&self) -> TypeFindFactory
fn clone(&self) -> TypeFindFactoryReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Debug for TypeFindFactory
impl Debug for TypeFindFactoryimpl Hash for TypeFindFactory
impl Hash for TypeFindFactoryfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl StaticType for TypeFindFactory
impl StaticType for TypeFindFactoryfn static_type() -> Type
fn static_type() -> TypeReturns the type identifier of Self.
impl<T: IsA<Object>> PartialEq<T> for TypeFindFactory
impl<T: IsA<Object>> PartialEq<T> for TypeFindFactoryfn eq(&self, other: &T) -> bool
fn eq(&self, other: &T) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
fn ne(&self, other: &Rhs) -> bool1.0.0
[src]This method tests for !=.
impl Eq for TypeFindFactory
impl Eq for TypeFindFactoryimpl IsA<PluginFeature> for TypeFindFactory
impl IsA<PluginFeature> for TypeFindFactoryimpl IsA<Object> for TypeFindFactory
impl IsA<Object> for TypeFindFactoryimpl IsA<Object> for TypeFindFactory
impl IsA<Object> for TypeFindFactoryimpl Send for TypeFindFactory[src]
impl Send for TypeFindFactoryimpl Sync for TypeFindFactory[src]
impl Sync for TypeFindFactory